'From Squeak3.1alpha of 27 September 2001 [latest update: #4347] on 11 March 2002 at 8:16 pm'!
"Change Set:		CommandShell-sUnitV3-0
Date:			10 March 2002
Author:			David T. Lewis

Unit tests for CommandShell"!

TestCase subclass: #CommandShellTestCase
	instanceVariableNames: 'shell checkFileHandleCount '
	classVariableNames: 'TempResult '
	poolDictionaries: ''
	category: 'OSProcess-SUnit'!

!CommandShellTestCase commentStamp: 'dtl 12/30/2001 17:05' prior: 0!
Unit tests for CommandShell. This tests a reasonable range of command line inputs, verifying command execution and IO redirection for internal and external process proxies.

Many of the tests can try to check for unclosed file handles. The #setUp method sets the value of checkFileHandleCount (true or false) to control this. In addition, the #runAll method can separately do a count of open file handles after running all the tests. Unfortunately, there are a couple of problems with this. First, the check makes use of the /proc filesystem on Linux, which will not be available (or may be implemented differently) on other systems. Second, for reasons which I do not quite understand, files may stay open (or perhaps just appear to stay open in the /proc filesystem) after Squeak has apparently closed them. This produces intermittent failures in the unit tests. For these reasons, I recommend running the file handle count checks once or twice to make sure things are working correctly, then turning the checks off in the #setUp method to avoid seeing intermittent errors later on. If anyone figures out what is going on here, please let me know. -dtl!

TestCase subclass: #InternalPipeTestCase
	instanceVariableNames: 'pipe '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-SUnit'!

!InternalPipeTestCase commentStamp: 'dtl 12/30/2001 17:05' prior: 0!
Test operation of InternalPipe in blocking and nonBlocking mode.!


!CommandShellTestCase methodsFor: 'running' stamp: 'dtl 3/9/2002 19:56'!
runAll
	"Functional failures will be reported as failures, and problems with number
	of open file handles will be reported as errors (they can be intermittent and
	possibly bogus). Note: setting checkFileHandleCount to true here forces a
	count check after all the tests are run. The individual tests may or may
	not do the file count check, depending on what is done in the #setUp method."

	"CommandShellTestCase new checkFileHandleCount: true; runAll"
	"CommandShellTestCase new checkFileHandleCount: false; runAll"

	| result suite openFileCount |
	suite := TestSuite new.
	openFileCount _ self numberOfOpenFiles.
	suite addTest: (CommandShellTestCase selector: #testPipeline01).
	suite addTest: (CommandShellTestCase selector: #testPipeline02).
	suite addTest: (CommandShellTestCase selector: #testPipeline03).
	suite addTest: (CommandShellTestCase selector: #testPipeline04).
	suite addTest: (CommandShellTestCase selector: #testPipeline05).
	suite addTest: (CommandShellTestCase selector: #testPipeline06).
	suite addTest: (CommandShellTestCase selector: #testPipeline07).
	suite addTest: (CommandShellTestCase selector: #testPipeline08).
	suite addTest: (CommandShellTestCase selector: #testPipeline09).
	suite addTest: (CommandShellTestCase selector: #testPipeline10).
	suite addTest: (CommandShellTestCase selector: #testPipeline11).
	suite addTest: (CommandShellTestCase selector: #testPipeline12).
	suite addTest: (CommandShellTestCase selector: #testPipeline13).
	suite addTest: (CommandShellTestCase selector: #testPipeline14).
	suite addTest: (CommandShellTestCase selector: #testPipeline20).
	suite addTest: (CommandShellTestCase selector: #testPipeline21).
	suite addTest: (CommandShellTestCase selector: #testPipeline22).
	suite addTest: (CommandShellTestCase selector: #testPipeline23).
	suite addTest: (CommandShellTestCase selector: #testPipeline24).
	suite addTest: (CommandShellTestCase selector: #testPipeline25).
	suite addTest: (CommandShellTestCase selector: #testPipeline26).
	suite addTest: (CommandShellTestCase selector: #testPipeline27).
	suite addTest: (CommandShellTestCase selector: #testPipeline28).
	suite addTest: (CommandShellTestCase selector: #testPipeline30).
	suite addTest: (CommandShellTestCase selector: #testPipeline31).
	suite addTest: (CommandShellTestCase selector: #testPipeline32).
	suite addTest: (CommandShellTestCase selector: #testPipeline33).
	suite addTest: (CommandShellTestCase selector: #testPipeline34).
	suite addTest: (CommandShellTestCase selector: #testPipeline35).
	suite addTest: (CommandShellTestCase selector: #testPipeline36).
	suite addTest: (CommandShellTestCase selector: #testPipeline37).
	suite addTest: (CommandShellTestCase selector: #testPipeline38).
	suite addTest: (CommandShellTestCase selector: #testPipeline39).
	suite addTest: (CommandShellTestCase selector: #testPipeline40).
	suite addTest: (CommandShellTestCase selector: #testPipeline41).
	suite addTest: (CommandShellTestCase selector: #testPipeline42).
	suite addTest: (CommandShellTestCase selector: #testPipeline50).
	suite addTest: (CommandShellTestCase selector: #testPipeline51).
	suite addTest: (CommandShellTestCase selector: #testPipeline52).
	suite addTest: (CommandShellTestCase selector: #testPipeline53).
	suite addTest: (CommandShellTestCase selector: #testPipeline60).
	suite addTest: (CommandShellTestCase selector: #testPipeline61).
	suite addTest: (CommandShellTestCase selector: #testPipeline62).
	suite addTest: (CommandShellTestCase selector: #testPipeline63).
	suite addTest: (CommandShellTestCase selector: #testPipeline64).
	suite addTest: (CommandShellTestCase selector: #testPipeline65).
	suite addTest: (CommandShellTestCase selector: #testPipeline66).
	suite addTest: (CommandShellTestCase selector: #testPipeline70).
	suite addTest: (CommandShellTestCase selector: #testPipeline71).
	suite addTest: (CommandShellTestCase selector: #testPipeline72).
	suite addTest: (CommandShellTestCase selector: #testPipeline73).
	suite addTest: (CommandShellTestCase selector: #testPipeline74).
	suite addTest: (CommandShellTestCase selector: #testPipeline80).
	suite addTest: (CommandShellTestCase selector: #testPipeline81).
	suite addTest: (CommandShellTestCase selector: #testPipeline90).
	suite addTest: (CommandShellTestCase selector: #testPipeline91).
	suite addTest: (CommandShellTestCase selector: #testPipeline92).
	suite addTest: (CommandShellTestCase selector: #testPipeline93).
	suite addTest: (CommandShellTestCase selector: #testPipeline94).
	suite addTest: (CommandShellTestCase selector: #testPipeline95).
	result _ suite run.
	self should: [result defects size == 0].
	self should: [self isNumberOfOpenFiles: openFileCount].
	^ result
! !

!CommandShellTestCase methodsFor: 'running' stamp: 'dtl 10/14/2001 09:57'!
setUp

	shell _ CommandShell new.
	self checkFileHandleCount: false
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 1/1/2002 13:01'!
testDoCommandsInString1

	"(CommandShellTestCase selector: #testDoCommandsInString1) run"

	| command expectedResult |

	command _ 'help help | CommandShellTestCase tempResult: stdin upToEnd !!'.
	expectedResult _ (shell pipeline: 'help help') last output.
	self should: [expectedResult size > 10].
	self class tempResult: nil.
	shell doCommandsInString: command.
	(Delay forSeconds: 1) wait.	"Allow the command to run"
	self should: [self class tempResult = expectedResult]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline01

	"(CommandShellTestCase selector: #testPipeline01) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline02

	"(CommandShellTestCase selector: #testPipeline02) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'echo hello world'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: ['hello world*' match: o].
	self should: [o withBlanksTrimmed = 'hello world'].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline03

	"(CommandShellTestCase selector: #testPipeline03) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline04

	"(CommandShellTestCase selector: #testPipeline04) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline05

	"(CommandShellTestCase selector: #testPipeline05) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | cat | od | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline06

	"(CommandShellTestCase selector: #testPipeline06) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps > /tmp/delete.me | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline07

	"(CommandShellTestCase selector: #testPipeline07) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps > /dev/null | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline08

	"(CommandShellTestCase selector: #testPipeline08) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'cat < /etc/passwd | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline09

	"(CommandShellTestCase selector: #testPipeline09) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /etc/hosts /etc/NOSUCHFILE 2> /tmp/delete.me | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline10

	"(CommandShellTestCase selector: #testPipeline10) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | cat > /tmp/delete.me | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline11

	"(CommandShellTestCase selector: #testPipeline11) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | cat > /dev/null | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline12

	"(CommandShellTestCase selector: #testPipeline12) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ps | cat < /etc/passwd | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	(self numberOfOpenFiles == openFileCount) ifFalse: [Smalltalk garbageCollect].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline13

	"(CommandShellTestCase selector: #testPipeline13) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'who | ls /etc/hosts /etc/NOSUCHFILE 2> /tmp/delete.me | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline14

	"(CommandShellTestCase selector: #testPipeline14) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | cat < /etc/passwd | cat'.
	p _ procs last.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline20

	"(CommandShellTestCase selector: #testPipeline20) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline21

	"(CommandShellTestCase selector: #testPipeline21) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput > /tmp/delete.me | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline22

	"(CommandShellTestCase selector: #testPipeline22) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput 2> /tmp/delete.me | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline23

	"(CommandShellTestCase selector: #testPipeline23) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput 2 > /dev/null | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline24

	"(CommandShellTestCase selector: #testPipeline24) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput>/tmp/delete.me | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline25

	"(CommandShellTestCase selector: #testPipeline25) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput2>/tmp/delete.me | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline26

	"(CommandShellTestCase selector: #testPipeline26) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput < /etc/hosts | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:57'!
testPipeline27

	"(CommandShellTestCase selector: #testPipeline27) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput < /etc/hosts | copyToError'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:58'!
testPipeline28

	"(CommandShellTestCase selector: #testPipeline28) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls -l | copyToOutput < /etc/hosts | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline30

	"(CommandShellTestCase selector: #testPipeline30) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline31

	"(CommandShellTestCase selector: #testPipeline31) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput > /tmp/delete.me | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline32

	"(CommandShellTestCase selector: #testPipeline32) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput 2> /tmp/delete.me | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 11:16'!
testPipeline33

	"(CommandShellTestCase selector: #testPipeline33) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput 2> /dev/null | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	[p isComplete] whileFalse: [(Delay forMilliseconds: 200) wait].
	"FIXME: Need the following delay to avoid timing errors. This is a bug, but appears
	to have no practical impact - dtl"
	(Delay forMilliseconds: 200) wait.
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline34

	"(CommandShellTestCase selector: #testPipeline34) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput>/tmp/delete.me | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline35

	"(CommandShellTestCase selector: #testPipeline35) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput2>/tmp/delete.me | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline36

	"(CommandShellTestCase selector: #testPipeline36) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | copyToOutput < /etc/hosts | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline37

	"(CommandShellTestCase selector: #testPipeline37) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls -l | copyToOutput < /etc/hosts | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty not].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline38

	"(CommandShellTestCase selector: #testPipeline38) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/9/2002 17:56'!
testPipeline39

	"(CommandShellTestCase selector: #testPipeline39) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'help > /tmp/delete.me | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline40

	"(CommandShellTestCase selector: #testPipeline40) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'ps > /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline41

	"(CommandShellTestCase selector: #testPipeline41) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'ls /etc/hosts /NO/SUCH/FILE 2> /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline42

	"(CommandShellTestCase selector: #testPipeline42) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'cat < /etc/hosts'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/9/2002 19:54'!
testPipeline50

	"(CommandShellTestCase selector: #testPipeline50) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'help > /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self shouldnt: [(CommandShell new pipeline: 'cat /tmp/delete.me') last output isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 11:04'!
testPipeline51

	"(CommandShellTestCase selector: #testPipeline51) run"

	| openFileCount procs p o fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'copyToError /etc/hosts 2> /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline52

	"(CommandShellTestCase selector: #testPipeline52) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'copyToError < /etc/hosts 2> /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline53

	"(CommandShellTestCase selector: #testPipeline53) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'copyToOutput < /etc/hosts'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline60

	"(CommandShellTestCase selector: #testPipeline60) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'Smalltalk!! > /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self shouldnt: [(CommandShell new pipeline: 'cat /tmp/delete.me') last output isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline61

	"(CommandShellTestCase selector: #testPipeline61) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'stdout nextPutAll: ''Hello world!!'' !! > /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline62

	"(CommandShellTestCase selector: #testPipeline62) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'stderr nextPutAll: ''Hello stderr'' !! 2> /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline63

	"(CommandShellTestCase selector: #testPipeline63) run"

	| procs p o openFileCount |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'stdin upToEnd !! < /etc/hosts'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline64

	"(CommandShellTestCase selector: #testPipeline64) run"

	| procs p o openFileCount fs |
	openFileCount _ self numberOfOpenFiles.
	FileDirectory default deleteFileNamed: '/tmp/delete.me' ifAbsent: [].	
	procs _ shell pipeline: 'stdout nextPutAll: stdin upToEnd !! < /etc/hosts > /tmp/delete.me'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	fs _ FileStream fileNamed: '/tmp/delete.me'.
	self should: [fs upToEnd isEmpty not].
	fs close.
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 11/22/2001 12:06'!
testPipeline65
	"Run a fairly long Smalltalk expression and make sure the complete output
	gets picked up by the next internal process in the pipeline."

	"(CommandShellTestCase selector: #testPipeline65) run"

	| procs p o last |
	last _ (Smalltalk asArray first: 300) last printString.
	procs _ shell pipeline: 'Smalltalk asArray first: 300!! | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [((o copyFrom: (o size - (last size + 1)) to: o size) allButLast allButLast) = last]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/11/2002 20:15'!
testPipeline66
	"Run a fairly long Smalltalk expression and make sure the complete output
	gets picked up by the next internal process in the pipeline."

	"Warning: This test will produce a deadlock condition if the Smalltalk
	expression runs too long."

	"(CommandShellTestCase selector: #testPipeline66) run"

	| procs p o last count |
	count _ 150. "<== Make this smaller if you get a deadlock"
	last _ (Smalltalk asArray first: count) last printString.
	procs _ shell pipeline: 'Smalltalk asArray first: ', count printString, '!! | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [((o copyFrom: (o size - (last size + 1)) to: o size) allButLast allButLast) = last]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:23'!
testPipeline70

	"(CommandShellTestCase selector: #testPipeline70) run"

	| procs p o openFileCount e |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /no/such/file'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	e _ p errorUpToEnd.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [e isKindOf: String].
	self shouldnt: [e isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 07:22'!
testPipeline71

	"(CommandShellTestCase selector: #testPipeline71) run"

	| procs p o openFileCount e |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /no/such/file | cat'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	o _ p output.
	e _ p errorPipelineStream contents.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [e isKindOf: String].
	self shouldnt: [e isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 10:46'!
testPipeline72

	"(CommandShellTestCase selector: #testPipeline72) run"

	| procs p o openFileCount e |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /no/such/file | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	[p isComplete] whileFalse: [(Delay forMilliseconds: 200) wait].
	"FIXME: Need the following delay to avoid timing errors. This is a bug, but appears
	to have no practical impact - dtl"
	(Delay forMilliseconds: 200) wait.
	o _ p output.
	e _ p errorPipelineStream contents.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [e isKindOf: String].
	self shouldnt: [e isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 10:46'!
testPipeline73

	"(CommandShellTestCase selector: #testPipeline73) run"

	| procs p o openFileCount e |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /no/such/file | stdout nextPutAll: stdin upToEnd !!'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	[p isComplete] whileFalse: [(Delay forMilliseconds: 200) wait].
	"FIXME: Need the following delay to avoid timing errors. This is a bug, but appears
	to have no practical impact - dtl"
	(Delay forMilliseconds: 200) wait.
	o _ p output.
	e _ p errorPipelineStream contents.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [e isKindOf: String].
	self shouldnt: [e isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 10/13/2001 17:59'!
testPipeline74

	"(CommandShellTestCase selector: #testPipeline74) run"

	| procs p o openFileCount e |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /no/such/file | stdout nextPutAll: stdin upToEnd !! | cat | copyToOutput | cat | cat | copyToOutput | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	o _ p output.
	e _ p errorPipelineStream contents.
	self should: [o isKindOf: String].
	self should: [o isEmpty].
	self should: [e isKindOf: String].
	self shouldnt: [e isEmpty].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 3/4/2002 18:55'!
testPipeline80
	"Test error streaming for a PipeableOSProcess"

	"(CommandShellTestCase selector: #testPipeline80) run"

	| procs p o openFileCount errorLength e1 e2 |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /etc/hosts /NO/SUCH/FILE'.
	p _ procs last.
	self should: [p class == PipeableOSProcess].
	[p isComplete] whileFalse: [(Delay forMilliseconds: 100) wait].
	(Delay forMilliseconds: 200) wait.
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	errorLength _ p errorPipelineStream size.
	e1 _ p nextFromError: 15.
	e2 _ p errorUpToEnd.
	self should: [errorLength == (e1 size + (e2 size))].
	self should: [p errorUpToEnd isEmpty].
	self should: [p errorPipelineStream upToEnd size = 0].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 11/3/2001 10:22'!
testPipeline81
	"Test error streaming for a PipeableEvaluator"

	"(CommandShellTestCase selector: #testPipeline81) run"

	| procs p o openFileCount errorLength e1 e2 |
	openFileCount _ self numberOfOpenFiles.
	procs _ shell pipeline: 'ls /etc/hosts /NO/SUCH/FILE | copyToOutput'.
	p _ procs last.
	self should: [p class == PipeableEvaluator].
	[p isComplete] whileFalse: [(Delay forMilliseconds: 100) wait].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	errorLength _ p errorPipelineStream size.
	e1 _ p nextFromError: 15.
	e2 _ p errorUpToEnd.
	self should: [errorLength == (e1 size + (e2 size))].
	self should: [p errorUpToEnd isEmpty].
	self should: [p errorPipelineStream size == 0].
	self should: [self isNumberOfOpenFiles: openFileCount]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 14:50'!
testPipeline90
	"Test Smalltalk expression as the complete command. Do not worry about the
	actual output, as it gets clobbered by the prompt."

	"(CommandShellTestCase selector: #testPipeline90) run"

	| o |
	shell doCommandsInString: 'Smalltalk classNames size'.
	o _ shell setToEnd; contents.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	self should: [o size > 3]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 15:01'!
testPipeline91
	"Test Smalltalk expression as the complete command"

	"(CommandShellTestCase selector: #testPipeline91) run"

	| numberOfClasses p o numberCounted |
	numberOfClasses _ Smalltalk classNames size.
	p _ shell tryEvaluatingAsSmalltalk: 'Smalltalk classNames size'.
	self should: [p class == PipeableEvaluator].
	self should: [p isComplete].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self shouldnt: [o isEmpty].
	numberCounted _ o asInteger.
	self should: [numberCounted == numberOfClasses]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 14:56'!
testPipeline92
	"Test Smalltalk expression as the complete command"

	"(CommandShellTestCase selector: #testPipeline92) run"

	| p o |
	p _ shell tryEvaluatingAsSmalltalk: '#Smalltalk classNames size'.
	self should: [p class == PipeableEvaluator].
	self should: [p isComplete].
	self should: [p exitStatus == #fail].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self should: [o isEmpty]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 15:07'!
testPipeline93
	"Test Smalltalk expression as the complete command. Should fail in compiler."

	"(CommandShellTestCase selector: #testPipeline93) run"

	| p o |
	p _ shell tryEvaluatingAsSmalltalk: 'Smalltalk classNames size!!'.
	self should: [p class == PipeableEvaluator].
	self should: [p isComplete].
	self should: [p exitStatus == #fail].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self should: [o isEmpty]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 15:04'!
testPipeline94
	"Test Smalltalk expression as the complete command. Should fail in evaluation."

	"(CommandShellTestCase selector: #testPipeline94) run"

	| p o |
	p _ shell tryEvaluatingAsSmalltalk: 'Smalltalk noSuchSelector'.
	self should: [p class == PipeableEvaluator].
	self should: [p isComplete].
	self should: [p exitStatus == #fail].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self should: [o isEmpty]
! !

!CommandShellTestCase methodsFor: 'testing' stamp: 'dtl 12/1/2001 15:08'!
testPipeline95
	"Test Smalltalk expression as the complete command. Should fail in compiler."

	"(CommandShellTestCase selector: #testPipeline95) run"

	| p o |
	p _ shell tryEvaluatingAsSmalltalk: '(Smalltalk classNames size'.
	self should: [p class == PipeableEvaluator].
	self should: [p isComplete].
	self should: [p exitStatus == #fail].
	o _ p upToEnd.
	self should: [o isKindOf: String].
	self should: [o isEmpty]
! !

!CommandShellTestCase methodsFor: 'accessing' stamp: 'dtl 10/14/2001 09:34'!
checkFileHandleCount
	"If true, attempt to count the number of open file handles before and after
	tests. This uses the /proc file system on Linux, and may work on other systems
	which support a /proc file system."

	^ checkFileHandleCount! !

!CommandShellTestCase methodsFor: 'accessing' stamp: 'dtl 10/14/2001 09:34'!
checkFileHandleCount: trueOrFalse
	"If true, attempt to count the number of open file handles before and after
	tests. This uses the /proc file system on Linux, and may work on other systems
	which support a /proc file system."

	checkFileHandleCount _ trueOrFalse! !

!CommandShellTestCase methodsFor: 'private' stamp: 'dtl 10/14/2001 09:59'!
isNumberOfOpenFiles: anInteger
	"Answer true if the number of open file handles is anInteger. Do some garbage
	collection if necessary to clean up stale references, but give up after a few tries."

	| loops milliseconds |
	self checkFileHandleCount ifFalse: [^ true]. "Bypass the test"
	loops _ 4.
	milliseconds _ 500.
	(1 to: loops)
		detect:
			[:i | (self numberOfOpenFiles == anInteger)
				ifFalse:
					[(Delay forMilliseconds: milliseconds) wait.
					Smalltalk garbageCollect].
			self numberOfOpenFiles == anInteger]
		ifNone:
			["This causes the failure to appear as an error rather than a
			failure in the test runner. This kind of problem can be appear
			intermittently, and is different from a functional failure of
			a method."
			self error:
				self numberOfOpenFiles printString,
				' files are open, expected ', anInteger printString].
	^ self numberOfOpenFiles == anInteger
! !

!CommandShellTestCase methodsFor: 'private' stamp: 'dtl 10/14/2001 09:59'!
numberOfOpenFiles
	"Answer the number of files currently open for this OS process. This works
	only on a system with a /proc filesystem and file descriptors located in a
	directory called /proc/<pid>/fd. On other systems, just answer 0."

	"UnixProcessTestCase new numberOfOpenFiles"

	self checkFileHandleCount ifFalse: [^ 0]. "Bypass the test"
	^ (FileDirectory on: '/proc/' , OSProcess thisOSProcess pid printString, '/fd') entries size! !


!CommandShellTestCase class methodsFor: 'accessing' stamp: 'dtl 9/15/2001 12:49'!
tempResult
	"A global variable for holding the result of an internal process proxy evaluation.
	This is an ugly kludge."

	^ TempResult! !

!CommandShellTestCase class methodsFor: 'accessing' stamp: 'dtl 9/15/2001 12:50'!
tempResult: anObject
	"A global variable for holding the result of an internal process proxy evaluation.
	This is an ugly kludge."

	TempResult _ anObject! !


!InternalPipeTestCase methodsFor: 'running' stamp: 'dtl 11/25/2001 00:33'!
runAll

	"InternalPipeTestCase new runAll"

	| result suite |
	suite := TestSuite new.
	suite addTest: (InternalPipeTestCase selector: #testBlocking).
	suite addTest: (InternalPipeTestCase selector: #testNonBlocking).
	result _ suite run.
	self should: [result defects size == 0].
	^ result
! !

!InternalPipeTestCase methodsFor: 'running' stamp: 'dtl 11/25/2001 00:14'!
setUp

		pipe _ InternalPipe new
! !

!InternalPipeTestCase methodsFor: 'testing' stamp: 'dtl 11/25/2001 18:15'!
testBlocking

	"(InternalPipeTestCase selector: #testBlocking) run"

	| resultString |
	pipe setBlocking.
	self writeStuffOnThenClose: pipe.
	Processor yield.
	resultString _ pipe upToEnd last: 16.
	self should: [resultString notNil].
	self should: ['this is line 10*' match: resultString]
! !

!InternalPipeTestCase methodsFor: 'testing' stamp: 'dtl 11/25/2001 00:29'!
testNonBlocking

	"(InternalPipeTestCase selector: #testNonBlocking) run"

	| ws str |
	pipe setNonBlocking.
	self writeStuffOnThenClose: pipe.
	ws _ self readFromAndClose: pipe writingTo: (WriteStream on: String new).
	str _ (ws contents last: 16).
	self should: ['this is line 10*' match: str]
! !

!InternalPipeTestCase methodsFor: 'private' stamp: 'dtl 11/25/2001 00:42'!
readFromAndClose: aPipe writingTo: aStream

	| s |
	[aPipe atEnd] whileFalse:
		[s _ aPipe next: 10000.
		aStream nextPutAll: s asString.
		(Delay forMilliseconds: 100) wait].
	(aPipe respondsTo: #reader) ifTrue: [aPipe reader close].
	^ aStream
! !

!InternalPipeTestCase methodsFor: 'private' stamp: 'dtl 11/25/2001 17:28'!
writeStuffOnThenClose: aPipe

	^ [(1 to: 10) do:
		[:i |
		aPipe nextPutAll: 'this is line ', i printString; cr.
		(Delay forMilliseconds: 100) wait].
	(aPipe respondsTo: #writer)
		ifTrue: [aPipe writer close]
		ifFalse: [aPipe close]] fixTemps forkAt: Processor userInterruptPriority! !

CommandShellTestCase removeSelector: #doPipeline51!
