'From Squeak3.1alpha of 27 September 2001 [latest update: #4347] on 11 March 2002 at 7:32:37 pm'!
"Change Set:		CommandShellV3-0
Date:			10 March 2002
Author:			David T. Lewis

CommandShell 3.0
Previous released version: CommandShell 1.6
Best if used with OSProcess 3.0

CommandShell is a Smalltalk simulation of a Unix command shell, with a
simple dumb terminal window in Morphic and MVC. It is useful for running
programs without leaving Squeak, and for piping command output directly
into Squeak.

CommandShell can be loaded and run on any platform, but is most useful
on Unix, Linux and Windows systems with OSProcess. Windows programs
can be launched from a 'Squeak Shell', although command pipelines with
external Windows programs are not yet possible. MacOS and other platforms
have not been tested.

When running on a Windows platform, CommandShell provides Unix style
command line parsing with DOS device names (C:, D:, etc) to mimic the
normal behavior of a DOS command shell. A set of builtin commands
('cd', 'pwd', 'sls' and 'edit') provide enough functionality to navigate
Windows file systems, list directory contents, and edit files.

On Windows, DOS style device names (such as 'C:') are recognized as part
of the path syntax, and separate current working directory paths are
maintained for each DOS style device. The command '$ cd D:' is interpreted
to mean 'change to the D: device and use its previous working directory
path'. When running on Unix, a single current working directory path is
maintained in the usual manner.

CommandShell provides a simple script processing capability. The
scripting methods are contained in the 'command scripting' category of
class CommandShell.

A script is a String containing a list of zero or more commands delimited
by Character cr. Each command in the list is treated as as a CommandShell
command line. The script commands may consist of a mix of Smalltalk
expressions, shell builtins, and external commands. Simple conditional
branching is supported for commands or scripts based on testing the exit
status of the command lines or scripts.

Try evaluating these expressions:
	CommandShell command: 'help'
	CommandShell open
	CommandShell new command: 'ps -aef | edit'
	CommandShell command: 'ps -aef | edit'
	CommandShell new command: 'ps -aef | edit'
	CommandShell command: 'edit /etc/hosts'
	CommandShell command: 'edit /etc/hosts; exit'
	CommandShell command: 'help | edit'
	CommandShell command: 'ps -aef | edit'
	CommandShell command: 'Time dateAndTimeNow!! | edit; exit'
	CommandShell command: 'Class allSubInstances!! | edit; exit'
	CommandShell command: 'type type | inspect; exit'

Class CommandShell is a command shell, similar to /bin/sh, with a command
line user interface. It collaborates with process proxies to provide command
execution, and provides a limited set of built in commands similar to those in
a Unix shell. Built in commands are implemented in Smalltalk. Simple
Smalltalk expressions, followed by $!!, are evaluated as doIt commands.
All other commands are passed to process proxies to be executed externally.

CommandShell can open a terminal window in either Morphic or MVC.

UnixCommandSyntax implements command line parsing and file name
globbing. This allows direct execution of external commands without use
of an external command shell.

PipeJunction represents an OS process or internal Smalltalk evaluator
connected in a command pipeline. PipeableOSProcess is a subclass which
collaborates with instances of ExternalOSProcess, and PipeableEvaluator
is a subclass to represent Smalltalk evaluation in a command pipeline.

PipeableEvaluator evaluates Smalltalk expressions and provides a framework
for pipelines of expressions combining Smalltalk expressions with external
Unix commands. It behaves similarly to a ConnectedUnixProcess. Both the
shell builtin commands and doIt expression commands are implemented with
PipeableEvaluator.

ShellBuiltin contains the implementations for shell builtin commands.
Instances of ShellBuiltin represent various commands, and may be installed
into an instance of CommandShell with CommandShell>>installCommand:.

CrLfFileEditor is a simple editor which can be used within command pipelines.
The 'edit' shell builtin creates an instance of CrLfFileEditor.

Changes in CommandShell 3.0 since CommandShell 1.6:
- Version number bumped to 3.0 for consistency with OSProcess. The major
  version bump is due to the addition of Windows support in OSProcess.
- Refactored to support OSProcess 3.0. Most importantly, added PipeJunction
  hierarchy with collaboration with ExternalOSProcess instances (replacing
  subclasses of platform specific OS process classes).

Changes in CommandShell 1.6 since CommandShell 1.5:
- Added limited support for Win32 to CommandShell, with correct file and
  path expansion.
- Added new 'sls' internal command to provide a simple directory listing.
- Add support for multiple working directories (one per device) for Windows.
- Renamed UnixCommandSyntax as ShellSyntax, and gave it responsibility
  for maintaining current working directories.
- Isolated platform specific methods in a 'platform specific' method category.
- Added scripting capability for the Squeak shell (see 'command scripting'
  category of class CommandShell).
- Fixed bug in ShellSyntax>>programNameAndArgumentsFrom:inDirectoryPath:
  in which a fully specified path was incorrectly evaluated.
- Added class ShellBuiltin, and moved all built in commands from
  CommandShell to the separate ShellBuiltin class.
- Added CommandShell class>>versionString.

Changes in CommandShell 1.5 since CommandShell 1.4:
- Added some more documentation (CommandShell class>>overview).
- Added direct Smalltalk evaluation to command line processing. Each
  command line is first evaluated as a Smalltalk, with no interpretation
  of shell characters such as $| prior to the evaluation. If this evaluation
  fails (either in the Compiler or at runtime), the command line is assumed
  to be a command pipeline and is subject to shell syntax interpretation
  (including doIt expressions, which may themselves be simple Smalltalk
  expressions). This turns out to work surprisingly well, with very little
  conflict with expected Unix style command interpretation. 
- Fixed various problems with error pipeline handling, and added SUnit
  tests to verify.
- Fixed a problem which allowed some pipeline data to be lost when
  piping very large strings to an editor or an inspector.
- Consolidated some code into #copyAllFrom:to: and improved performance
  for internal pipelines using this method.
- Fixed a bug in output and error redirection from the last process in
  a pipeline, where the last process is an internal command. For
  example, '$ who | copyToOutput > b' generated an error. Added SUnit
  tests to catch this condition.

Changes in CommandShell 1.4 since CommandShell 1.3:
- Fixes a timing problem for CommandShell pipelines running in MVC.
  Symptom: A command line such as '$ ls | edit' or '$ ls | inspect' did
  not work in an MVC shell window (Morphic was OK). The editor
  or inspector window would open and display an empty string.
  Cause: In MVC, the 'edit' and 'inspect' builtin commands scheduled
  an editor or inspector window to be opened at a later time using
  #addDeferredUIMessage:, and then cheerfully went on to close the
  input pipe for the command prior to the deferred action being
  executed.
  Fix: in a command pipeline, input to the 'edit' and 'inspect'
  shell builtin commands is now read completely prior to scheduling
  the editor or inspector window and closing the input pipe.
- Fixes a harmless but unappealing buglet in which the last proxy in
  a command pipeline was sent the #value message twice.
- Adds better error pipeline handling for command windows. Prior to
  this change, a command which generated a large amount our error
  output would clog up the pipes and cause the command window to
  hang up. I ran into the problem when running running configure
  and make to build a VM with VMMaker.
- Use deferred UI events in Morphic to eliminate intermittent red screen
  of death on '$ edit someBigFile' command.
- Fixed search for executable path in UnixCommandSyntax to properly
  handle the curent directory '.' in the PATH list.
- Added a #startUp handler to eliminate leftover Smalltalk processes
  after an image restart. The problem arose when a CommandShell
  ran an external program in background mode with a Smalltalk
  process waiting for the external program to exit. After an
  image restart, there was no way to be notified when the external
  process exited, so the Smalltalk process was left dangling forever.""!

WriteStream subclass: #CommandShell
	instanceVariableNames: 'shellSyntax environment builtinCommands commandHistory historyIndex keyboardConnector allMyChildren activeController readSyncSemaphore commandLineProcesses stProcesses timeWasterProcess '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!CommandShell commentStamp: '<historical>' prior: 0!
I am a command shell, similar to /bin/sh, with a simple command line user interface. I collaborate with process proxies to provide command execution, and I provide a limited set of built in commands similar to those in /bin/sh. My built in commands are implemented in Smalltalk, and any other commands are passed to process proxies to be executed either internally as Smalltalk "doIt" expressions, or externally as commands passed to the external operating system. I am similar to a TranscriptStream (some methods are copied directly from TranscriptStream), but I also know how to accept lines of command input, parse them, and hand them off to process proxies for execution.

Three types of commands may be executed from a CommandShell: internal "builtin" commands implemented in Smalltalk; internal Smalltalk "doIt" commands; and external commands. Internal commands (builtin commands or doIt commands) may be freely mixed with external operating system commands in a command pipeline. See CommandShell class>>commandProcessing for more information.

Each command line is first evaluated as a Smalltalk expression, and is subject to further parsing only if the Smalltalk evaluation fails. In practice, this permits complete Smalltalk expressions to be evaluated easily without conflicting with shell syntax, and allows Smalltalk and unix shell commands to be freely mixed.

Simple command scripting is supported (method category 'command scripting'). Any mix of internal and external commands may be included in a script. Conditional branching is supported based on command exit status.

Open a new shell window with "CommandShell open". Type 'help' followed by <return> or <enter> for help on builtin commands.

Things that work reasonably well:
- Simple command execution for running command line programs or starting
  X programs.
- Command pipelines. Built in commands can be mixed with external
  commands, as in "help sqsh | wc -l".
- Command IO redirection with '<',  '>', '>>', '2>', and '2>>'.
- Command history and command history recall.
- Background command execution, as in "xterm&".
- <ctl-C> to interrupt a running external command.
- <ctl-D> to indicate end of file in terminal input.

Limitations include:
- Dumb tty only. Do not try to run vi.
- Standard Unix shell syntax is not completely implemented.

Race conditions are possible for certain command pipelines. See CommandShell class>>raceConditions for more information.
!

CommandShell class
	instanceVariableNames: ''!
StringHolder subclass: #CrLfFileEditor
	instanceVariableNames: 'lineEndConvention directory fileName viewStyle '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!CrLfFileEditor commentStamp: '<historical>' prior: 0!
I provide an editor on a single file. I attempt to avoid changing the line termination character convention when writing my text back to a file.

Bug: On older Squeak systems which do not support FilesStream>>truncate, file permissions may be lost when a file is rewritten at a shorter length.
!

CrLfFileEditor class
	instanceVariableNames: ''!
Stream subclass: #InternalPipe
	instanceVariableNames: 'queue writerClosed nonBlockingMode '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!InternalPipe commentStamp: '<historical>' prior: 0!
I am a first-in, first-out queue with streaming behavior. I behave similarly to an OSPipe,
but am implemented in the Smalltalk image rather than with external OS pipes. I can
behave either as a blocking pipe or as a nonblocking pipe, similar to an OS pipe with
its reader end set in blocking or nonblocking mode.!

InternalPipe class
	instanceVariableNames: ''!
Object subclass: #PipeJunction
	instanceVariableNames: 'pipeToInput pipeFromOutput errorPipelineStream '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!PipeJunction commentStamp: '<historical>' prior: 0!
I am a connector junction for input, output, and error pipelines. I obtain input from an input pipeline and, after possibly performing some kind of operation on the input objects, I send output to an output pipeline. I may also append objects onto an error pipeline.

My subclasses implement the operations on the objects which pass through a pipe junction.

In general, input pipes are connected to output pipes in a serial fashion, and error pipelines are shared by one or more instances of my subclasses.
!

PipeJunction subclass: #PipeableEvaluator
	instanceVariableNames: 'runState expression evaluationBlock extraArguments needsPrompt exitStatus outputHasBeenRedirected '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!PipeableEvaluator commentStamp: '<historical>' prior: 0!
I evaluate Smalltalk expressions taken from my pipeToInput, and print the results of the evaluation on my pipeFromOutput. I may append error messages to my errorPipelineStream. I provide a framework for pipelines of expressions, possibly combined in the same pipeline with ExternalOSProcess proxies executing external operating system commands.

My evaluationBlock may be supplied directly, or can be compiled from an expression string. If compiled from an expression string, the names 'stdin', 'stdout', 'stderr', and 'args' are used to refer to the input stream, output stream, error stream, and an array of arguments. If any of these names are used in the expression string, then the evaluation block will be compiled in such as way as to connect these names with their corresponding streams or argument array.
!

PipeableEvaluator class
	instanceVariableNames: ''!
PipeJunction subclass: #PipeableOSProcess
	instanceVariableNames: 'processProxy pipeFromError closeOutputOnExit keepInitialStdErrOpen accessProtect '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!PipeableOSProcess commentStamp: '<historical>' prior: 0!
I am a connector junction for input, output, and error pipelines. I collaborate with a process proxy to evaluate an internal or external process, and to move objects through the pipelines as the proxy is evaluated.

From Smalltalk, you can write to my pipeToInput, and read from my pipeFromOutput and pipeFromError streams. I implement simple streaming protocol as a convenience for reading and writing these pipe streams. I support command pipelines with the #| message, with the pipeFromOutput of one instance connected to the pipeToInput of the next instance, and a shared errorPipelineStream collecting error output text for the command pipeline.

All reading and writing should be done with the streaming protocol, rather than by direct access to the pipe streams. This is because the output pipe streams may be silently replaced by simple ReadStreams following the exit of the child process.

Normal exit for the external process may not happen when expected. If the process is writing to the output pipe, it may block on write until enough of its data is read from the pipeFromOutput pipe, after which it will exit normally.!

PipeableOSProcess class
	instanceVariableNames: ''!
Object subclass: #ShellBuiltin
	instanceVariableNames: 'name procedureSelector helpSelector needsPrompt '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!ShellBuiltin commentStamp: '<historical>' prior: 0!
A shell builtin command, intended to be invoked by a CommandShell.

A builtin command consists of:
 name - a String identifier, used by the CommandShell to identify and invoke the commmand.
 helpString - a String to describe the function of the command.
 procedure - a BlockContext with parameters to be passed by the CommandShell.

Commands are implemented in class methods. To create a new command, write a new
command implementation method and a corresponding instance creation method patterned
after one of the existing commands, and install the instance creation method in an
instance of CommandShell with CommandShell>>installCommand:.!

ShellBuiltin class
	instanceVariableNames: ''!
Object subclass: #ShellSyntax
	instanceVariableNames: 'cwdDictionary cwdIndex '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!ShellSyntax commentStamp: '<historical>' prior: 0!
My instances implement parsing of strings in a manner similar to a simple Unix command shell. I provide path name expansion in the context of an external file system, and support the syntax required for IO redirection. All file name globbing and PATH searching are implemented in Smalltalk rather than in C library functions or an external command shell.

Most of my syntax is applicable for any operating system. Where needed, platform specific methods are in my "platform dependent" category. Currently, Unix and Windows are supported, and other platforms have not been testing. The primary difference between Unix and Windows support is that device names (such as 'C:') are used in Windows path strings. Separate current working directory strings are maintained for all Windows device names. For Unix, a single current working directory path is used. On Windows, this permits the CommandShell 'cd' command to support changing directories to another device without losing track of the current working directory for the previous device.

Command pipeline syntax is not supported here. See CommandShell for the implementation of command pipelines.
!

PluggableTextMorph subclass: #ShellWindowMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!ShellWindowMorph commentStamp: '<historical>' prior: 0!
I am a simple teletype shell session morph, providing a view on an instance of CommandShell.!

ShellWindowMorph class
	instanceVariableNames: ''!
PluggableTextView subclass: #ShellWindowView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!ShellWindowView commentStamp: '<historical>' prior: 0!
I am a simple teletype shell session view, providing a view on an instance of CommandShell.!

PluggableTextController subclass: #TtyPluggableTextController
	instanceVariableNames: 'acceptOnCr callbackQueue closed readSyncSemaphore '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!TtyPluggableTextController commentStamp: '<historical>' prior: 0!
I add keyboard hooks to a PluggableTextController to allow filtering of keystrokes for a simple tty terminal emulator.!

TextMorphForEditView subclass: #TtyTextMorphForEditView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OSProcess-CommandShell'!

!TtyTextMorphForEditView commentStamp: '<historical>' prior: 0!
I add a keyboard hook to a TextMorphForEditView to allow filtering of keystrokes for a simple tty terminal emulator.!


!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/2/2001 12:05'!
clearSemaphore

	[self readSyncSemaphore isEmpty] whileFalse: [readSyncSemaphore terminateProcess].
	readSyncSemaphore signal
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/27/2001 01:16'!
initialize

	self installCommands
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/27/2001 12:24'!
installCommand: aShellBuiltin

	self builtinCommands at: aShellBuiltin name put: aShellBuiltin! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/27/2001 10:26'!
installCommands

	self installCommand: (ShellBuiltin cd: self).
	self installCommand: (ShellBuiltin clear: self).
	self installCommand: (ShellBuiltin copyToError: self).
	self installCommand: (ShellBuiltin copyToOutput: self).
	self installCommand: (ShellBuiltin edit: self).
	self installCommand: (ShellBuiltin exit: self).
	self installCommand: (ShellBuiltin fc: self).
	self installCommand: (ShellBuiltin help: self).
	self installCommand: (ShellBuiltin history: self).
	self installCommand: (ShellBuiltin inspect: self).
	self installCommand: (ShellBuiltin pwd: self).
	self installCommand: (ShellBuiltin sls: self).
	self installCommand: (ShellBuiltin sqsh: self).
	self installCommand: (ShellBuiltin type: self).
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 4/2/2001 22:43'!
open

	^ self openLabel: self class defaultWindowName! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 7/2/2001 21:57'!
openAsMorphLabel: labelString 
	"Build a morph viewing this stream"

	| window textMorph |
	window _ (SystemWindow labelled: labelString) model: self.
	textMorph _ ShellWindowMorph
					on: self
					text: nil
					accept: nil
					readSelection: nil
					menu: #codePaneMenu:shifted:.
	textMorph acceptOnCR: true.
	window addMorph: textMorph frame: (0@0 corner: 1@1).
	self prompt.
	self changed: #relabel.
	^ window! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/22/2001 11:27'!
openLabel: aString 
	"Open a window on this stream. This is copied from the corresponding method in
	TranscriptStream."

	| topView codeView |
	Smalltalk isMorphic ifTrue: [^ (self openAsMorphLabel: aString) openInWorld].

	topView _ StandardSystemView new.
	topView model: self;
			controller: DeferredActionStandardSystemController new;
			borderWidth: 1;
			label: aString;
			minimumSize: 100 @ 50.
	codeView _ ShellWindowView
					on: self
					text: nil
					accept: nil
					readSelection: nil
					menu: #codePaneMenu:shifted:.
	codeView window: (0@0 extent: 200@200).
	topView addSubView: codeView.
	topView controller addDeferredUIMessage: [self changed: #relabel].
	topView controller open
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 7/2/2001 21:58'!
openLabel: aString command: commandString
	"Open a window on this stream. This is copied from the corresponding method in
	TranscriptStream."

	"CommandShell new openLabel: self defaultWindowName command: 'help'"

	| topView codeView m |
	Smalltalk isMorphic
		ifTrue:
			[m _ (self openAsMorphLabel: aString) openInWorld.
			m model command: commandString.
			^m].

	topView _ StandardSystemView new.
	topView model: self;
			controller: DeferredActionStandardSystemController new;
			borderWidth: 1;
			label: aString;
			minimumSize: 100 @ 50.
	codeView _ ShellWindowView
					on: self
					text: nil
					accept: nil
					readSelection: nil
					menu: #codePaneMenu:shifted:.
	codeView window: (0@0 extent: 200@200).
	topView addSubView: codeView.
	self activeController: topView controller.
	topView controller addDeferredUIMessage: [self changed: #relabel].
	topView controller addDeferredUIMessage: [self command: commandString] fixTemps.
	topView controller open
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 12/2/2001 11:29'!
release

	self terminateStProcesses.
	self terminateCommandLineProcesses.
	self clearSemaphore.
	^ super release! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 9/26/2001 22:22'!
terminateCommandLineProcesses
	"Terminate all but the currently active process"

	(self commandLineProcesses reject: [:e | e == Processor activeProcess])
		do: [:p | p terminate].
	commandLineProcesses _ nil
! !

!CommandShell methodsFor: 'initialize-release' stamp: 'dtl 9/26/2001 21:41'!
terminateStProcesses
	"Terminate all but the currently active process"

	(self stProcesses reject: [:e | e == Processor activeProcess])
		do: [:p | p terminate].
	stProcesses _ nil
! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/23/2001 17:20'!
command: aCommandString
	"Evaluate aCommandString. This is similar to #doCommandsInString, except
	that the evaluation is done in the current process. When all processing is
	complete, answer the last process proxy in the command pipeline, or nil if
	nothing was done."

	"CommandShell new command: 'ls -l | cat'"
	"CommandShell new open; command: 'ls -l | cat'"
	"CommandShell new open; command: 'who'"

	| lastProcess |
	(self isOneWordCommentString: aCommandString)
		ifTrue: "Ignore trivial case of a single word starting with $#"
			[self cr; prompt; flush.
			[^ nil]]
		ifFalse:
			[self show: aCommandString.
			lastProcess _ self tryEvaluatingAsSmalltalk: aCommandString.
			(lastProcess exitStatus == #success)
				ifTrue: "aCommandString was successfully evaluated as a Smalltalk expression"
					[self saveInHistoryList: aCommandString.
					self cr.
					self processOutput: lastProcess count: nil.
					self processError: lastProcess count: nil.
					self prompt; flush]
				ifFalse: "Treat aCommandString as a command pipeline"
					[lastProcess _ self doCommandsInString: aCommandString
									ifTrue: [self prompt; flush]]].
	^ lastProcess
! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/22/2001 19:06'!
command: aCommandString onFailureDo: aBlockWithOneParameter
	"Evaluate aCommandString. On failure, answer the result of evaluating
	aBlockWithOneParameter with the last proxy to have been evaluated as
	its parameter. Otherwise, answer the last process proxy to have been
	evaluated."

	"CommandShell new open;
		command: 'who'
		onFailureDo: [:p | 'the proxy which failed was ', p printString]"

	"CommandShell new open;
		command: 'ls NOSUCHFILE'
		onFailureDo: [:p | 'the proxy which failed was ', p printString]"

	| lastProxy |
	lastProxy _ self command: aCommandString.
	lastProxy succeeded ifFalse: [^ aBlockWithOneParameter value: lastProxy].
	^ lastProxy

! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/23/2001 17:26'!
if: aCommandStringOrScript then: successBlock else: failureBlock
	"Evaluate aCommandStringOrScript, then evaluate successBlock or failureBlock
	depending on the exit status of the command or script."

	"CommandShell new open;
		if: 'who'
		then: ['the command succeeded']
		else: ['the command failed']"

	"CommandShell new open;
		if: 'who
			ls NOSUCHFILE
			pwd'
		then: ['the script succeeded']
		else: ['the script failed']"

	(self script: aCommandStringOrScript) succeeded
		ifTrue: [^ successBlock value]
		ifFalse: [^ failureBlock value]


! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/23/2001 17:08'!
script: aScriptString
	"A script is a String containing a list of commands separated by Character cr.
	Evaluate each command string in the array until a failure is encountered.
	Answer the last process proxy to have been evaluated."

	"CommandShell new open; 
		script: 'who
				help
				ls -l NOSUCHFILE
				help'"

	^ self script: aScriptString onFailureDo: [:p | p]

! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/23/2001 17:23'!
script: aScriptString onFailureDo: aBlockWithOneParameter
	"A script is a String containing a list of commands separated by Character cr.
	Evaluate each command in aScriptString until a failure is encountered.
	On failure, answer the result of evaluating aBlockWithOneParameter with
	the last proxy to have been evaluated as its parameter. Otherwise, answer the
	last process proxy to have been evaluated."

	"CommandShell new open; 
		script: 'who
				help
				ls -l NOSUCHFILE
				help'
		onFailureDo: [:p | 'the proxy which failed was ', p printString]"

	| commandStream lastProxy |
	commandStream _ ReadStream on:
						(aScriptString
							copyReplaceAll: Character lf asString
							with: Character cr asString).
	[commandStream atEnd]
		whileFalse:
			[lastProxy _ self command: commandStream nextLine.
			(lastProxy notNil and: [lastProxy succeeded not])
				ifTrue:
					[^ aBlockWithOneParameter value: lastProxy]].
	^ lastProxy

! !

!CommandShell methodsFor: 'command scripting' stamp: 'dtl 12/24/2001 09:07'!
scriptDoAll: aScriptString
	"A script is a String containing a list of commands separated by Character cr.
	Evaluate each command in aScriptString. Ignore failures and force evaluation of
	all commands in the script. Answer the last process proxy to have been evaluated."

	"CommandShell new open; 
		scriptDoAll: 'who
				help
				ls -l NOSUCHFILE
				help'"

	| commandStream lastProxy |
	commandStream _ ReadStream on:
						(aScriptString
							copyReplaceAll: Character lf asString
							with: Character cr asString).
	[commandStream atEnd]
		whileFalse:
			[lastProxy _ self command: commandStream nextLine].
	^ lastProxy

! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 6/24/2001 19:09'!
activeController
	"In Morphic, alway nil. In MVC, the controller which most recently invoked
	a command."

	^ activeController! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 6/24/2001 19:09'!
activeController: aController
	"In Morphic, alway nil. In MVC, the controller which most recently invoked
	a command."

	activeController _ aController! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 4/28/2001 09:20'!
allMyChildren

	allMyChildren ifNil: [allMyChildren _ OrderedCollection new].
	^ allMyChildren! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 12/27/2001 12:24'!
builtinCommands

	^ builtinCommands ifNil: [builtinCommands _ Dictionary new]! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 3/16/2001 05:58'!
characterLimit
	"Tell the views how much to retain on screen"
	^ 20000! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 4/7/2001 12:48'!
commandHistory
	"Automatically trim the history list, and answer the resulting list."

	| trimIncrement |
	trimIncrement _ 1.	"Could be a larger number to copy the collection less often"
	commandHistory isNil
		ifTrue:
			[commandHistory _ OrderedCollection new]
		ifFalse:
			[(commandHistory size > (self historyDepth * 2 + (trimIncrement * 2) - 2))
				ifTrue:
					[commandHistory _ commandHistory
						copyFrom: (trimIncrement * 2 + 1) to: commandHistory size]].
	^ commandHistory! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 9/26/2001 22:19'!
commandLineProcesses
	"The Smalltalk processes associated with currently executing command lines. Keep
	track of them here so that they can be conveniently terminated if something gets
	out of whack and needs cleaning up."

	commandLineProcesses ifNil: [commandLineProcesses _ Set new].
	^ commandLineProcesses
! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 12/15/2001 10:54'!
environment

	environment ifNil:
		[(Smalltalk hasClassNamed: 'OSProcess')
			ifTrue: [environment _ OSProcess thisOSProcess environment deepCopy]].
	^ environment! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 7/28/2001 14:54'!
externalChildren

	^ self allMyChildren select: [:p | p isExternalProcess]
! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 4/3/2001 22:48'!
historyIndex

	historyIndex ifNil: [historyIndex _ 1].
	^ historyIndex
! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 4/22/2001 18:49'!
keyboardConnector
	"If nil, then my views should behave normally. If a WriteStream, then my
	views should attempt to forward all keyboard inputs to the WriteStream.
	This is to permit the keyboard to be connected to an externally executing
	process, then reconnected to its normal functions when the external process
	is complete."


	^ keyboardConnector! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 4/22/2001 18:56'!
keyboardConnector: aWriteStreamOrNil
	"If nil, then my views should behave normally. If a WriteStream, then my
	views should attempt to forward all keyboard inputs to the WriteStream.
	This is to permit the keyboard to be connected to an externally executing
	process, then reconnected to its normal functions when the external process
	is complete."

	keyboardConnector _ aWriteStreamOrNil
! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 6/25/2001 23:07'!
readSyncSemaphore
	"Used in MVC to pause the screen output when presenting a dialogue to the user"

	readSyncSemaphore ifNil: [readSyncSemaphore _ Semaphore forMutualExclusion].
	^ readSyncSemaphore! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 6/25/2001 20:34'!
readSyncSemaphore: aSemaphore
	"Used in MVC to pause the screen output when presenting a dialogue to the user"

	readSyncSemaphore _ aSemaphore! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 12/17/2001 11:34'!
shellSyntax
	"A pluggable instance of a command processing syntax"

	^ shellSyntax ifNil: [shellSyntax _ ShellSyntax new]! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 9/8/2001 11:10'!
shellSyntax: aSyntax
	"A pluggable instance of a command processing syntax"

	shellSyntax _ aSyntax! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 9/30/2001 00:00'!
stProcesses
	"The Smalltalk processes associated with process proxies."

	stProcesses ifNil: [stProcesses _ OrderedCollection new].
	^ stProcesses
! !

!CommandShell methodsFor: 'accessing' stamp: 'dtl 10/27/2001 14:00'!
timeWasterProcess

	^ timeWasterProcess! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 3/9/2002 14:57'!
builtinCommandProxyFor: aCommandString input: inputStream output: outputStream error: errorStream
	"Answer a PipeableEvaluator on a built in command, or nil."

	"CommandShell new initialize builtinCommandProxyFor: 'help' input: nil output: nil error: nil"

	| tokens args c commandBlock proxy |
	^ (self isBuiltInCommand: aCommandString)
		ifTrue:
			[tokens _ aCommandString findTokens: ' '.
			tokens size == 0 ifTrue: [self error: 'expected one or more tokens'].
			args _ (tokens copyFrom: 2 to: tokens size) asArray.
			c _ self builtinCommands at: tokens first.
			"The command proxy will pass arguments to commandBlock at runtime"
			commandBlock _
				[:input :output :error :arguments |
				c class perform: c procedureSelector
					withArguments: (Array
						with: self
						with: input
						with: output
						with: error
						with: arguments)].
			proxy _ (self expressionEvaluatorClass
							block: commandBlock
							pipeFrom: inputStream
							pipeTo: outputStream
							errorPipelineStream: errorStream
							withArgs: args).
			proxy needsPrompt: c needsPrompt.
			^ proxy]
		ifFalse: [nil]
! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 11/25/2001 22:35'!
doItProxyFor: aCommandString input: inputStream output: outputStream error: errorStream
	"Answer a PipeableEvaluator on a doIt command, or nil."

	"CommandShell new doItProxyFor: '#thisIsADoIt !! ' input: nil output: nil error: nil"

	^ (self isDoItCommand: aCommandString)
		ifTrue: [self evaluationProxyFor: (self doItStringFrom: aCommandString)
					input: inputStream
					output: outputStream
					error: errorStream]
! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 11/25/2001 22:26'!
evaluationProxyFor: aCommandString input: inputStream output: outputStream error: errorStream
	"Answer a PipeableEvaluator on a doIt command, or nil."

	"CommandShell new evaluationProxyFor: 'Smalltalk' input: nil output: nil error: nil"
	"CommandShell new evaluationProxyFor: 'BOGUS' input: nil output: nil error: nil"

	| proxy |
	proxy _ self expressionEvaluatorClass
							command: aCommandString
							pipeFrom: inputStream
							pipeTo: outputStream
							errorPipelineStream: errorStream.
	proxy needsPrompt: true.
	^ proxy
! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 11/25/2001 22:34'!
pipeableProxyFor: aCommandString input: inputStream output: outputStream error: errorStream predecessorProxy: lastProxy
	"Answer a proxy for an external OS process, or for an internal builtin command,
	or for an evaluation string. The proxy is suitable for use in a command pipeline,
	possibly mixing internal and external commands."

	"(CommandShell new pipeableProxyFor: '#''this is a doIt'' !! ' input: nil output: nil error: nil predecessorProxy: nil) value upToEnd"
	"(CommandShell new pipeableProxyFor: 'help' input: nil output: nil error: nil predecessorProxy: nil) value upToEnd"
	"(CommandShell new pipeableProxyFor: 'cat /etc/hosts' input: nil output: nil error: nil predecessorProxy: nil) value upToEnd"

	| errorPipelineStream |
	errorPipelineStream _ lastProxy ifNotNil: [lastProxy errorPipelineStream].
	^ ((self doItProxyFor: aCommandString
			input: inputStream
			output: outputStream
			error: (errorStream ifNil: [errorPipelineStream]))
		ifNil: [self builtinCommandProxyFor: aCommandString
				input: inputStream
				output: outputStream
				error: (errorStream ifNil: [errorPipelineStream])])
			ifNil: [self processProxyFor: aCommandString
					input: inputStream
					output: outputStream
					error: errorStream
					predecessorProxy: lastProxy]
! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 10/20/2001 12:19'!
processProxyFor: aCommandString input: inputStream output: outputStream error: errorStream predecessorProxy: lastProxy
	"Answer a proxy for an external OS command process."

	"CommandShell new processProxyFor: '/bin/sh' input: nil output: nil error: nil predecessorProxy: nil"

	| input newInputPipe errorPipelineStream p |
	((Smalltalk hasClassNamed: #OSProcess) and: [OSProcess accessor canAccessSystem])
		ifFalse:
			["Answer a doIt proxy with an error message. Call it this way to make sure that
			the error streams get wired up correctly"
			p _ self pipeableProxyFor: 'String new: 0 !! '
					input: inputStream
					output: outputStream
					error: errorStream
					predecessorProxy: lastProxy.
			p errorPipelineStream nextPutAll:
				'cannot access system to run ''', aCommandString, '''', Character cr asString.
			^ p].
	((inputStream isNil or: [lastProxy isNil]) or: [inputStream isKindOf: FileStream])
		ifTrue:
			[input _ inputStream]
		ifFalse:
			["Input from a command pipeline"
			(inputStream isKindOf: OSPipe)
				ifTrue:
					[input _ inputStream reader]
				ifFalse:
					["The inputStream is not an OS pipe. Need to create one, and move
					the contents of inputStream into the new OSPipe prior to starting
					the external OS process."
					newInputPipe _ OSPipe blockingPipe.
					lastProxy replaceOutputStreamWith: newInputPipe writer.
					input _ newInputPipe reader]].
	"If the input stream is nil, provide an OSPipe and close the writer end. If this is not
	done, the default behavior will be to provide an OSPipe with the input still open,
	which could lead to the external command waiting indefinitely for input."
	input ifNil:
		[newInputPipe _ OSPipe blockingPipe.
		newInputPipe writer close.
		input _ newInputPipe reader].
	errorPipelineStream _ lastProxy ifNotNil: [lastProxy errorPipelineStream].
	^ self commandProcessorClass
		commandNoEvaluate: aCommandString
		environment: self environment
		workingDir: self workingDirectory
		input: input
		output: outputStream
		error: errorStream
		errorPipelineStream: errorPipelineStream
		shellSyntax: self shellSyntax
! !

!CommandShell methodsFor: 'process proxy creation' stamp: 'dtl 3/9/2002 19:54'!
redirectedPipeableProxyFor: aCommandString predecessorProxy: lastProxy
	"Answer a proxy for an external OS process, or for an internal builtin command,
	or for an evaluation string. The proxy is suitable for use in a command pipeline,
	possibly mixing internal and external commands."

	"(CommandShell new redirectedPipeableProxyFor: '#''this is a doIt'' !! '
							predecessorProxy: nil) value upToEnd"
	"(CommandShell new redirectedPipeableProxyFor: 'help'
							predecessorProxy: nil) value upToEnd"
	"(CommandShell new redirectedPipeableProxyFor: 'cat /etc/hosts'
							predecessorProxy: nil) value upToEnd"

	| redirectedCommand nextProxy input |
	redirectedCommand _ self shellSyntax
								redirectIOFor: aCommandString
								inDirectoryPath: self workingDirectory.
	lastProxy isNil
		ifTrue:
			[input _ redirectedCommand at: 2]
		ifFalse:
			[(redirectedCommand at: 2) isNil
				ifTrue:
					[input _ lastProxy outputPipeForNextProxy]
				ifFalse:
					[lastProxy replaceOutputStreamWith: nil.
					input _ redirectedCommand at: 2]].
	nextProxy _ self pipeableProxyFor: (redirectedCommand at: 1)
		input: input
		output: (redirectedCommand at: 3)
		error: (redirectedCommand at: 4)
		predecessorProxy: lastProxy.
	^ nextProxy
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 11/17/2001 08:43'!
background: aProxy
	"Run aProxy, and write output and error without waiting for command completion.
	Restore the command prompt if background process has written anything."

	| sema hist |
	sema _ Semaphore new.
	hist _ (self historyIndex - 1) printString.
	self nextPutAll: '[', hist, '] '.
	(aProxy respondsTo: #pid)
		ifTrue:
			[aProxy pid printOn: self.
			self nextPut: Character space].
	self cr.
	self stProcesses add:
		([self runProxy: aProxy signaling: sema.
		self stProcesses
				remove: Processor activeProcess
				ifAbsent: []] forkAt: Processor userBackgroundPriority).
	self stProcesses add:
		[sema wait.
		self nextPutAll: '[', hist, ']+ Done '.
		(aProxy respondsTo: #programName)
			ifTrue: [self nextPutAll: '			',
						(FileDirectory default localNameFor: aProxy programName),
						' '].
		self cr.
		self restorePrompt.
		self stProcesses
			remove: Processor activeProcess
			ifAbsent: []] fork.
	^ aProxy
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 11/27/2001 00:16'!
doCommandsInString: aCommandString
	"Process all the commands in aCommandString and issue a new command
	prompt based on the result of the evaluation. All of the processing runs in
	a separate Smalltalk process to prevent blocking the user interface. In MVC,
	schedule the prompt to be displayed during the control loop of aController.
	Keep track of the forked process in while it is running."

	| process |
	(self isOneWordCommentString: aCommandString)
		ifTrue: "Ignore trivial case of a single word starting with $#"
			[self cr; prompt; flush]
		ifFalse:
			[process _ self tryEvaluatingAsSmalltalk: aCommandString.
			(process exitStatus == #success)
				ifTrue: "aCommandString was successfully evaluated as a Smalltalk expression"
					[self saveInHistoryList: aCommandString.
					self cr.
					self processOutput: process count: nil.
					self processError: process count: nil.
					self prompt; flush]
				ifFalse: "Treat aCommandString as a command pipeline"
					[process _
						[self doCommandsInString: aCommandString ifTrue: [self prompt; flush].
						self commandLineProcesses
								remove: Processor activeProcess
								ifAbsent: []] fixTemps fork.
			self commandLineProcesses add: process]]
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 3/9/2002 19:54'!
doCommandsInString: aCommandString ifTrue: aBlock
	"Process all the commands in aCommandString, then conditionally evaluate aBlock.
	Answer the last proxy in the pipeline of process proxies."

	| str tokens strm cmd cmdWithTerm detach proxies childSemaphore doIt lastProxy |
	str _ aCommandString withBlanksTrimmed.
	doIt _ false.
	self cr; flush.
	(self shellSyntax isComment: str)
		ifTrue:
			[doIt _ true]
		ifFalse:
			[tokens _ str findTokens: ';&' keep: ';&'.
			strm _ ReadStream on: tokens.
			[strm atEnd]
				whileFalse:
					[cmd _ strm next withBlanksTrimmed.
					(self shellSyntax isComment: cmd)
						ifFalse:
							[strm atEnd
								ifTrue:
									[((cmd size == 1) and: [((cmd at: 1) == $;) | ((cmd at: 1) == $&)])
										ifTrue:
											["Special case, user has entered ';<cr>' or '&<cr>'"
											cmd _ cmdWithTerm _ '']
										ifFalse:
											[cmdWithTerm _ cmd]]
								ifFalse:
									[cmdWithTerm _ cmd, strm peek].
							self saveInHistoryList: cmdWithTerm.
							(cmdWithTerm size > 0)
								ifTrue:
									[detach _ (strm next = self noWaitToken).
									proxies _ self pipeline: cmd.
									lastProxy _ proxies last.
									lastProxy isNil
										ifTrue:
											[self show: 'cannot access system'; cr.
											^ self].
									lastProxy outputPipeForNextProxy
										ifNotNil:
											[lastProxy setNonBlockingOutput].
									self allMyChildren addAll: proxies.
									detach
										ifTrue:
											[self background: lastProxy]
										ifFalse:
											[childSemaphore _ Semaphore new.
											"Connect stdin from keyboard to the external process."
											self keyboardConnector: proxies first pipeToInput.
											self foreground: lastProxy
												signaling: childSemaphore.
											childSemaphore wait.
											self keyboardConnector: nil].
									doIt _ lastProxy needsPrompt.
									lastProxy errorPipelineStream close.
									self allMyChildren removeAll: proxies]]]].
	doIt ifTrue: [aBlock value].
	^ lastProxy
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 9/10/2001 20:02'!
foreground: aProxy signaling: aSemaphore
	"Evaluate aProxy, write output and error, and signal aSemaphore when
	complete. The semaphore can be used to determine when a new command
	line prompt may be issued."

	^ self runProxy: aProxy signaling: aSemaphore! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 2/7/2002 08:12'!
pipeProxy: aCommandProxy toCommand: aCommand
	"Find the individual commands in a command pipeline string, and execute
	them as a command pipeline with aCommandProxy as the first member of
	the pipeline of proxies. Answer a collection of processes in the pipeline."

	^ self pipeProxy: aCommandProxy toCommandList: (self splitPipelineCommands: aCommand)
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 2/7/2002 08:04'!
pipeProxy: aCommandProxy toCommandList: anArrayOfCommandStrings
	"Using the individual commands in a command pipeline string, execute them
	as a command pipeline. Each process proxy in the pipeline (except the last)
	runs in a separate Smalltalk process. In most cases, this has no impact on
	the behavior of the command pipeline; however, if one or more of the proxies
	is an internal PipeableEvaluator, this permits the internal proxy to explicitly
	yield the processor and avoid possible IO race conditions.
	Answer a collection of processes in the pipeline."

	| processes nextProxy |
	processes _ OrderedCollection new.
	processes add: aCommandProxy.
	anArrayOfCommandStrings
			inject: aCommandProxy
			into: [:prev :next | prev isNil ifFalse:
					[prev prepareOutputForPipe.
					nextProxy _ self redirectedPipeableProxyFor: next predecessorProxy: prev.
					processes add: nextProxy.
					self stProcesses add:
						[prev value.
						self stProcesses remove: Processor activeProcess ifAbsent: []] fixTemps fork.
					Processor yield.
					nextProxy]].
	processes last value.
	^ processes
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 2/7/2002 22:14'!
pipeline: aCommand
	"Find the individual commands in a command pipeline string, and execute them
	as a command pipeline. Each process proxy in the pipeline (except the last)
	runs in a separate Smalltalk process. In most cases, this has no impact on
	the behavior of the command pipeline; however, if one or more of the proxies
	is an internal PipeableEvaluator, this permits the internal proxy to explicitly
	yield the processor and avoid possible IO race conditions.
	Answer a collection of processes in the pipeline."

	| commands firstProxy |
	commands _ self splitPipelineCommands: aCommand.
	firstProxy _ self redirectedPipeableProxyFor: commands first predecessorProxy: nil.
	^ self pipeProxy: firstProxy toCommandList: (commands copyAfter: commands first)

	"(CommandShell new pipeline: 'ps') last output"
	"(CommandShell new pipeline: 'ps | grep ps | wc') last output"

	"The following examples will only work in Morphic"
	"CommandShell new doCommandsInString: 'who | edit'"
	"CommandShell new doCommandsInString: 'who | wc | edit'"
	"CommandShell new doCommandsInString: 'who | cat | dd | cat | dd | edit'"
	"CommandShell new doCommandsInString: 'who | stdout nextPutAll: stdin upToEnd!! | edit'"
	"CommandShell new doCommandsInString: 'help | edit'"
	"CommandShell new doCommandsInString: 'help | cat | edit'"
	"CommandShell new doCommandsInString: 'help | stdout nextPutAll: stdin upToEnd!! | cat | edit'"
	"CommandShell new doCommandsInString: 'stdout nextPutAll: ''Hello world!!'' !! | edit'"
	"CommandShell new doCommandsInString:
		'stdout nextPutAll: ''Hello world!!'' !! | copyToOutput | edit'"
	"CommandShell new doCommandsInString: 'stdout nextPutAll: ''Hello world!!'' !! | cat | edit'"
	"CommandShell new doCommandsInString:
		'stdout nextPutAll: ''Hello world!!'' !! | cat | copyToOutput | dd | cat | edit'"
	"CommandShell new doCommandsInString: 'help > /tmp/delete.me | edit'"
	"CommandShell new doCommandsInString: 'help | cat < /etc/hosts | edit'"
	"CommandShell new doCommandsInString: 'cat < /etc/hosts | edit'"
! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 11/24/2001 19:46'!
runProxy: aProxy signaling: aSemaphore
	"Run aProxy, updating the output and error streams, and signaling aSemaphore
	when complete."

	| loopDelay chunkSize proj mvc |
	"These values for loopDelay and chunkSize provide reasonable performance."
	loopDelay _ Delay forMilliseconds: 100.
	chunkSize _ 1920.
	proj _ Project current.
	mvc _ proj world isKindOf: ControlManager.
	[aProxy isComplete]
		whileFalse:
			["In MVC, pause the output if user switches to another project. If this
			is not done, the view will be repainted right on top of the Morphic world."
			mvc ifTrue:
				[[proj == Project current] whileFalse: [(Delay forSeconds: 1) wait]].
			loopDelay wait.
			self processOutput: aProxy count: chunkSize.
			self processError: aProxy count: chunkSize].
	self processOutput: aProxy count: nil.
	self processError: aProxy count: nil.
	aSemaphore ifNotNil: [aSemaphore signal].
	 ^ aProxy! !

!CommandShell methodsFor: 'command processing' stamp: 'dtl 3/5/2002 05:28'!
tryEvaluatingAsSmalltalk: aCommandString
	"Attempt to treat aCommandString as a Smalltalk expression running in an
	evaluation process. Evaluate the proxy and set exit status to reflect failure
	on either the expression compilation or the runtime evaluation. Answer the
	process proxy."

	"CommandShell new tryEvaluatingAsSmalltalk: 'this expression should fail in the compiler'"
	"CommandShell new tryEvaluatingAsSmalltalk: '#this expressionShouldFailInRuntimeEvaluation'"
	"CommandShell new tryEvaluatingAsSmalltalk: '#thisIsAValidSymbolExpression'"
	"CommandShell new tryEvaluatingAsSmalltalk: 'Smalltalk'"
	"CommandShell new tryEvaluatingAsSmalltalk: '#oneWordCommentShouldFail'"

	| process |
	process _ self evaluationProxyFor: aCommandString input: nil output: nil error: nil.
	process value.
	process closeOutput.
	process closeErrorPipeline. "Last process in pipeline, so it can be closed."
	^ process! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 12/15/2001 07:19'!
dirEntryString: aDirectoryEntry
	"Code lifted from Lex Spoon's FileList>>fileNameFormattedFrom:sizePad:"

	"CommandShell new dirEntryString: FileDirectory default entries first"

	| folderString nameStr dateStr sizeStr |
	folderString _ ' [...]'.
	nameStr _ (aDirectoryEntry at: 4)
		ifTrue: [aDirectoryEntry first , folderString]
		ifFalse: [aDirectoryEntry first].
	dateStr _ ((Date fromSeconds: (aDirectoryEntry at: 3) )
					printFormat: #(3 2 1 $. 1 1 2)) , ' ' ,
				(String streamContents: [:s |
					(Time fromSeconds: (aDirectoryEntry at: 3) \\ 86400)
						print24: true on: s]).
	sizeStr _ (aDirectoryEntry at: 5) asStringWithCommas.
	^ nameStr , '    (' , dateStr , ' ' , sizeStr , ')'
! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 7/11/2001 22:28'!
doItStringFrom: aCommandString
	"Answer a string which can be evaluated as Smalltalk doIt, or nil."

	"CommandShell new doItStringFrom: 'this should answer a string!!'"
	"CommandShell new doItStringFrom: 'this should answer a string!!   '"
	"CommandShell new doItStringFrom: 'this should answer nil'"

	| s |
	s _ aCommandString withoutTrailingBlanks.
	s last == $!!
		ifTrue: [^ aCommandString copyUpToLast: $!!]
		ifFalse: [^ nil]! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 7/2/2001 11:59'!
home
	"Home directory. Could change this to use the environment."

	^ FileDirectory default pathName! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 1/3/2002 21:52'!
isADirectory: aPathString

	| fullPath localName entry |
	^ (('*', FileDirectory slash) match: aPathString) or:
		[fullPath _ FileDirectory default fullNameFor: aPathString.
		localName _ FileDirectory localNameFor: fullPath.
		entry _ (FileDirectory on: (FileDirectory dirPathFor: fullPath)) entries
			detect: [:e | e name = localName] ifNone: [nil].
		entry notNil and: [entry isDirectory]]
! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 12/17/2001 11:06'!
newDirPath: aPath from: initialPath
	"Answer a path string for a change directory command. Change from initialPath
	(usually the current working directory) to the new path, where aPath may be
	either an absolute path name (fully specified from the root) or a relative path
	name (relative to initialPath)."

	"CommandShell new cdTo: 'b?n' from: '/usr'"
	"CommandShell new cdTo: '..' from: '/usr/bin'"
	"CommandShell new cdTo: '.././bin' from: '/usr/bin'"
	"CommandShell new cdTo: '../../../../..' from: '/usr/bin'"
	"CommandShell new cdTo: '../../../../../usr' from: '/usr/bin'"

	^ (self shellSyntax
			expandedPathsFrom: aPath
			beginningAt: initialPath)
				at: 1
				ifAbsent: [nil]

! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 12/16/2001 19:17'!
nullDirectoryString
	"String to display when the current directory is one level above the file system root."

	^ '[]'! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 12/3/2001 23:14'!
processError: aProxy count: num
	"Process up to num error stream characters if available. If num is nil,
	process all available characters"

	| str |
	self readSyncSemaphore critical:
		[num isNil
			ifTrue: [str _ aProxy errorUpToEnd]
			ifFalse: [str _ aProxy nextFromError: num].
		(str notNil and: [str size > 0])
			ifTrue:
				[self show: (str replaceAll: Character lf with: Character cr); flush]]! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 11/3/2001 08:56'!
processOutput: aProxy count: num
	"Process up to num output characters if available. If num is nil, process all
	available characters"

	| str |
	self readSyncSemaphore critical:
		[num isNil
			ifTrue: [str _ aProxy upToEnd]
			ifFalse: [str _ aProxy next: num].
		(str notNil and: [str size > 0])
			ifTrue:
				[self show: (str replaceAll: Character lf with: Character cr); flush]]! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 7/1/2001 16:21'!
prompt

	self show: self promptString; restoreSelectionMarker! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 4/14/2001 09:49'!
restorePrompt
	"May be called following completion of a background process which might have written
	output beyond the current prompt position. Should restore user edited text beyond the
	command prompt, but for now simply reissue the prompt and let the user figure out
	what to do about it."

	^ self prompt! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 9/23/2001 13:10'!
restoreSelectionMarker
	"Restore selection marker in MVC"

	| c |
	Smalltalk isMorphic
		ifFalse:
			[c _ self activeController.
			self scheduleToEvaluate: [c initializeSelection] fixTemps]
! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 11/17/2001 07:59'!
scheduleToEvaluate: aBlock
	"Evaluate aBlock, typically to create a new scheduled window. Make it work in
	both Morphic and MVC. In Morphic, just evaluate aBlock, but in MVC, put it in
	a queue for evaluation within a control loop. This method may be sent from
	a process running independent of MVC controller scheduling."

	Smalltalk isMorphic
		ifTrue: [WorldState addDeferredUIMessage: aBlock]
		ifFalse: [self activeController ifNotNil: [activeController addDeferredUIMessage: aBlock]]! !

!CommandShell methodsFor: 'command support' stamp: 'dtl 2/7/2002 08:11'!
splitPipelineCommands: aCommand
	"Answer a list of the individual commands in a command pipeline string,
	delimited by the pipe character."

	^ (aCommand findTokens: self pipeCharToken) collect: [:e | e withBlanksTrimmed]
! !

!CommandShell methodsFor: 'command history' stamp: 'dtl 7/1/2001 18:25'!
editCommand: aString

	^ FillInTheBlank
		request: 'edit command'
		initialAnswer: aString! !

!CommandShell methodsFor: 'command history' stamp: 'dtl 4/22/2001 10:48'!
historyAt: anInteger

	| bufferSize index |
	bufferSize _ commandHistory size / 2.
	(anInteger > 0)
		ifTrue:
			[index _ bufferSize + 1 - historyIndex + anInteger * 2]
		ifFalse:
			[index _ bufferSize + anInteger * 2].
	((index > commandHistory size) | (index < 1))
		ifTrue: [^ '']
		ifFalse: [^ commandHistory at: index]
! !

!CommandShell methodsFor: 'command history' stamp: 'dtl 4/7/2001 13:05'!
saveInHistoryList: aCommandString

	((aCommandString size == 0) or: [self isExcludedFromHistory: aCommandString])
		ifFalse:
			[self commandHistory add: self historyIndex printString; add: aCommandString.
			historyIndex _ historyIndex + 1]
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:26'!
checkSttyFor: characterValue
	"Check for interrupt characters and such. Consume interrupt character and
	answer nil, otherwise answer characterValue."

	(self isInterrupt: characterValue)
		ifTrue:
			[self doInterrupt.
			^ nil].
	(self isEndOfFile: characterValue)
		ifTrue:
			[self doEndOfFile.
			^ nil].
	^ characterValue! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:14'!
doEndOfFile
	"EOF character detected, close stdin to pipeline."

	| firstChild |
	firstChild _ self allMyChildren first.
	firstChild ifNotNil: [firstChild pipeToInput close]
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 3/9/2002 18:22'!
doInterrupt
	"Interrupt character detected, do interrupt stuff."

	| msgStrm children answer |
	children _ self externalChildren collect: [:e | e processProxy].
	(children size > 0)
		ifTrue:
			[msgStrm _ WriteStream on: String new.
			(children size > 1)
				ifTrue: [msgStrm nextPutAll: 'kill processes']
				ifFalse: [msgStrm nextPutAll: 'kill process'].
			children do: [:e | msgStrm nextPutAll: ' ', e pid printString, ' (', e programName, ')'].
			msgStrm nextPut: $?.
			self readSyncSemaphore critical:
				[self pauseStProcesses.
				answer _ self confirm: msgStrm contents.
				self unpauseStProcesses.
				answer ifTrue:
					[children reverseDo: [:e | e sigkill].
					self terminateStProcesses]]]
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:17'!
endOfFileCharacterValue
	"<ctl>-D"

	^ 4! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/9/2001 16:13'!
filterAndForward: aCharacter
	"Filter aCharacter, taking special action if needed. If a child process is active,
	forward aCharacter to the child and answer nil. Otherwise answer aCharacter."

	^ (self checkSttyFor: aCharacter asciiValue) ifNotNil:
		[keyboardConnector isNil
			ifTrue:
				[aCharacter]
			ifFalse:
				[keyboardConnector closed
					ifTrue:
						[aCharacter]
					ifFalse:
						[keyboardConnector nextPut: aCharacter; flush.
						nil]]]! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:17'!
interruptCharacterValue
	"<ctl>-C"

	^ 3! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:20'!
isEndOfFile: anInteger

	^ anInteger == self endOfFileCharacterValue
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 6/7/2001 23:21'!
isInterrupt: anInteger

	^ anInteger == self interruptCharacterValue
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 9/30/2001 16:14'!
pauseStProcesses
	"Prevent my Smalltalk processes from being scheduled."

	"Set all my stProcesses to a very low priority"
	(self stProcesses reject: [:e | e == Processor activeProcess])
		do: [:p | p priority: Processor systemBackgroundPriority].

	"Start a process at slightly higher priority to prevent the low priority processes
	from being scheduled. Ack!! Pffft!! What a hack."
	timeWasterProcess _ [ProcessorScheduler idleProcess] newProcess.
	timeWasterProcess priority: Processor userBackgroundPriority.
	timeWasterProcess resume
! !

!CommandShell methodsFor: 'input character filtering' stamp: 'dtl 9/27/2001 20:23'!
unpauseStProcesses
	"Permit my Smalltalk processes to be scheduled."

	(self stProcesses reject: [:e | e == Processor activeProcess])
		do: [:p | p priority: Processor userSchedulingPriority; resume].
	timeWasterProcess ifNotNil: [timeWasterProcess terminate]
! !

!CommandShell methodsFor: 'testing' stamp: 'dtl 12/27/2001 12:24'!
isBuiltInCommand: aCommandString
	"Answer true if aCommandString can be evaluated as a built in command."

	"CommandShell new initialize isBuiltInCommand: 'help this should answer true'"
	"CommandShell new initialize isBuiltInCommand: 'this should answer false'"

	^ self builtinCommands includesKey: (aCommandString upTo: Character space)! !

!CommandShell methodsFor: 'testing' stamp: 'dtl 7/11/2001 20:55'!
isDoItCommand: aCommandString
	"Answer true if aCommandString should be evaluated as Smalltalk doIt."

	"CommandShell new isDoItCommand: 'this should answer true!!'"
	"CommandShell new isDoItCommand: 'this should answer true!!   '"
	"CommandShell new isDoItCommand: 'this should answer false'"

	^ aCommandString withoutTrailingBlanks last == $!!! !

!CommandShell methodsFor: 'testing' stamp: 'dtl 4/7/2001 13:04'!
isExcludedFromHistory: commandString
	"Answer true if commandString should not be remembered in the history list. The 'fc'
	and 'history' commands should be excluded."

	^ ('fc*' match: commandString)
		or: ['history*' match: commandString]! !

!CommandShell methodsFor: 'testing' stamp: 'dtl 7/20/2001 10:45'!
isExternalCommand: aCommandString
	"Answer true if aCommandString should be evaluated as an external process."

	"CommandShell new isExternalCommand: 'help this should answer false'"
	"CommandShell new isExternalCommand: 'this should answer false!!'"
	"CommandShell new isExternalCommand: 'echo ''this should answer true'''"

	^ ((self isBuiltInCommand: aCommandString) or: [self isDoItCommand: aCommandString]) not! !

!CommandShell methodsFor: 'testing' stamp: 'dtl 11/27/2001 00:19'!
isOneWordCommentString: aCommandString
	"Answer true if aCommandString is one word beginning with $#, or if it is an empty string."

	"CommandShell new isOneWordCommentString: '#oneWordComment'"
	"CommandShell new isOneWordCommentString: ' #oneWordComment'"
	"CommandShell new isOneWordCommentString: ' #oneWordComment '"
	"CommandShell new isOneWordCommentString: '#three word comment'"
	"CommandShell new isOneWordCommentString: 'not a comment'"
	"CommandShell new isOneWordCommentString: 'notAComment'"
	"CommandShell new isOneWordCommentString: ''"

	| s |
	s _ aCommandString withBlanksTrimmed.
	^ s isEmpty
		or: [(s first == $#)
			and: [(Scanner new scanTokens: s) size == 1]]
! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:56'!
bs
	self position > 0 ifTrue: [^ self skip: -1].
	self changed: #bs! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:56'!
clear
	"Clear all characters and redisplay the view"
	self changed: #clearText.
	self reset! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:56'!
endEntry
	"Display all the characters since the last endEntry, and reset the stream"
	self changed: #appendEntry.
	self reset! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:57'!
flush
	self endEntry! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:57'!
pastEndPut: anObject
	"If the stream reaches its limit, just output the contents and reset."
	self endEntry.
	^ self nextPut: anObject! !

!CommandShell methodsFor: 'stream extensions' stamp: 'dtl 3/16/2001 05:57'!
show: anObject  "TextCollector compatibility"
	self nextPutAll: anObject asString; endEntry! !

!CommandShell methodsFor: 'model protocol' stamp: 'dtl 3/16/2001 05:59'!
codePaneMenu: aMenu shifted: shifted
	"Note that unless we override perform:orSendTo:, PluggableTextController will respond
	to all menu items"

	^ StringHolder basicNew codePaneMenu: aMenu shifted: shifted
! !

!CommandShell methodsFor: 'model protocol' stamp: 'dtl 12/16/2001 19:25'!
labelString

	| directoryString |
	directoryString _ self workingDirectory.
	directoryString isEmpty ifTrue: [directoryString _ self nullDirectoryString].
	^ self class defaultWindowName, ': ', directoryString
! !

!CommandShell methodsFor: 'model protocol' stamp: 'dtl 3/17/2001 12:38'!
perform: selector orSendTo: otherTarget
	"Selector was just chosen from a menu by a user.  If can respond, then
	perform it on myself. If not, send it to otherTarget, presumably the
	editPane from which the menu was invoked."

	(self respondsTo: selector)
		ifTrue: [^ self perform: selector]
		ifFalse: [^ otherTarget perform: selector]! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 3/4/2002 07:21'!
commandProcessorClass
	"Proxy for external command processing"

	^ PipeableOSProcess
! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 3/31/2001 18:57'!
commentChar

	^ $#! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 4/8/2001 12:02'!
expressionEvaluatorClass
	"Proxy for internal command processing"

	^ PipeableEvaluator
! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 4/8/2001 15:26'!
historyDepth
	"Number of commands to retain in the command history list"

	^ 100! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 4/8/2001 15:11'!
invalidCommandMessage

	^ 'invalid command', Character cr asString! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 4/8/2001 14:04'!
noWaitToken
	"This character at the end of a command string means execute as detached process."

	^ '&'! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 4/8/2001 14:03'!
pipeCharToken
	"The command pipeline character"

	^ '|'! !

!CommandShell methodsFor: 'defaults' stamp: 'dtl 3/31/2001 18:57'!
promptString

	^ '$ '! !

!CommandShell methodsFor: 'working directory' stamp: 'dtl 12/16/2001 20:27'!
workingDirectory

	^ self shellSyntax workingDirectory
		ifNil:
			[shellSyntax workingDirectory: FileDirectory default pathName; workingDirectory]! !

!CommandShell methodsFor: 'working directory' stamp: 'dtl 12/16/2001 20:15'!
workingDirectory: aPathString

	self shellSyntax workingDirectory: aPathString
! !


!CommandShell class methodsFor: 'version testing' stamp: 'dtl 3/10/2002 11:09'!
versionString

	"CommandShell versionString"

	^'3.0'! !

!CommandShell class methodsFor: 'class initialization' stamp: 'dtl 11/17/2001 08:58'!
initialize

	"CommandShell initialize"

	Smalltalk addToStartUpList: self after: ImageSegment
! !

!CommandShell class methodsFor: 'instance creation' stamp: 'dtl 12/27/2001 23:36'!
command: aCommandString

	"CommandShell command: 'help'"

	^ self new openLabel: self defaultWindowName command: aCommandString
! !

!CommandShell class methodsFor: 'instance creation' stamp: 'dtl 12/27/2001 23:36'!
new

	^ (self on: (String new: 1000)) initialize! !

!CommandShell class methodsFor: 'instance creation' stamp: 'dtl 12/27/2001 23:36'!
open
	"CommandShell open"

	^ self new open! !

!CommandShell class methodsFor: 'instance creation' stamp: 'dtl 12/27/2001 23:36'!
openLabel: aString
	"CommandShell openLabel: self defaultWindowName"

	^ self new openLabel: aString
! !

!CommandShell class methodsFor: 'system startup' stamp: 'dtl 11/17/2001 08:57'!
startUp
	"A CommandShell may be running external processes in background, and waiting
	for those processes to complete. If the Squeak image is stopped and restarted, the
	background processes are no longer children of the Squeak process, and there is
	no way to receive notification when the processes exit. This would result in leftover
	Smalltalk processes associated with the CommandShell waiting forever for the
	external processes to exit. The simplest way to prevent this is to terminate all
	the Smalltalk processes unconditionally after an image restart."

	self allInstances do: [:e | e terminateStProcesses]
! !

!CommandShell class methodsFor: 'defaults' stamp: 'dtl 4/2/2001 20:48'!
defaultWindowName

	^ 'Squeak Shell'! !

!CommandShell class methodsFor: 'documentation' stamp: 'dtl 12/29/2001 14:18'!
commandProcessing
	"Explanation of the command parsing and evaluation."

	"CommandShell new pipeline: 'CommandShell commandProcessing!! | edit'"

	^
'CommandShell behaves similarly to a Unix command shell. One or more Morphic or MVC views can be opened on an instance of CommandShell. Command lines are accepted in the view, passed to the CommandShell instance (the model), and the results are displayed in the view(s). The overall behavior can be thought of as a Transcript acting like an xterm window, and the CommandShell acting like a /bin/sh shell.

A command line is first evaluated as a Smalltalk expression if possible. If this evaluation fails, either as a result of a sytax error or a runtime error, it is assumed to be a command string with syntax similar to that of a Unix command shell.

The command line is parsed by CommandShell to break command lines into elements of a command pipeline. All further parsing, such as file name expansion, is performed by an instance of ShellSyntax.

Three types of commands may be executed from a CommandShell:
1) Internal "builtin" commands are implemented in Smalltalk, and behave similarly to the shell builtin commands of a typical Unix command shell. See protocol category "shell builtins" for the implementation of these builtin shell commands.
2) Internal "doIt" commands are simple Smalltalk expression strings, terminated by a $!! character, which are evaluated as Smalltalk expressions, and which recognize the tokens "stdin", "stdout", and "stderr" as temporary variables in the doIt expression. An internal doIt command is evaluated such that it may be incorporated into a command pipeline with access to the stdin/stdout/stderr streams used in the command pipeline. In the current implementation, a doIt command may not include a $| character, which has meaning both for Smalltalk syntax and for Unix command line processor syntax.
3) External commands. Any command expression not recognized as a shell builtin or as a doIt expression is passed to an external process proxy for execution by the external operating system, with stdin/stdout/stderr incorporated into the command pipeline.

Internal and external commands can be freely mixed in a command pipeline, with results which should be familiar to users of Unix command shells. Pipes are implemented as instances of OSPipe or InternalPipe, and are capable of passing streams of characters from one process proxy to the next. All commands (internal or external) evaluate to strings, such that their results can either be passed through a pipe to the next command proxy in a pipeline, or displayed in the terminal window view if the proxy represents the last command in a command pipeline. Error messages (also strings) are written to an errorPipelineStream which is shared by all proxies in a command pipeline, such that any error messages are accumulated for the entire command pipeline.'! !

!CommandShell class methodsFor: 'documentation' stamp: 'dtl 3/10/2002 13:50'!
htmlOverview
	"A general overview"

	^
'<html><head><title>Introduction to CommandShell</title></head>
<body>
<h3>CommandShell</h3>
 CommandShell is a Smalltalk implementation of a command processor shell and terminal
 window. It is intended to behave like to a simple terminal window (like xterm) running
 a Unix command shell (like /bin/sh). It lacks some elements of Unix shell syntax, and
 does not provide terminal emulation, but it adds some nice Smalltalk enhancements such
 as a text editor which works in a command pipeline, and the ability to evalute Smalltalk
 expressions in a command pipeline with Unix commands.

<h3>How to use CommandShell</h3>
  Evaluate "CommandShell open" or, if you have loaded the change set to put CommandShell
  in your world menu, just select "squeak shell" from the "open..." menu entry.
  To use the command shell window, enter commands on the command line (after
  the "$ " command prompt, followed by cr to accept the command. The "help" command
  gives some clues as to what can be done. In general, just try any command which
  you might otherwise enter into a Unix shell or xterm window. Then try some of
  the Smalltalk features such as mixing Smalltalk expressions with Unix commands, and
  piping commands into Smalltalk editors.

<h3>Basic Concepts</h3>
<ul><li><h4>  Commands</h4>
    Smalltalk uses objects and messages, with expressions arranged in a natural
    Noun-Verb-Predicate sentence structure, similar to that of some spoken languages.
    In contrast, many other computer systems use a style in which users issue
    a command to the system, in which the "command" (a verb) is followed by various
    (predicate) modifiers. In the case of a traditional command-line interface, such
    as a Unix shell, the command is usualy the name of a program, and the modifiers
    are parameters passed to the program to influence its behavior. CommandShell attempts
    to provide a command line interface for executing commands within Squeak, in
    a style and environment which is comforable for someone accustomed to the
    Smalltalk style of expression.
<p>
<li><h4>  Process Proxies</h4>
    A command line user interface, such as a Unix shell or a "DOS window" in
    Windows, revolves around the notion of executing programs from user commands.
    When Squeak is hosted in another operating system, it is useful to be able to
    execute an external program from a command line expression. A process proxy
    is an object which represents the evaluation of such an external command
    in a command line environment.
<p>
    From the point of view of Squeak, a process proxy might just as well represent
    the evaluation of a Smalltalk expression in the context of a command line
    environment. Thus a process proxy can be an object which represents the execution
    of an external program or an internal Smalltalk expression. It is created from a
    command line expression, and provides a representation of certain aspects of the
    external (or internal) process execution, such as process run state, exit status, and
    the input, output and error streams for the process.
<p>
    External process proxies are used to evaluate programs in the external operating
    system (this requires the OSProcess change set in addition to CommandShell). Internal
    process proxies are used to evaluate "built in" commands for a command shell,
    such as the "cd" command to change the working directory for the command shell.
    Internal proxies are also used for evaluating "doIt" expressions within a command
    pipeline. In this case, the variables "stdin", "stdout", and "stderr" are pre-defined
    such that the doIt expression can directly access the input, output and error
    pipes for the internal process proxy (in other words, the doIt expression
    "stdout nextPutAll: ''Hello world'' !!" will write ''Hello world'' on the output pipe
    of the proxy).
<p>
<li><h4> Pipelines</h4>
    Powerful computing systems may be built upon simple design metaphors. In
    Smalltalk, the concept of objects communicating through messages is generalized
    and extended to produce the Squeak system. In Unix systems, the metaphor of a
    pipe with data flowing between two programs is generalized to produce a mechanism
    for connecting small programs to produce complex systems. The command line shells
    for Unix support this metaphor by providing syntax for connecting two or more
    commands together into more complex command pipelines.
<p>
    CommandShell provides a framework for connecting several process proxies into a
    command pipeline, using command syntax similar to that of a Unix shell. Since the
    process proxies are implemented in Smalltalk, the "programs" in a command pipeline
    may consist of process proxies representing external programs, or of proxies representing
    the evaluation of internal Smalltalk expressions. The objects which flow through
    the pipes in a command pipeline are assumed to be characters, such that the external
    commands can operate on the streams of characters in the usual way, and the internal
    Smalltalk commands read and write streams of characters.
<p>
    Just as programs (or internal expressions) are represented by process proxies, the
    pipes which interconnect two process proxies are represented by pipe objects. The
    pipe may be either an OSPipe (a proxy representing a Unix system FIFO pipe) or an
    InternalPipe (a Smalltalk object which behaves similarly to an OSPipe). The combination
    of process proxies and pipes is a command pipeline, which may be created and
    evaluated from a command line expression using conventional Unix shell syntax.
</ul>
<h3>Command Line Syntax</h4>
    A command or command pipeline may be created from a string expression, and
    evaluated using Unix shell syntax. CommandShell accepts command line strings and
    does some high level processing to set up process proxy execution. For most of the
    command parsing, it relies on a ShellSyntax object to do the syntax evaluation.
    In particular, a real Unix shell interprets command line parameters in the context of the
    Unix file system, expanding "wildcard" characters and searching for files in the context
    of a "current working directory" location in the file system tree. A CommandShell,
    collaborating with an instance of ShellSyntax, implements this syntax parsing
    and evaluation in Smalltalk.

<h3>Command Execution</h4>
    Beginning with a command line (which may represent a pipeline of several
    commands), a CommandShell first attempts to treat the entire command line as
    a Smalltalk expression. The command line string is used to create an instance of
    PipeableEvaluator (a kind of process process). If the expression is successfully
    compiled and evaluated in the PipeableEvaluator, the command line is executed
    just as if it were an external Unix command, with the result of the evaluation
    written as a string to the output stream of the process proxy.
<p>
    If the complete command line cannot be treated as a Smalltalk expression,
    CommandShell assumes that it must be a Unix style command pipeline. If the
    command line is a comment (starting with ''#'') it is discarded; otherwise it
    is broken down into a series of process proxies connected by pipes, with
    command line parameters and other aspects of the command line parsing handled
    by a ShellSyntax object.
<p>
    The process proxies in the command pipeline may represent internal or external
    commands. CommandShell parses the command line to create the proxies by breaking
    the command pipeline into segments (separated by the "|" pipe character), with
    different kinds of process proxy created according to the following priorities:
<ul><li>
      If the command segment is a simple Smalltalk expression terminated by "!!", it
      is treated as a "doIt" expression, evaluated in a PipeableEvaluator proxy. This
      kind of simple doIt expression is limited to commands with characters which
      are unambiguous in a shell command. For example, "|" has special meaning in
      a command line, and cannot be used in a doIt expression (command line quoting
      and escape characters have not yet been implemented in the CommandShell syntax).
<li>
      If the command segment is not a doIt expression, CommandShell checks to see
      if it matches one of several "shell builtin" commands. These are special commands
      implemented in class ShellBuiltin and evaluated in a PipeableEvaluator proxy.
      They behave analogously to shell builtin commands in a conventional Unix shell.
      A number of commands such as "cd" and "pwd" are implemented as internal builtin
      commands, rather than relying on Unix external equivalents. In addition, other
      builtin commands such as "edit" do things which are useful in Squeak and have
      no real equivalent in Unix (the "edit" builtin opens an editor within Squeak, taking
      its input from files or directly from the output of a command pipeline such as
      "Smalltalk !! | edit" or "who | edit").
<li>
      If the command segment is not a shell builtin command, it is assumed to be an
      external command. It this case, the command line segment is fully parsed, then
      used to create an external OS process proxy to run the external command. The
      external process proxy responds to a #value message by running the external
      program, with output and error written to pipes connected to the command
      pipeline.
<li>
      Finally, if no external program can be found to execute the command, an error
      message is provided to the command window, and no command is evaluated.
</ul>
    Once the command proxy pipeline has been created, the individual process proxies
    are evaluated in such a way that they appear to execute in parallel, with each
    proxy reading its input from a pipe connected to its predecessor in the pipeline,
    and writing its output to a pipe connected to its successor in the pipeline. An
    additional error pipe is shared by all process proxies in the pipeline, such that
    any error output is accumulated in the shared error pipe stream.
<p>
    As the command pipeline is created from the command line string, each process
    proxy sends a #value message to its predecessor cause it to be evaluated (internal
    process proxies) or to create and run its external program (external process proxies).
    The chain of process proxies is connected by pipes for the connected input and
    output streams, and has a single shared pipe to collect error streams from all
    the process proxies.
<p>
    A command shell can obtain the output and error of a complex command pipeline
    simply by evaluating the last process proxy in the chain, and reading up to the
    end of its output and error pipes. Since a process proxy knows its run state, and
    a pipe is not "at end" until a process proxy closes one end of the pipe, the pipeline
    can be constructed in such a way that the command shell is assured that all process
    proxies have completed their evaluation when the output of the last proxy is read
    up to the end of the pipe.
<p>
    As the last process proxy in a command pipeline is evaluated, CommandShell reads
    its output and error pipes, and displays the text in the View or Morph which it uses
    as its terminal window. When complete, it issues a new prompt string, and waits for
    another command line to be entered by the user.
<p>
<h3>Exercise for the Reader:</h4>
Which one of the following five command lines will generate
an error, and why?
<ol><li>
  $ stdout nextPutAll: ''hello world''
<li>
  $ stdout nextPutAll: ''hello world''; cr
<li>
  $ stdout nextPutAll: ''hello world''!!
<li>
  $ stdout nextPutAll: ''hello world''; cr!!
<li>
  $ stdout nextPutAll: ''hello world''!!; stdout cr!!
</ol>
<h3>Answer:</h4>
The fourth command will generate an error.
<ul><li>
  Line one is evaluated as a complete Smalltalk expression, and succeeds.
<li>
  Line two is evaluated as a complete Smalltalk expression, and succeeds.
<li>
  Line three is evaluated as a pipeline after failing evaluation as a complete Smalltalk
  expression. It succeeds as a pipeline with one internal doIt proxy, and produces
  the same output as line one.
<li>
  Line four cannot be evaluated as a complete Smalltalk expression. The ";" token
  causes the command line to be evaluated as two pipelines. The expression for the
  first pipeline does not have a trailing "!!" token, so it is assumed to be an external
  command, and fails. The second pipeline is evaluated as a doIt on the string ''cr!!'',
  which fails as an invalid Smalltalk expression. The error messages for both failures
  are accumulated on the shared error pipe, and are displayed in the terminal window.
<li>
  Line five is evaluated successfully as two pipelines, each consisting of one doIt
  proxy. The output is the same as for line two.
</ul></body></html>
'! !

!CommandShell class methodsFor: 'documentation' stamp: 'dtl 12/1/2001 18:51'!
overview
	"A general overview"

	"CommandShell new pipeline: 'CommandShell overview!! | edit'"

	| rs ws |
	rs _ ReadStream on: self htmlOverview.
	ws _ WriteStream on: String new.
	[rs atEnd]
		whileFalse:
			[ws nextPutAll: (rs upTo: $<).
			rs upTo: $>].
	^ ws contents
! !

!CommandShell class methodsFor: 'documentation' stamp: 'dtl 3/10/2002 13:48'!
raceConditions

	"CommandShell new pipeline: 'CommandShell raceConditions!! | edit'"

	^
'It may be possible to hang the Squeak VM in an IO race condition when doing certain command pipelines. These conditions have been largely (completely?) eliminated for Unix platforms through the use of nonblocking pipes in conjunction with polling processes on the Smalltalk side of the pipes. However, these notes are provided to describe possible deadlock scenarios.

Note that nonblocking OS pipes are not yet available on Windows. Command pipelines with external OS processes on Windows are not supported. Blocking on read or write to an OSPipe in Windows will definitely lock the VM.

The overall scenario is as follows: From a Squeak Shell, enter a command pipeline with an internal command proxy, piped to an external command proxy, piped to another internal command proxy. 

Two kinds of deadlock are possible. In both cases, deadlock occurs when the single-threaded Squeak VM is blocked on a read or write to an OS pipe, and the blocked condition can only be cleared by another process running in the blocked VM.

1) Block on write. The Squeak VM can block on a write to an OS pipe if the external process at the other end of the pipe does not keep up with reading it. One internal process proxy writes on an pipe to an external process proxy, and fills the pipe up to some capacity limit, after which the write blocks. The external proxy is writing its output to another internal process proxy in the command pipeline, which never executes because the VM is still blocked trying to write to the full pipe.

2) Block on read. The Squeak VM can block on a read from an OS pipe if the external process writing to the pipe never closes the pipe. The internal proxy will post a read on the output pipe from the external command. If the external command has exited, the read will return with a (possibly empty) string. However, if the external command either does not exit, or exits without Squeak being notified, the read on the output pipe will block indefinitely.

2a) In the case where the external command exits while the Squeak VM is blocked on a read, Squeak is unable to respond to the notification of the external process exiting. The process stays in a zombie state, the pipes therefore never get closed, and the VM stays in a blocked condition.

Here are things to try if a deadlock occurs:

Squeak will be blocked and will not respond to the mouse or keyboard. Open a command shell outside of Squeak (perhaps an xterm, or log in to another virtual terminal on Linux or FreeBSD). Using the "ps" command, find the Squeak VM process and its subprocesses. Kill the subprocess. In many cases this will free up the deadlock, and Squeak will come back to life. If this does not work, then you will probably find that one of the processes which you just killed is now in a "zombie" state, which means that the Squeak VM is deadlocked in such a way that it cannot recognize that its child process exited (and therefore cannot properly close the associated file handles). In this case, if your operating system supports a /proc file system, you may be able to break things free by emptying the pipes. On Linux, go to /proc/<pidOfTheSqueakVMProcess>/fd/ and do "cat" commands on all the pipe files in this directory. If none of this works, you are just plain stuck, and you will need to kill your Squeak session and recover anything valuable from the changes log.

Notes:
In the current implemention, the following command line will deadlock the VM.
$ who | copyToOutput | copyToOutput | copyToOutput | cat | copyToOutput | copyToOutput

The condition can be resolved by killing the "cat" command from outside of Squeak. The deadlock occurs because the "copyToOutput" command are shell builtins which have delays built into a loop of execution. The delays prevent another deadlock condition (overflowing the output pipe, resulting in a block on write deadlock). However, the delays also permit the "cat" command to complete execution prior to the preceding "copyToOutput" commands. The "copyToOutput" command after the "cat" will block on read, and the preceding "copyToOutput" commands are prevented from completing. The input to "cat" is never closed, so "cat" continues executing, and the Squeak VM stays blocked on a read indefinitely.

Race conditions which are now prevented in this implementation:
Fixed one race condition as follows:
  "$ ls -lR / | copyToOutput | cat"

This formerly resulted in the following race condition:
  1) The "ls -lR" external process generates a large output string.
  2) The "copyToOutput" internal doIt command pipes the large output string to an external "cat" command, and blocks on the write when the OS pipe is full.
  3) The output of "cat" should be read by a Smalltalk process associated with a CommandShell, but...
  4) The output of "cat" is not read, because we are still blocking on the write to the input of "cat".
  5) ==> deadlock

The CommandShell>>copyToOutput:input:output:error method (one of the shell builtin commands) now prevents this race condition by explicitly forcing updates of "OSProcess thisOSProcess updateActiveChildren".

However, this still permitted the race condition to occur when interrupting the command line with a <ctl>C. Interrupt character processing now prevents this race condition by pausing all background processes in CommandShell>>doInterrupt.
'! !


!CrLfFileEditor methodsFor: 'initialize-release' stamp: 'dtl 6/16/2001 10:14'!
mvcWithLabel: aLabelString

	| topView fileContentsView |
	Smalltalk isMorphic ifTrue:
		[^ self error: 'this method should be used only for MVC'].
	topView _ StandardSystemView new.
	topView
		model: self;
		controller: DeferredActionStandardSystemController new;
		label: aLabelString;
		minimumSize: 200@200.
	topView borderWidth: 1.
	fileContentsView _ PluggableTextView on: self
		text: #contents
		accept: #put:
		readSelection: #contentsSelection
		menu: #fileContentsMenu:shifted:.
	fileContentsView window: (0@0 extent: 200@140).
	topView addSubView: fileContentsView.
	^ topView controller
! !

!CrLfFileEditor methodsFor: 'initialize-release' stamp: 'dtl 6/14/2001 22:20'!
openAsMorphLabel: aLabelString

	| window |
	window _ (SystemWindow labelled: aLabelString) model: self.
	window
		addMorph: (PluggableTextMorph
		on: self
		text: #contents
		accept: #put:
		readSelection: #contentsSelection menu: #fileContentsMenu:shifted:)
		frame: (0@0 corner: 1@1).
	window submorphsDo: [:m | m color: Color lightMagenta].
	^ window! !

!CrLfFileEditor methodsFor: 'initialize-release' stamp: 'dtl 6/14/2001 22:36'!
openLabel: aLabelString

	Smalltalk isMorphic
		ifTrue:
			[^ self openAsMorphLabel: aLabelString]
		ifFalse:
			[^ (self mvcWithLabel: aLabelString) open]
! !

!CrLfFileEditor methodsFor: 'initialize-release' stamp: 'dtl 6/16/2001 08:16'!
withLabel: aLabelString
	"Same as #openLabel: but does not open the window in MVC"

	Smalltalk isMorphic
		ifTrue:
			[^ self openAsMorphLabel: aLabelString]
		ifFalse:
			[^ self mvcWithLabel: aLabelString]
! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:41'!
directory

	^ directory! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:40'!
directory: aDirectory

	directory _ aDirectory! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:01'!
fileName

	^ fileName! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:01'!
fileName: aString

	fileName _ aString! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:00'!
lineEndConvention

	^ lineEndConvention! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/19/2001 17:01'!
lineEndConvention: aSymbol
	"See CrLfFileStream for the allowable values of aSymbol."

	lineEndConvention _ aSymbol! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/20/2001 12:44'!
viewStyle
	"#text or #hex"

	viewStyle isNil ifTrue: [viewStyle _ #text].
	^ viewStyle! !

!CrLfFileEditor methodsFor: 'accessing' stamp: 'dtl 5/20/2001 12:45'!
viewStyle: aSymbol
	"#text or #hex"

	viewStyle _ aSymbol! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/20/2001 14:27'!
contents

	^ (self viewStyle == #hex)
		ifTrue: [self hexFormat: contents]
		ifFalse: [contents]
! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/20/2001 13:01'!
contents: aString

	(self viewStyle == #hex)
		ifTrue: [self inform: 'cannot update in hex mode']
		ifFalse: [^ super contents: aString]! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/20/2001 21:21'!
currentFilePathName

	^ self directory pathName, FileDirectory slash, self fileName! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/20/2001 21:27'!
fileContentsMenu: aMenu shifted: shifted

| shiftMenu |
^ shifted 
	ifFalse: [aMenu 
		labels: 
'save
save as...
exit
view as hex
view as text
browse changes
find...(f)
find again (g)
set search string (h)
do again (j)
undo (z)
copy (c)
cut (x)
paste (v)
paste...
do it (d)
print it (p)
inspect it (i)
fileIn selection
accept (s)
cancel (l)
more...' 
		lines: #(3 6 9 11 15 19 21)
		selections: #(save saveAs exit getHex getText browseChanges
find findAgain setSearchString
again undo
copySelection cut paste pasteRecent
doIt printIt inspectIt fileItIn
accept cancel
shiftedYellowButtonActivity)]

	ifTrue: [shiftMenu _ ParagraphEditor shiftedYellowButtonMenu.
		aMenu 
			labels: shiftMenu labelString 
			lines: shiftMenu lineArray
			selections: shiftMenu selections]

! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/26/2001 18:23'!
getSelection

	^ 1 to: 0  "null selection"! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 5/20/2001 21:22'!
labelString
	"For views to use a labels"

	^ self currentFilePathName! !

!CrLfFileEditor methodsFor: 'model access' stamp: 'dtl 7/2/2001 08:39'!
put: aText 

	| str newFileName fs |
	(self viewStyle == #hex)
		ifTrue:
			[self inform: 'cannot save file in hex mode'.
			^ false].
	str _ aText asString.
	self contents: str.
	(directory fileExists: fileName)
		ifTrue: [newFileName _ self
					getFileName: directory pathName,
						FileDirectory slash , fileName.]
		ifFalse: [newFileName _ directory pathName,
						FileDirectory slash , fileName].
	newFileName ifNil: [^ false].
	fs _ CrLfFileStream fileNamed: newFileName.
	[fs isNil] whileTrue:
		[self inform: 'cannot write file'.
		newFileName _ self getAnotherFileName: newFileName.
		newFileName isNil
			ifTrue:
				[self inform: 'file not written'.
				^ false]
			ifFalse:
				[fs _ CrLfFileStream fileNamed: newFileName]].
	(str size < fs size)
		ifTrue:
			[(fs respondsTo: #truncate)
				ifTrue:
					[[fs truncate]
						on: Error
						do: [fs _ self bogusTruncate: fs]]
				ifFalse: [fs _ self bogusTruncate: fs]].
	fs nextPutAll: str.
	fs close.
	self updateFilePathWith: newFileName.
	^ true! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 5/20/2001 14:58'!
browseChanges
	"Browse in fileIn format."

	| fs |
	fs _  self directory fileNamed: fileName.
	ChangeList browseStream: fs.
	fs close
! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 6/3/2001 16:54'!
controllerForAccept
	"Find the controller or morph which expects the #accept message"

	| controller view |
	Smalltalk isMorphic
		ifTrue:
			[controller _ dependents detect: [:e | e respondsTo: #accept] ifNone: [nil]]
		ifFalse:
			[view _ dependents detect: [:e | e controller respondsTo: #accept] ifNone: [nil].
			controller _ view isNil
				ifTrue: [nil]
				ifFalse: [view controller]].
	^ controller! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 6/3/2001 20:20'!
exit

	self changed: #accept.
	Smalltalk isMorphic
		ifTrue:
			[dependents do: [:d | (d respondsTo: #closeBoxHit) ifTrue: [d closeBoxHit]]]
		ifFalse:
			[dependents first controller closeAndUnschedule]! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 5/20/2001 12:46'!
getHex

	Cursor read showWhile:
		[self viewStyle: #hex.
		self changed: #contents]
! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 5/20/2001 14:01'!
getText

	Cursor read showWhile:
		[self viewStyle: #text.
		self changed: #contents]
! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 6/29/2001 23:22'!
save

	| controller |
	self forceDirtyBuffer.
	controller _ self controllerForAccept.
	controller ifNotNil: [controller accept]
! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 6/29/2001 23:23'!
saveAs

	| oldFilePath newFilePath controller |
	oldFilePath _ self currentFilePathName.
	newFilePath _ FillInTheBlank
					request: 'Enter a new file name'
					initialAnswer: oldFilePath.
	newFilePath isEmpty
		ifFalse:
			[self updateFilePathWith: newFilePath.
			controller _ self controllerForAccept.
			controller ifNotNil:
				[self forceDirtyBuffer.
				controller accept]]

! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 5/20/2001 19:39'!
selectedClassOrMetaClass
	"For support of the pretty printer menu option"

	^ self class! !

!CrLfFileEditor methodsFor: 'menus' stamp: 'dtl 5/20/2001 19:37'!
selectedMessageCategoryName
	"For support of the pretty printer menu option"

	^ '-- all --'! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 7/2/2001 08:36'!
bogusTruncate: fileStream
	"Truncate the file by brute force if FileStream>>truncate is not supported on
	this system. Note that this does not preserve file permissions."

	| name |
	name _ fileStream name.
	fileStream close.
	directory deleteFileNamed: name.
	^ CrLfFileStream fileNamed: name
! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 6/29/2001 23:21'!
forceDirtyBuffer
	"This will force the view to behave as if it had been edited. Call this to
	enable a file save even if the text has not actually been edited by the
	user."

	| controller |
	controller _ self dependents
			detect: [:e | e respondsTo: #hasUnacceptedEdits:]
			ifNone:
				[self dependents
					collect: [:d | d controller]
					thenSelect: [:c | c respondsTo: #hasUnacceptedEdits:]].
	controller hasUnacceptedEdits: true.
! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 5/20/2001 09:52'!
getAnotherFileName: initialFileName

	| choice newFileName |
	choice _ (PopUpMenu
		labels: 'choose another name\cancel' withCRs)
		startUpWithCaption: initialFileName.
	choice = 1
		ifTrue: [newFileName _ FillInTheBlank
									request: 'Enter a new file name'
									initialAnswer: initialFileName.
				newFileName _ (directory fileExists: newFileName)
					ifTrue: [self getFileName: newFileName]
					ifFalse: [newFileName].
				^ newFileName].
	^ nil! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 5/19/2001 22:37'!
getFileName: initialFileName

	| choice newFileName |
	choice _ (PopUpMenu
		labels: 'overwrite that file\choose another name\cancel' withCRs)
		startUpWithCaption: initialFileName, ' already exists.'.
	choice = 1
		ifTrue: [^ initialFileName].
	choice = 2
		ifTrue: [newFileName _ FillInTheBlank
									request: 'Enter a new file name'
									initialAnswer: initialFileName.
				newFileName _ (directory fileExists: newFileName)
					ifTrue: [self getFileName: newFileName]
					ifFalse: [newFileName].
				^ newFileName].
	^ nil! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 5/20/2001 14:25'!
hexFormat: aString

	"CrLfFileEditor new hexFormat: 'this is a test of the HEX string reformat method'"

	| s |
	s _ WriteStream on: (String new: aString size*4).
	0 to: aString size-1 by: 16 do:
		[:loc | s nextPutAll: loc hex; space;
			nextPut: $(; print: loc; nextPut: $); space; tab.
		loc+1 to: (loc+16 min: aString size) do: [:i | s nextPutAll: (aString at: i) hex; space].
		s cr].
	^ s contents.
! !

!CrLfFileEditor methodsFor: 'private' stamp: 'dtl 5/20/2001 16:25'!
updateFilePathWith: aPathString

	self fileName: (FileDirectory localNameFor: aPathString).
	self directory: (FileDirectory on: (FileDirectory dirPathFor: aPathString)).
	self changed: #relabel
! !


!CrLfFileEditor class methodsFor: 'instance creation' stamp: 'dtl 5/20/2001 14:31'!
editFileNamed: pathName

	"CrLfFileEditor editFileNamed: '/etc/hosts'"
	"CrLfFileEditor editFileNamed: '/NO/SUCH/FILE'"
	"CrLfFileEditor editFileNamed: '/etc/NOSUCHFILE)'"

	| w |
	Cursor read showWhile: [w _ (self openForFileNamed: pathName) openInWorld].
	^ w
! !

!CrLfFileEditor class methodsFor: 'instance creation' stamp: 'dtl 1/1/2002 16:34'!
fileNamed: pathName
	"Answer a Controller or Morph as view on an instance of myself."

	"CrLfFileEditor fileNamed: '/etc/hosts'"
	"CrLfFileEditor fileNamed: '/NO/SUCH/FILE'"
	"CrLfFileEditor fileNamed: '/etc/NOSUCHFILE'"

	| dirPath dir fs convention editText localName model |
	dirPath _ FileDirectory dirPathFor: pathName.
	dir _ FileDirectory on: dirPath.
	localName _ FileDirectory localNameFor: pathName.
	(dir fileExists: localName)
		ifTrue:
			[[fs _ CrLfFileStream readOnlyFileNamed: pathName.
			convention _ fs detectLineEndConvention.
			editText _ fs contentsOfEntireFile.
			fs close]
				on: Error
				do: [convention _ #lf.	"Default for Unix text files"
					editText _ '']]
		ifFalse:
			[convention _ #lf.	"Default for Unix text files"
			editText _ ''].
	model _ self new.
	model
		contents: editText;
		directory: dir;
		fileName: localName;
		lineEndConvention: convention.

	^ model withLabel: pathName
! !

!CrLfFileEditor class methodsFor: 'instance creation' stamp: 'dtl 6/14/2001 22:23'!
openOn: aString withLabel: aLabelString inDirectory: aDirectory defaultFileName: nameString

	"(CrLfFileEditor openOn: 'this is the string to edit' withLabel: 'this is the window label' inDirectory: FileDirectory default defaultFileName: 'buffer.txt') openInWorld"

	| model |
	model _ self new contents: aString.
	model directory: aDirectory.
	model fileName: nameString.
	^ model openLabel: aLabelString
! !

!CrLfFileEditor class methodsFor: 'private' stamp: 'dtl 6/16/2001 08:31'!
openForFileNamed: pathName

	"CrLfFileEditor openForFileNamed: '/etc/hosts'"
	"CrLfFileEditor openForFileNamed: '/NO/SUCH/FILE'"
	"CrLfFileEditor openForFileNamed: '/etc/NOSUCHFILE'"

	^ Smalltalk isMorphic
		ifTrue: [(self fileNamed: pathName) openInWorld]
		ifFalse: [(self fileNamed: pathName) open]
! !


!InternalPipe methodsFor: 'initialize-release' stamp: 'dtl 9/16/2001 22:35'!
initialize

	self queue
! !

!InternalPipe methodsFor: 'initialize-release' stamp: 'dtl 11/25/2001 14:33'!
setBlocking
	"For compatibility with OSPipe"

	self nonBlockingMode: false! !

!InternalPipe methodsFor: 'initialize-release' stamp: 'dtl 11/24/2001 15:56'!
setNonBlocking
	"For compatibility with OSPipe"

	self nonBlockingMode: true! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 21:06'!
contents
	"Answer contents of the pipe, and return the contents to the pipe so it can still be read."

	"InternalPipe new nextPutAll: 'hello'; contents"

	| s |
	s _ self next: queue size.
	self nextPutAll: s.
	^ s! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 16:19'!
next
	"Answer the next object accessible by the receiver."

	(self nonBlockingMode and: [queue size == 0])
		ifTrue: [^ nil]
		ifFalse: [^ queue next]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 16:23'!
next: anInteger 
	"Answer the next anInteger elements of my collection."

	| strm c |
	strm _ WriteStream on: ''.
	(1 to: anInteger) do:
		[:index |
		self atEnd
			ifTrue: [^ strm contents]
			ifFalse:
				[(c _ self next) ifNil: [^ strm contents].
				strm nextPut: c]].
	^ strm contents
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 9/16/2001 22:37'!
nextPut: anObject 
	"Insert the argument, anObject, as the next object accessible by the 
	receiver. Answer anObject."

	^ queue nextPut: anObject! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 9/16/2001 22:41'!
nextPutAll: aCollection 
	"Append the elements of aCollection to the sequence of objects accessible 
	by the receiver. Answer aCollection."

	aCollection do: [:e | queue nextPut: e]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 15:55'!
nonBlockingMode

	^ nonBlockingMode ifNil: [nonBlockingMode _ false]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 15:55'!
nonBlockingMode: trueOrFalse

	nonBlockingMode _ trueOrFalse
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 9/16/2001 22:42'!
peek

	^ queue peek
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 9/16/2001 22:35'!
queue

	^ queue ifNil: [queue _ SharedQueue new]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/25/2001 19:15'!
size
	"An InternalPipe may contain a trailing nil if it has been closed. This should
	not be counted as part of the pipe size, so use #contents to determine the size
	after stripping any trailing nil."

	"InternalPipe new nextPutAll: 'hello'; size"

	^ self closed
		ifTrue: [self contents size]
		ifFalse: [self queue size]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/25/2001 18:14'!
upToEnd
	"Answer the remaining elements in the pipe"

	| strm c |
	strm _ WriteStream on: ''.
	[self atEnd] whileFalse:
		[c _ self next.
		c isNil
			ifTrue: [^ strm contents]
			ifFalse: [strm nextPut: c]].
	^ strm contents! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 15:01'!
writerClosed

	^ writerClosed ifNil: [writerClosed _ false]
! !

!InternalPipe methodsFor: 'accessing' stamp: 'dtl 11/24/2001 15:02'!
writerClosed: trueOrFalse

	writerClosed _ trueOrFalse
! !

!InternalPipe methodsFor: 'character writing' stamp: 'dtl 9/23/2001 16:49'!
cr
	"Append a return character to the receiver."

	self queue nextPut: Character cr! !

!InternalPipe methodsFor: 'testing' stamp: 'dtl 11/24/2001 15:04'!
atEnd
	"Answer whether the receiver can access any more objects."

	^ self writerClosed and: [queue size == 0]
! !

!InternalPipe methodsFor: 'testing' stamp: 'dtl 11/24/2001 15:03'!
closed

	^ self writerClosed! !

!InternalPipe methodsFor: 'finalization' stamp: 'dtl 1/1/2002 11:38'!
close

	self closeWriter; closeReader! !

!InternalPipe methodsFor: 'finalization' stamp: 'dtl 1/1/2002 11:38'!
closeReader
	"Nothing to do. This is for OSPipe compatibility."
! !

!InternalPipe methodsFor: 'finalization' stamp: 'dtl 12/31/2001 15:23'!
closeWriter
	"Set the writerClosed flag, and add a trailing nil to the pipe to mimic the
	behaviour of an external pipe which blocks until the writer end is closed.
	Writing a trailing nil the the queue has the side effect of waking up any
	process which is blocked waiting on the queue, which will receive the nil
	as an indication that the pipe has been closed."

	self writerClosed: true.
	self nextPut: nil! !


!InternalPipe class methodsFor: 'instance creation' stamp: 'dtl 12/2/2001 19:24'!
blockingPipe

	"InternalPipe blockingPipe"

	^ super basicNew initialize setBlocking
! !

!InternalPipe class methodsFor: 'instance creation' stamp: 'dtl 12/2/2001 19:25'!
new

	"InternalPipe new"

	^ self blockingPipe! !

!InternalPipe class methodsFor: 'instance creation' stamp: 'dtl 12/2/2001 19:24'!
nonBlockingPipe

	"InternalPipe nonBlockingPipe"

	^ super basicNew initialize setNonBlocking
! !

!InternalPipe class methodsFor: 'examples' stamp: 'dtl 9/19/2001 21:18'!
testPipe

	"InternalPipe testPipe inspect"

	| pipe result |
	pipe _ self new.
	pipe nextPutAll: 'string to send through an InternalPipe'.
	result _ pipe upToEnd.
	pipe close.
	^ result
! !


!PipeJunction methodsFor: 'initialize - release' stamp: 'dtl 3/5/2002 05:27'!
closeErrorPipeline

	errorPipelineStream ifNotNil: [errorPipelineStream close]
! !

!PipeJunction methodsFor: 'initialize - release' stamp: 'dtl 3/5/2002 05:27'!
closeOutput

	pipeFromOutput ifNotNil: [pipeFromOutput close]
! !

!PipeJunction methodsFor: 'initialize - release' stamp: 'dtl 3/8/2002 05:34'!
ensurePipeFromOutput
	"Make sure that an output pipe is provided."

	^ pipeFromOutput ifNil: [pipeFromOutput _ InternalPipe new]
! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 19:29'!
errorPipelineStream
	"Accumulates the error output of commands in a command pipeline."

	errorPipelineStream isNil ifTrue: [errorPipelineStream _ InternalPipe nonBlockingPipe].
	^ errorPipelineStream
! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 19:30'!
errorPipelineStream: aStream
	"Accumulates the error output of commands in a command pipeline."

	errorPipelineStream _ aStream
! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 21:46'!
pipeFromOutput

	^ pipeFromOutput! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 21:46'!
pipeFromOutput: aPipeStream

	pipeFromOutput _ aPipeStream! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 21:36'!
pipeToInput

	^ pipeToInput! !

!PipeJunction methodsFor: 'accessing' stamp: 'dtl 3/4/2002 21:37'!
pipeToInput: aPipeStream

	pipeToInput _ aPipeStream! !

!PipeJunction methodsFor: 'testing' stamp: 'dtl 3/9/2002 18:16'!
isExternalProcess
	"Answer true if the process which I represent is an external OSProcess."

	^ false! !

!PipeJunction methodsFor: 'command pipelines' stamp: 'dtl 3/9/2002 19:52'!
outputPipeForNextProxy

	^ pipeFromOutput! !


!PipeableEvaluator methodsFor: 'initialize - release' stamp: 'dtl 3/9/2002 19:33'!
initialize
	"If pipeFromOutput has been set, then the output stream is being redirected.
	Set a flag to indicate this, otherwise open new a pipe stream to use for output."

	pipeFromOutput isNil
		ifTrue: [self ensurePipeFromOutput]
		ifFalse: [self outputHasBeenRedirected: true]
! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/8/2001 09:18'!
evaluationBlock
	"Answer the block to be evaluated, possibly compiling it from the expression string."

	evaluationBlock ifNil: [self compile].
	^ evaluationBlock! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/8/2001 09:13'!
evaluationBlock: aBlock
	"The block to be evaluated, possibly compiled from the expression string."

	evaluationBlock _ aBlock! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 11/25/2001 22:46'!
exitStatus

	exitStatus ifNil: [self success].
	^ exitStatus! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 11/25/2001 22:38'!
exitStatus: aSymbol

	exitStatus _ aSymbol! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/7/2001 16:35'!
expression

	^ expression! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/7/2001 16:36'!
expression: aString

	expression _ aString! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/21/2001 08:39'!
extraArguments
	"Any additional arguments for my evaluationBlock, to be passed in an Array."

	^ extraArguments! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/21/2001 08:39'!
extraArguments: anArray
	"Any additional arguments for my evaluationBlock, to be passed in an Array."

	extraArguments _ anArray! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 7/1/2001 12:53'!
needsPrompt
	"Answer true if a shell will want to issue a prompt after evaluating me."

	needsPrompt ifNil: [needsPrompt _ true].
	^ needsPrompt
! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 7/1/2001 12:54'!
needsPrompt: aBoolean
	"True if a shell will want to issue a prompt after evaluating me."

	needsPrompt _ aBoolean
! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 3/9/2002 18:55'!
outputHasBeenRedirected
	"True if pipeFromOutput has been redirected to a FileStream"

	^ outputHasBeenRedirected ifNil: [outputHasBeenRedirected _ false]! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 3/9/2002 18:57'!
outputHasBeenRedirected: trueOrFalse
	"True if pipeFromOutput has been redirected to a FileStream"

	outputHasBeenRedirected _ trueOrFalse! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 4/28/2001 09:07'!
pid
	"A PipeableEvaluator does not have a pid, so answer nil. This is for
	compatability in a Unix process pipeline."

	^ nil! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 3/4/2002 06:55'!
runState

	^ runState
! !

!PipeableEvaluator methodsFor: 'accessing' stamp: 'dtl 3/4/2002 06:56'!
runState: aSymbol

	runState _ aSymbol.
	self changed: #runState
! !

!PipeableEvaluator methodsFor: 'setting run state' stamp: 'dtl 3/4/2002 22:32'!
complete
	"Evaluation has been completed."

	self runState: #complete
! !

!PipeableEvaluator methodsFor: 'setting run state' stamp: 'dtl 3/4/2002 22:32'!
notYetRunning
	"Process has not yet entered running state."

	self runState: #notYetRunning
! !

!PipeableEvaluator methodsFor: 'setting run state' stamp: 'dtl 3/4/2002 22:32'!
running
	"Process is actively running."

	self runState: #running
! !

!PipeableEvaluator methodsFor: 'setting run state' stamp: 'dtl 3/4/2002 22:32'!
unknownRunState
	"Unable to determine the current run state of the process."

	self runState: #unknownRunState
! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 4/21/2001 10:56'!
addTreeLeaves: treeOfSymbols to: aCollection
	"Flatten a tree of Symbols built by a Scanner."

	treeOfSymbols do: [:e |
		(e isKindOf: Array)
			ifTrue: [self addTreeLeaves: e to: aCollection]
			ifFalse: [aCollection add: e]].
	^ aCollection! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 3/3/2002 21:29'!
blockString
	"Answer source code for a block to execute my expression. Attempt to give it the correct
	number of parameters based on scanning expression for use of #args, #stderr, #stdout,
	and #stdin tokens."

	"PipeableEvaluator new expression: 'stdout nextPutAll: (args at: 4)'; blockString"
	"PipeableEvaluator new expression: 'stderr nextPutAll: stdin contents'; blockString"
	"PipeableEvaluator new expression: 'stdout nextPutAll: stdin contents'; blockString"
	"PipeableEvaluator new expression: 'stdin contents'; blockString"
	"PipeableEvaluator new expression: '#HelloWorld'; blockString"

	| tokens prefix |
	self expression isNil
		ifTrue:
			[^ '[]']
		ifFalse:
			[tokens _ self addTreeLeaves: (Scanner new scanTokens: expression) to: OrderedCollection new.
			(tokens includes: #args)
				ifTrue:
					[prefix _ '[:stdin :stdout :stderr :args | ']
				ifFalse:
					[(tokens includes: #stderr)
						ifTrue:
							[prefix _ '[:stdin :stdout :stderr | ']
						ifFalse:
							[(tokens includes: #stdout)
								ifTrue:
									[prefix _ '[:stdin :stdout | ']
								ifFalse:
									[(tokens includes: #stdin)
										ifTrue:
											[prefix _ '[:stdin | ']
										ifFalse:
											[prefix _ '[']]]].
			^ prefix, self expression, ']']
! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 3/4/2002 22:19'!
blockValue
	"Evaluate my evaluationBlock. For a smart block, answer self. For a dumb
	block, answer the result of evaluating it. Heuristic: If the block receives
	two or more arguments, then assume that it was smart enough to write
	output to stdout. Otherwise, assume that it was a dumb block."

	| nArgs |
	self evaluationBlock ifNil: [^ nil].
	nArgs _ evaluationBlock numArgs.
	(nArgs == 0)
		ifTrue: "dumb block"
			[^ evaluationBlock value]
		ifFalse:
			[(nArgs == 1)
				ifTrue: "dumb block"
					[^ evaluationBlock value: self pipeToInput]
				ifFalse:
					[(nArgs == 2)
						ifTrue: "smart block"
							[evaluationBlock
								value: self pipeToInput
								value: self pipeFromOutput]	
						ifFalse:
							[(nArgs == 3)
								ifTrue: "smart block"
									[evaluationBlock
										value: self pipeToInput
										value: self pipeFromOutput
										value: self errorPipelineStream]
								ifFalse:
									[(nArgs == 4)
										ifTrue: "smart block"
											[evaluationBlock
												value: self pipeToInput
												value: self pipeFromOutput
												value: self errorPipelineStream
												value: self extraArguments]
										ifFalse: "really stupid block"
											[self error: 'expected block with 4 or fewer arguments'. ^ nil]]]]]
! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 3/4/2002 22:23'!
closePipes

	pipeFromOutput ifNotNil: [pipeFromOutput close].
	pipeToInput ifNotNil: [pipeToInput close].
	self errorHasBeenRedirected ifTrue: [errorPipelineStream close]
! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 3/4/2002 22:24'!
compile
	"Compile my expression into a block with zero to four parameters. The parameters,
	if present, correspond to my pipeToInput, pipeFromOutput, errorPipelineStream, and
	an array of extra parameters (in that order). By convention, these are named 'stdin',
	'stdout', 'stderr', and 'args' within my expression string.

	If the compilation fails due to a syntax error (compile time failure, not run time
	failure), put an error message on the standard error stream and answer a block
	which evaluates to a null string."

	evaluationBlock ifNil:
		[evaluationBlock _ self handleCompileErrorFor:
			[Compiler evaluate: self blockString
					for: self
					notifying: self
					logged: false]]
! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 11/25/2001 22:39'!
fail

	self exitStatus: #fail! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 11/25/2001 22:39'!
success

	self exitStatus: #success! !

!PipeableEvaluator methodsFor: 'evaluating' stamp: 'dtl 3/9/2002 18:08'!
value
	"Evaluate my evaluationBlock. If the block evaluates to anything other
	than self, then print the result on pipeFromOutput as output. Otherwise,
	assume that the block was smart enough to have written its own output.
	For a block which does not write its own output, add a trailing <cr> after
	the evaluation if needed. Answer self as the result of the evaluation."

	| result resultString |
	self success. "Hope for the best, send #fail if something goes wrong"
	self isNotYetRunning ifTrue:
		[self ensurePipeFromOutput.
		self running.
		self evaluationBlock notNil
			ifTrue:
				[result _ self handleRuntimeErrorFor: [self blockValue].
				(result == self)
					ifFalse:
						[resultString _ result asString.
						pipeFromOutput nextPutAll: resultString.
						(resultString isEmpty not and:
							[(resultString last ~= Character cr) and:
								[resultString last ~= Character lf]])
						ifTrue: [pipeFromOutput nextPut: Character cr]]]
			ifFalse:
				[self fail].
		self closePipes.
		self complete]
! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/9/2002 19:44'!
output
	"Answer output contents."

	^ self outputHasBeenRedirected
		ifTrue: ['']
		ifFalse: [self pipeFromOutput upToEnd]
! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/9/2002 19:45'!
outputAndError
	"Answer an array with output and error contents. If standard error has been
	redirected to a file, answer a null string as the error message."

	| out err |
	out _ self output.
	(self errorHasBeenRedirected)
		ifTrue: [err _ '']
		ifFalse: [err _ errorPipelineStream contents].
	^ Array with: out with: err! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/9/2002 19:53'!
outputPipeForNextProxy

	^ self outputHasBeenRedirected
		ifTrue: [nil]
		ifFalse: [pipeFromOutput]
! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 9/18/2001 22:39'!
prepareOutputForPipe
	"Output stream will be used by another process proxy as input. Set output stream
	characteristics accordingly."
! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/4/2002 22:20'!
replaceOutputStreamWith: anotherStream
	"Sender is not happy with the kind of output stream we are using. Replace
	pipeFromOutput with anotherStream, and copy the current contents of pipeFromOutput
	to the new stream."

	| oldOutputStream |
	oldOutputStream _ self pipeFromOutput.
	self pipeFromOutput: anotherStream.
	oldOutputStream ifNotNil:
		[anotherStream ifNotNil:
			[anotherStream nextPutAll: oldOutputStream contents].
		oldOutputStream close]
! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/4/2002 22:24'!
setNonBlockingOutput
	"Check first to make sure process is not complete because pipeFromOutput will not respond
	to #setNonBlocking after the process has exited."

	self isComplete ifFalse: [pipeFromOutput setNonBlocking]! !

!PipeableEvaluator methodsFor: 'command pipelines' stamp: 'dtl 3/4/2002 22:20'!
| anotherCommandString
	"Pipe my output to another evaluator, where the other evaluator evaluates
	anotherCommandString."

	"((PipeableEvaluator command: 'Smalltalk')
		| 'stdout nextPutAll: stdin upToEnd'
		| 'stdout nextPutAll: stdin upToEnd') upToEnd"

	"(PipeableEvaluator command: 'BOGUS')
		| 'stdout nextPutAll: stdin upToEnd'
		| 'stdout nextPutAll: stdin upToEnd'"

	"((PipeableEvaluator command: '(true == false) not')
		| 'stdout nextPutAll: stdin upToEnd'
		| 'stdout nextPutAll: stdin upToEnd') upToEnd"

	| new |
	new _ self species
			command: anotherCommandString
			pipeFrom: self pipeFromOutput
			errorPipelineStream: self errorPipelineStream.
	self value.
	^ new
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 11/22/2001 23:59'!
errorUpToEnd
	"Answer all available characters from my error stream. If evaluation
	has not happened yet, do it now."

	self isComplete ifFalse: [self value].
	^ (errorPipelineStream isNil or: [self errorHasBeenRedirected])
		ifTrue:
			['']
		ifFalse:
			[errorPipelineStream upToEnd]
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 3/4/2002 22:25'!
next

	^ pipeFromOutput next
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 3/4/2002 22:25'!
next: count

	^ pipeFromOutput next: count
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 11/3/2001 08:38'!
nextFromError: count

	^ errorPipelineStream next: count
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 3/4/2002 20:34'!
nextPut: aCharacter
	"Write aCharacter to the standard input stream of my process."

	| readPosition |
	readPosition _ pipeToInput position.
	pipeToInput setToEnd nextPut: aCharacter.
	pipeToInput position: readPosition.
	^ pipeToInput
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 3/4/2002 20:34'!
nextPutAll: aCollection
	"Write aCollection to the standard input stream of my process."

	| readPosition |
	readPosition _ pipeToInput position.
	pipeToInput setToEnd nextPutAll: aCollection.
	pipeToInput position: readPosition.
	^ pipeToInput
! !

!PipeableEvaluator methodsFor: 'streaming' stamp: 'dtl 3/4/2002 22:25'!
upToEnd
	"Answer all available characters from my output. If evaluation has not
	happened yet, do it now."

	self isComplete ifFalse: [self value].
	^ self pipeFromOutput isNil
		ifTrue:
			['']
		ifFalse:
			[pipeFromOutput upToEnd]
! !

!PipeableEvaluator methodsFor: 'testing' stamp: 'dtl 11/22/2001 23:57'!
canProvideOutputPipe
	"Answer false if output has been redirected to a file and cannot be accessed by
	the next process proxy in a command pipeline."

	^ self outputHasBeenRedirected not
! !

!PipeableEvaluator methodsFor: 'testing' stamp: 'dtl 11/22/2001 23:55'!
errorHasBeenRedirected
	"Answer true if the error output has been redirected to an external file
	and is not available to be read as error output of a pipeline."

	^ self errorPipelineStream isKindOf: FileStream
! !

!PipeableEvaluator methodsFor: 'testing' stamp: 'dtl 3/4/2002 06:58'!
isComplete

	^ self runState == #complete! !

!PipeableEvaluator methodsFor: 'testing' stamp: 'dtl 3/4/2002 06:59'!
isNotYetRunning

	^ self runState == #notYetRunning! !

!PipeableEvaluator methodsFor: 'testing' stamp: 'dtl 12/22/2001 18:37'!
succeeded
	"Answer true if my evaluation completed successfully."

	^ self exitStatus == #success! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 12/8/2001 18:02'!
handleCompileErrorFor: aBlock
	"Evaluate aBlock. On error, put a message onto the error stream and declare failure."

	^ [aBlock value]
		on: Error
		do: [:e |
			self errorPipelineStream
				nextPutAll: 'Compiler: invalid Smalltalk expression', Character lf asString.
			self fail.
			nil]
! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 12/8/2001 17:35'!
handleRuntimeErrorFor: aBlock
	"Evaluate aBlock. On error, put a message onto the error stream and declare failure."

	^ [aBlock value]
		on: Error
		do: [:e |
			self errorPipelineStream nextPutAll: e description; nextPut: Character lf.
			self fail]
! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 4/7/2001 21:29'!
notify: aString at: aPosition in: aStream

	| s |
	s _ aStream contents.
	self errorPipelineStream
		nextPutAll: (s copyFrom: 1 to: (aPosition - 1));
		nextPutAll: aString;
		nextPutAll: (s copyFrom: aPosition to: s size);
		cr

! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 4/7/2001 21:27'!
selectFrom: start to: end

	^ self blockString copyFrom: start to: end! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 4/7/2001 19:50'!
selectionInterval
	"The compiler wants this for some reason."

	^ 1 to: 1! !

!PipeableEvaluator methodsFor: 'error handling' stamp: 'dtl 12/8/2001 18:13'!
text
	"The compiler needs this to generate error messages."

	^ Text fromString: self expression! !

!PipeableEvaluator methodsFor: 'printing' stamp: 'dtl 9/17/2001 22:22'!
printOn: aStream

	super printOn: aStream.
	self isComplete
		ifTrue: [aStream nextPutAll: ' (complete)']
		ifFalse: [aStream nextPutAll: ' (notYetRunning)']! !


!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 3/4/2002 07:18'!
block: aSimpleBlock

	"(PipeableEvaluator block: [#'This block answers a symbol as String']) value upToEnd"

	^ self block: aSimpleBlock
		pipeFrom: nil
! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 4/21/2001 09:32'!
block: aSimpleBlock pipeFrom: inputStream

	"(PipeableEvaluator
		block: [:input | input contents]
		pipeFrom: (ReadStream on: 'Here is some input text'))
			value upToEnd"

	^ self block: aSimpleBlock pipeFrom: inputStream errorPipelineStream: (WriteStream on: String new)! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 4/21/2001 09:33'!
block: aSimpleBlock pipeFrom: inputStream errorPipelineStream: errorStream

	^ self block: aSimpleBlock pipeFrom: inputStream pipeTo: nil errorPipelineStream: errorStream! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 4/21/2001 09:34'!
block: aSimpleBlock pipeFrom: inputStream pipeTo: outputStream errorPipelineStream: errorStream

	^ self block: aSimpleBlock pipeFrom: inputStream pipeTo: outputStream errorPipelineStream: errorStream withArgs: nil
! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 3/9/2002 17:32'!
block: aBlock pipeFrom: inputStream pipeTo: outputStream errorPipelineStream: errorStream withArgs: anArrayOfOtherArguments

	"(PipeableEvaluator
		block: [:in :out :err :stuff |
				out nextPutAll: in contents; cr.
				err nextPutAll: 'hello stderr'.
				stuff do: [:e | out nextPutAll: e; cr]]
		pipeFrom: (ReadStream on: 'Here is some input text')
		pipeTo: nil
		errorPipelineStream: nil
		withArgs: #(arg1 arg2 arg3))
			value upToEnd"

	^ super new
		evaluationBlock: aBlock;
		pipeToInput: inputStream;
		pipeFromOutput: outputStream;
		errorPipelineStream: errorStream;
		extraArguments: anArrayOfOtherArguments;
		notYetRunning;
		initialize! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 9/8/2001 17:04'!
command: aString

	"(PipeableEvaluator command: '''Hello world!!''') value upToEnd"

	^ self command: aString pipeFrom: nil errorPipelineStream: nil
! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 4/18/2001 20:47'!
command: aString pipeFrom: inputStream errorPipelineStream: errorStream

	"(PipeableEvaluator
		command: 'stdout nextPutAll: stdin upToEnd'
		pipeFrom: (ReadStream on: 'Here is some input text')
		errorPipelineStream: (WriteStream on: ''))
			value upToEnd"

	^ self command: aString pipeFrom: inputStream pipeTo: nil errorPipelineStream: errorStream! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 3/9/2002 17:33'!
command: aString pipeFrom: inputStream pipeTo: outputStream errorPipelineStream: errorStream

	"(PipeableEvaluator
		command: 'stdout nextPutAll: stdin contents'
		pipeFrom: (ReadStream on: 'Here is some input text')
		pipeTo: nil
		errorPipelineStream: (WriteStream on: ''))
			value upToEnd"

	^ super new
		expression: aString;
		pipeToInput: inputStream;
		pipeFromOutput: outputStream;
		errorPipelineStream: errorStream;
		notYetRunning;
		initialize! !

!PipeableEvaluator class methodsFor: 'instance creation' stamp: 'dtl 3/9/2002 17:33'!
command: aString pipeFrom: inputStream pipeTo: outputStream errorPipelineStream: errorStream withArgs: anArrayOfOtherArguments

	"(PipeableEvaluator
		command: 'stdout nextPutAll: stdin contents; cr. ',
				'stderr nextPutAll: ''hello stderr''. ',
				'args do: [:arg | stdout nextPutAll: arg; cr]'
		pipeFrom: (ReadStream on: 'Here is some input text')
		pipeTo: nil
		errorPipelineStream: (WriteStream on: '')
		withArgs: #(this is a test))
			value upToEnd"

	^ super new
		expression: aString;
		pipeToInput: inputStream;
		pipeFromOutput: outputStream;
		errorPipelineStream: errorStream;
		extraArguments: anArrayOfOtherArguments;
		notYetRunning;
		initialize! !

!PipeableEvaluator class methodsFor: 'defaults' stamp: 'dtl 12/17/2001 11:35'!
defaultSyntaxClass

	^ ShellSyntax! !


!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/26/2002 17:47'!
createErrorPipe
	"Create a pipe for the error stream from the child process."

	pipeFromError _ OSPipe nonBlockingPipe
! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/26/2002 17:47'!
createInputPipe
	"Create a pipe for input to the child process."

	pipeToInput _ OSPipe blockingPipe
! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/26/2002 17:47'!
createOutputPipe
	"Create a pipe for output from the child process."

	pipeFromOutput _ OSPipe nonBlockingPipe
! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/26/2002 19:03'!
createPipes

	pipeToInput ifNil: [self createInputPipe].
	pipeFromOutput ifNil: [self createOutputPipe].
	pipeFromError ifNil: [self createErrorPipe]
! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/27/2002 09:11'!
finalize

	processProxy ifNotNil: [processProxy removeDependent: self].
	self close! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 2/27/2002 22:48'!
handlePrecedingError
	"The stderr stream has been redirected. If there are any characters in the
	errorPipelineStream, write them to the stderr stream before proceeding. Fork
	a process to keep reading any additional error messages from preceding
	processes, and write them to the redirected error. When done, close the redirected
	error stream (this does not affect the actual external process, which has its own
	file handle on the error stream). A background process is used to copy the
	errorPipelineStream because it is not straightforward to attach all predecessor
	proxies in a command pipeline to the redirected error output. This design is
	kludgy, but it works."

	| d |
	d _ Delay forMilliseconds: 200.
	self setKeepInitialStdErrOpen.
	Processor yield.	"A chance to clean up predecessor proxies in command pipeline"
	errorPipelineStream ifNotNil:
			[processProxy initialStdErr nextPutAll: errorPipelineStream upToEnd.
			[[self isRunning or: [self isNotYetRunning]]
				whileTrue:
					[processProxy initialStdErr nextPutAll: errorPipelineStream upToEnd.
					d wait].
				self keepInitialStdErrOpen ifFalse: [processProxy initialStdErr close]] fork]
! !

!PipeableOSProcess methodsFor: 'initialize - release' stamp: 'dtl 3/10/2002 08:19'!
initialize
	"Semaphore to protect against finalizing the output and error streams
	while they are being read."

	accessProtect _ Semaphore forMutualExclusion
! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 10/12/2001 12:22'!
closeOutputOnExit

	^ closeOutputOnExit ifNil: [closeOutputOnExit _ true]
! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 10/12/2001 12:22'!
closeOutputOnExit: trueOrFalse

	closeOutputOnExit _ trueOrFalse
! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 12/3/2001 21:11'!
keepInitialStdErrOpen
	"True if stderr has been redirected and the handle must be kept open in case
	a predecessor in a command pipeline might have more error messages to write
	to the redirected error stream."

	^ keepInitialStdErrOpen ifNil: [keepInitialStdErrOpen _ false]! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 12/3/2001 21:11'!
keepInitialStdErrOpen: trueOrFalse
	"True if stderr has been redirected and the handle must be kept open in case
	a predecessor in a command pipeline might have more error messages to write
	to the redirected error stream."

	keepInitialStdErrOpen _ trueOrFalse! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 1/20/2001 17:14'!
pipeFromError

	^ pipeFromError! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 1/20/2001 17:14'!
pipeFromError: aPipeStream

	pipeFromError _ aPipeStream! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 3/3/2002 13:44'!
processProxy
	"An internal evaluation proxy, or an external OS process proxy."

	^ processProxy! !

!PipeableOSProcess methodsFor: 'accessing' stamp: 'dtl 2/27/2002 09:11'!
processProxy: aProxy
	"An internal evaluation proxy, or an external OS process proxy. Add myself as
	a dependent of aProxy in order to receive notification when the process run
	state changes."

	aProxy addDependent: self.
	processProxy _ aProxy! !

!PipeableOSProcess methodsFor: 'evaluating' stamp: 'dtl 2/27/2002 14:46'!
exec: aString
	"Pass aString to the child for execution. Presumably the child is running a
	command processor of some kind, such as a Unix shell."

	processProxy isRunning
		ifTrue:
			[self nextPutAll: aString;
			nextPut: Character lf;
			flush]
		ifFalse: [self notify: 'child process not running']


! !

!PipeableOSProcess methodsFor: 'evaluating' stamp: 'dtl 2/28/2002 11:06'!
value
	"Start the external process"

	| p |
	self errorHasBeenRedirected ifTrue: [self handlePrecedingError].
	p _ processProxy ifNotNil: [processProxy value].
	"The external child process now owns its own copy of the pipe handles. We no
	longer need our copies of these handles, so close the ones that are not needed."
	p ifNotNil:
		[p closeInitialStdIn.
		p closeInitialStdOut.
		self keepInitialStdErrOpen ifFalse: [p closeInitialStdErr]].
	^ p! !

!PipeableOSProcess methodsFor: 'child process termination' stamp: 'dtl 2/25/2001 13:09'!
close
	"Close pipe to child stdin."

	(pipeToInput notNil and: [pipeToInput closed not])
		ifTrue: [pipeToInput close]
! !

!PipeableOSProcess methodsFor: 'child process termination' stamp: 'dtl 3/10/2002 08:18'!
closePipes
	"Replace the output and error pipe streams with internal pipes, and close
	all input and output pipes."

	| output |
	self closeOutputOnExit
		ifTrue:
			[(output _ self pipeFromOutput)
				ifNotNil:
					[accessProtect critical:
						[self pipeFromOutput: InternalPipe new.
						self pipeFromOutput nextPutAll: output upToEnd.
						self pipeFromOutput closeWriter.
						output close]]]
		ifFalse:
			["The pipe stream will be closed by the next process in the command pipeline"].
	(pipeFromError) ifNotNil:
		[accessProtect critical:
			[self addToErrorPipeline: pipeFromError upToEnd.
			pipeFromError close]].
	self keepInitialStdErrOpen ifTrue: [self processProxy initialStdErr close].
	self pipeToInput ifNotNil: [pipeToInput close]
! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 3/3/2001 18:43'!
addToErrorPipeline: aString

	(aString notNil
		and: [aString size ~= 0])
			ifTrue:
				[self errorPipelineStream nextPutAll: aString]! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 12/3/2001 20:42'!
errorPipelineContents

	^ self errorHasBeenRedirected
		ifTrue: ['' "stderr has been redirected to a file"]
	 	ifFalse: [self errorPipelineStream contents]! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 3/4/2001 18:35'!
output
	"Wait for external process to exit, then answer the contents of its output stream.
	This is intended as notation for completing an external command pipeline."

	"((PipeableProcess command: 'ps') | 'grep squeak' | 'cut -c16-100') output"

	^ self outputWithErrorNotifier: false
! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 2/27/2002 16:01'!
outputAndError
	"Wait for external process to exit, then answer the contents of its output stream
	and its accumulated error stream. This is intended as notation for completing an
	external command pipeline."

	"((PipeableProcess command: 'ps') | 'NoSuchCommand; grep squeak' | 'cut -c16-100') outputAndError"

	| d s |
	d _ Delay forMilliseconds: 50.
	s _ WriteStream on: ''.
	s nextPutAll: self upToEnd.
	[processProxy runState == #complete]
		whileFalse:
			[d wait.
			s nextPutAll: self upToEnd].
	^ Array with: s contents with: self errorPipelineContents! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 2/27/2002 14:40'!
outputWithErrorNotifier: aBoolean
	"Wait for external process to exit, then answer the contents of its output stream.
	This is intended as notation for completing an external command pipeline."

	| d s |
	d _ Delay forMilliseconds: 50.
	s _ WriteStream on: ''.
	s nextPutAll: self upToEnd.
	[self processProxy runState == #complete]
		whileFalse:
			[d wait.
			s nextPutAll: self upToEnd].
	aBoolean ifTrue: [self notifyError].
	^ s contents! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 3/4/2001 18:38'!
outputWithNotifier
	"Wait for external process to exit, then answer the contents of its output stream.
	This is intended as notation for completing an external command pipeline."

	"((PipeableProcess command: 'ps') | 'grep squeak' | 'cut -c16-100; SNAFU') outputWithNotifier"
	"((PipeableProcess command: 'ps; SNAFU') | 'grep squeak' | 'cut -c16-100') outputWithNotifier"

	^ self outputWithErrorNotifier: true
! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 12/3/2001 23:49'!
prepareOutputForPipe
	"Output stream will be used by another process proxy as input. Set output stream
	characteristics accordingly."

	self setKeepOutputOpen; setBlockingOutput
! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 2/28/2002 07:57'!
replaceOutputStreamWith: anotherStreamOrNil
	"Sender is my successor in a command pipeline."

	processProxy isNotYetRunning
		ifFalse:
			[self error: 'too late to change the output now'].
	anotherStreamOrNil isNil
		ifFalse:
			[processProxy initialStdOut: anotherStreamOrNil.
			self pipeFromOutput: nil "Not accessible any more"]
		ifTrue:
			["Sender is my successor in a command pipeline, but does not want to use
			my standard output. Therefore, dump my standard output to the null device."
			pipeFromOutput
				ifNotNil:
					[pipeFromOutput close.
					self pipeFromOutput: nil].
			processProxy initialStdOut: self nullStream]
! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 12/3/2001 23:52'!
setKeepInitialStdErrOpen
	"Send this message if stderr has been redirected and the handle must be kept open in
	case a predecessor in a command pipeline might have more error messages to write
	to the redirected error stream."

	self keepInitialStdErrOpen: true! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 12/3/2001 23:49'!
setKeepOutputOpen
	"When child exits, do not close the output pipe. This is for an output pipe connected to
	another process in a pipeline, where it is assumed that the next process will close
	the pipe when it is done reading from it."

	closeOutputOnExit _ false! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 3/3/2002 09:52'!
setNonBlockingOutput
	"Check first to make sure process is not complete because pipeFromOutput will not respond
	to #setNonBlocking after the process has exited."

	self isComplete ifFalse: [pipeFromOutput setNonBlocking]! !

!PipeableOSProcess methodsFor: 'command pipelines' stamp: 'dtl 12/3/2001 23:49'!
| anotherCommandString
	"Pipe my output to another external process, where the other external process
	executes anotherCommandString."

	"Potential timing problem: If this child process exits and completes its #update: before
	receiving the #setKeepOutputOpen message here, the pipeline will not work. It is not
	clear to me if this can actually happen in practice."

	"(PipeableProcess command: 'ps') | 'grep squeak' | 'cut -c16-100'"

	self setKeepOutputOpen.
	self setBlockingOutput.
	^ self species
			command: anotherCommandString
			pipeFrom: pipeFromOutput reader
			errorPipelineStream: self errorPipelineStream
! !

!PipeableOSProcess methodsFor: 'shell support' stamp: 'dtl 10/13/2001 11:33'!
needsPrompt
	"After evaluating the command, a shell will want to issue a prompt"

	^ true
! !

!PipeableOSProcess methodsFor: 'shell support' stamp: 'dtl 10/13/2001 11:33'!
nullStream

	^ FileStream oldFileNamed: '/dev/null'
! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 3/10/2002 09:09'!
errorUpToEnd
	"Answer all available characters from the error stream of my external process."

	^ accessProtect critical:
		[self addToErrorPipeline: (pipeFromError upToEnd).
		self errorHasBeenRedirected
			ifTrue: ['']
			ifFalse: [self errorPipelineStream upToEnd]]
! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 2/25/2001 10:30'!
flush
	"Flush output to the standard input stream of my external process."

	(pipeToInput notNil and: [pipeToInput closed not])
		ifTrue: [pipeToInput flush]! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 10/27/2001 12:04'!
next
	"Answer the next character from the output stream of my external process,
	or nil if no data is available."

	| s |
	s _ accessProtect critical: [pipeFromOutput ifNotNil: [pipeFromOutput next]].
	^ s! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 10/27/2001 12:04'!
next: count
	"Answer up to count characters from the output stream of my external process,
	or an empty string if no data is available."

	| s |
	s _ accessProtect critical: [pipeFromOutput ifNotNil: [pipeFromOutput next: count]].
	^ s! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 3/9/2002 18:28'!
nextFromError: count
	"Answer up to count characters from the error stream of my external process,
	or an empty string if no data is available. All characters are routed through
	the errorPipelineStream, so that they are concatenated with any preceeding
	error message text (possibly from a preceeding process in a command pipeline)."

	accessProtect critical:
		[pipeFromError ifNotNil:
			[self addToErrorPipeline: (pipeFromError next: count)]].
	^ self errorHasBeenRedirected
		ifTrue: [nil]
		ifFalse: [self errorPipelineStream next: count]
! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 1/21/2001 13:25'!
nextPut: aCharacter
	"Write aCharacter to the standard input stream of my external process."

	^ pipeToInput nextPut: aCharacter! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 1/21/2001 13:26'!
nextPutAll: characters
	"Write characters to the standard input stream of my external process."

	^ pipeToInput nextPutAll: characters! !

!PipeableOSProcess methodsFor: 'streaming' stamp: 'dtl 4/16/2001 22:23'!
upToEnd
	"Answer all available characters from the output of my external process."

	| s |
	s _ accessProtect critical:
		[pipeFromOutput isNil
			ifTrue: ['']
			ifFalse: [pipeFromOutput upToEnd]].
	^ s! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 12/3/2001 20:48'!
errorHasBeenRedirected
	"Answer true if the error output has been redirected to an external file
	and is not available to be read as error output of a pipeline."

	^ self pipeFromError isNil
! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 2/27/2002 15:32'!
isComplete

	^ processProxy isComplete! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 3/9/2002 18:17'!
isExternalProcess
	"Answer true if the process which I represent is an external OSProcess."

	^ true! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 2/27/2002 22:50'!
isNotYetRunning

	^ processProxy isNotYetRunning! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 2/27/2002 22:50'!
isRunning

	^ processProxy isRunning! !

!PipeableOSProcess methodsFor: 'testing' stamp: 'dtl 2/27/2002 22:51'!
succeeded

	^ processProxy succeeded! !

!PipeableOSProcess methodsFor: 'updating' stamp: 'dtl 2/27/2002 09:14'!
update: aParameter
	"Clean up after processProxy exits. Remove myself as a dependent of processProxy,
	and close pipes."

	super update: aParameter.
	(aParameter == #runState and: [processProxy isComplete])
		ifTrue:
			[processProxy removeDependent: self.
			self closePipes]
! !

!PipeableOSProcess methodsFor: 'printing' stamp: 'dtl 3/3/2002 21:22'!
printOn: aStream

	super printOn: aStream.
	aStream nextPutAll: ' for '.
	self processProxy printOn: aStream
! !

!PipeableOSProcess methodsFor: 'private' stamp: 'dtl 3/11/2002 18:52'!
notifyError
	"Display a notifier if child exited with non-zero status, or if any of its predecessors
	in a command pipeline left error text in the errorPipeline."

	| errText |
	self isComplete ifTrue: [
		errText _ self errorPipelineContents.
		(errText size ~= 0)
			ifTrue:
				[self inform:
					self programName, ' exit status ',
					processProxy exitStatus printString, ', error message: ',
					errText]
			ifFalse:
				[(processProxy exitStatus ~= 0)
					ifTrue:
						[self inform:
							self programName, ' exit status ',
							processProxy exitStatus printString]]]
! !

!PipeableOSProcess methodsFor: 'private' stamp: 'dtl 9/12/2001 20:07'!
setBlockingOutput
	"Set the pipe from the child stdout to blocking mode. This is the normal
	mode for a pipe, although for Squeak we set pipe outputs to nonblocking
	to protect ourselves from blocking the Squeak VM when reading from
	a pipe. Unix command pipelines use the normal blocking behavior, and
	let the operating system timeslice the processes to keep the rest of the
	world from hanging on a blocked read."

	pipeFromOutput ifNotNil: [OSProcess accessor setBlocking: self pipeFromOutput reader ioHandle]
! !

!PipeableOSProcess methodsFor: 'private' stamp: 'dtl 3/11/2002 18:48'!
unixFileNumbers
	"Utility method for debugging. Answer the Unix file numbers for the streams
	associated with this instance. This may be useful for debugging file handle
	leaks (files or sockets being opened but never closed).

	When a process proxy is initially set up, it will normally have six file
	numbers associated with it prior to forking the child (two file numbers each
	for stdin, stdout, and stderr). Once the child is forked, the process proxy in
	Squeak will close its copies of the child ends of the pipes, so only three of
	the original six file numbers remain visible to Squeak."

	"(PipeableOSProcess command: 'who') unixFileNumbers"

	"(PipeableOSProcess new: '/bin/ls'
		arguments: #('-ls' 'hosts' 'NOSUCHFILE') environment: nil
		descriptors: nil workingDir: '/etc'
		errorPipelineStream: ((WriteStream on: '')
		nextPutAll: 'this is the error stream '; yourself)) unixFileNumbers"

	| d |
	d _ Dictionary new.
	d at: #initialStdIn put: (OSProcess accessor unixFileNumber: processProxy initialStdIn ioHandle).
	d at: #initialStdOut put: (OSProcess accessor unixFileNumber: processProxy initialStdOut ioHandle).
	d at: #initialStdErr put: (OSProcess accessor unixFileNumber: processProxy initialStdErr ioHandle).
	d at: #'pipeToInput writer'
		put: (OSProcess accessor unixFileNumber: pipeToInput writer ioHandle).
	d at: #'pipeFromOutput reader'
		put: (OSProcess accessor unixFileNumber: pipeFromOutput reader ioHandle).
	d at: #'pipeFromError reader'
		put: (OSProcess accessor unixFileNumber: pipeFromError reader ioHandle).
	^ d
! !


!PipeableOSProcess class methodsFor: 'instance creation' stamp: 'dtl 3/4/2002 07:24'!
forkAndExec: executableFile arguments: arrayOfStrings environment: stringDictionary descriptors: arrayOf3Streams workingDir: pathString errorPipelineStream: anErrorStream
	"Run a program in an external OS process, and answer an instance of myself
	which represents the external process."

	"PipeableOSProcess forkAndExec: '/bin/ls' arguments: #('-ls' 'hosts' 'NOSUCHFILE') environment: nil descriptors: nil workingDir: '/etc' errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself)"

	OSProcess accessor canAccessSystem
		ifFalse:
			[self inform: OSProcess accessor class name, ' cannot access system'.
			^ nil].
	^ (self new: executableFile
		arguments: arrayOfStrings
		environment: stringDictionary
		descriptors: arrayOf3Streams
		workingDir: pathString
		errorPipelineStream: anErrorStream) value; yourself
! !

!PipeableOSProcess class methodsFor: 'instance creation' stamp: 'dtl 3/4/2002 07:24'!
new: executableFile arguments: arrayOfStrings environment: stringDictionary descriptors: arrayOf3Streams workingDir: pathString errorPipelineStream: anErrorStream
	"Prepare to run a program in an external OS process, and answer an instance of
	myself which will represent the external process."

	"PipeableOSProcess new: '/bin/ls' arguments: #('-ls' 'hosts' 'NOSUCHFILE') environment: nil descriptors: nil workingDir: '/etc' errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself)"

	| pp proc s |
	pp _ super new.
	proc _ self externalProxyClass
			programName: executableFile
			arguments: arrayOfStrings
			initialEnvironment: stringDictionary.
	arrayOf3Streams isNil
		ifTrue:
			[pp createPipes.
			proc initialStdIn: pp pipeToInput reader.
			proc initialStdOut: pp pipeFromOutput writer.
			proc initialStdErr: pp pipeFromError writer]
		ifFalse:
			[(s _ (arrayOf3Streams at: 1)) isNil
				ifTrue:
					[pp createInputPipe.
					proc initialStdIn: pp pipeToInput reader]
				ifFalse:
					[proc initialStdIn: s].
			(s _ (arrayOf3Streams at: 2)) isNil
				ifTrue:
					[pp createOutputPipe.
					proc initialStdOut: pp pipeFromOutput writer]
				ifFalse:
					[proc initialStdOut: s].
			(s _ (arrayOf3Streams at: 3)) isNil
				ifTrue:
					[pp createErrorPipe.
					proc initialStdErr: pp pipeFromError writer]
				ifFalse:
					[proc initialStdErr: s]].
	pathString ifNotNil: [proc pwd: pathString].
	pp errorPipelineStream: anErrorStream.
	pp initialize.
	proc initialize.
	^ pp processProxy: proc
! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:24'!
command: aString

	"(PipeableOSProcess command: '/bin/echo this is a test') output"
	"(PipeableOSProcess command: 'echo this is a test') output"
	"(PipeableOSProcess command: '/bin/noSuchCommand this is a test') output"
	"(PipeableOSProcess command: 'ls -l Sq*log') output"
	"(PipeableOSProcess command: 'ls -l ?q*log') output"
	"(PipeableOSProcess command: '/bogusDirectory/ls -l Sq*log') output"

	^ self command: aString
		environment: nil
		workingDir: nil
		input: nil
		output: nil
		error: nil
		errorPipelineStream: nil! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:24'!
command: aString environment: anEnvironmentDictionary workingDir: pathString input: inputStream output: outputStream error: errorStream

	"PipeableOSProcess command: 'sleep 6' environment: nil workingDir: '/etc' input: nil output: nil error: nil"
	"(PipeableOSProcess command: 'ls -l' environment: nil workingDir: '/etc' input: nil output: nil error: nil) output"

	^ self command: aString
		environment: anEnvironmentDictionary
		workingDir: pathString
		input: inputStream
		output: outputStream
		error: errorStream
		errorPipelineStream: nil
! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:24'!
command: aString environment: anEnvironmentDictionary workingDir: pathString input: inputStream output: outputStream error: errorStream errorPipelineStream: anErrorWriteStream

	"(PipeableOSProcess command: 'ls -l hosts NOSUCHFILE' environment: nil workingDir: '/etc' input: nil output: nil error: nil errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself)) output"

	^ self command: aString
		environment: anEnvironmentDictionary
		workingDir: pathString
		input: inputStream
		output: outputStream
		error: errorStream
		errorPipelineStream: anErrorWriteStream
		shellSyntax: nil
! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:24'!
command: aString environment: anEnvironmentDictionary workingDir: pathString input: inputStream output: outputStream error: errorStream errorPipelineStream: anErrorWriteStream shellSyntax: aSyntaxProcessor

	"(PipeableOSProcess command: 'ls -l hosts NOSUCHFILE' environment: nil workingDir: '/etc' input: nil output: nil error: nil errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself) shellSyntax: nil) output"

	| nameAndArgs |
	aSyntaxProcessor isNil
		ifTrue:
			[nameAndArgs _ Array
				with: self externalProxyClass defaultShellPath
				with: (Array with: '-c' with: aString)]
		ifFalse:
			[nameAndArgs _ aSyntaxProcessor
				programNameAndArgumentsFrom: aString
				inDirectoryPath: pathString].
	^ self
		forkAndExec: (nameAndArgs at: 1)
		arguments: (nameAndArgs at: 2)
		environment: anEnvironmentDictionary
		descriptors: (Array with: inputStream with: outputStream with: errorStream)
		workingDir: pathString
		errorPipelineStream: anErrorWriteStream

! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 4/28/2001 12:04'!
command: aCommandString pipeFrom: aPipeStream errorPipelineStream: anErrorStream
	"Run a command in a shell process. Similar to the system(3) call in the standard C library,
	except that aCommandString runs asynchronously in a child process."

	^ self
		command: aCommandString
		environment: nil
		workingDir: nil
		input: aPipeStream
		output: nil
		error: nil
		errorPipelineStream: anErrorStream! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:25'!
commandNoEvaluate: aString environment: anEnvironmentDictionary workingDir: pathString input: inputStream output: outputStream error: errorStream errorPipelineStream: anErrorWriteStream
	"Set up the command but do not actually fork the child process."

	"PipeableOSProcess commandNoEvaluate: 'ls -l hosts NOSUCHFILE' environment: nil workingDir: '/etc' input: nil output: nil error: nil errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself)"

	 ^ self commandNoEvaluate: aString
		environment: anEnvironmentDictionary
		workingDir: pathString
		input: inputStream
		output: outputStream
		error: errorStream
		errorPipelineStream: anErrorWriteStream
		shellSyntax: nil
! !

!PipeableOSProcess class methodsFor: 'external command processing' stamp: 'dtl 3/4/2002 07:25'!
commandNoEvaluate: aString environment: anEnvironmentDictionary workingDir: pathString input: inputStream output: outputStream error: errorStream errorPipelineStream: anErrorWriteStream shellSyntax: aSyntaxProcessor
	"Set up the command but do not actually fork the child process."

	"PipeableOSProcess commandNoEvaluate: 'ls -l hosts NOSUCHFILE' environment: nil workingDir: '/etc' input: nil output: nil error: nil errorPipelineStream: ((WriteStream on: '') nextPutAll: 'this is the error stream '; yourself) shellSyntax: nil"

	| nameAndArgs |
	aSyntaxProcessor isNil
		ifTrue:
			[nameAndArgs _ Array
				with: self externalProxyClass defaultShellPath
				with: (Array with: '-c' with: aString)]
		ifFalse:
			[nameAndArgs _ aSyntaxProcessor
				programNameAndArgumentsFrom: aString
				inDirectoryPath: pathString].
	^ self
		new: (nameAndArgs at: 1)
		arguments: (nameAndArgs at: 2)
		environment: anEnvironmentDictionary
		descriptors: (Array with: inputStream with: outputStream with: errorStream)
		workingDir: pathString
		errorPipelineStream: anErrorWriteStream

! !

!PipeableOSProcess class methodsFor: 'process proxy classes' stamp: 'dtl 3/3/2002 15:31'!
externalProxyClass

	^ ExternalOSProcess concreteClass! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 2/27/2002 14:48'!
bash
	"Start a Gnu bash command interpreter (enhanced Unix shell)"

	"self bash"

	^ self command: self externalProxyClass bashShellPath! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 2/27/2002 14:52'!
remoteShell: remoteSystemName 
	"Start a remote Unix shell on another computer"

	"self remoteShell: 'localhost'"

	^ self
		forkAndExec: self externalProxyClass remoteShellPath
		arguments: (Array with: remoteSystemName with: 'sh')
		environment: nil
		descriptors: nil
		workingDir: nil
		errorPipelineStream: nil
! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 2/27/2002 14:46'!
shell
	"Start a Unix shell"

	"self shell"

	^ self command: self externalProxyClass defaultShellPath! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 3/4/2002 07:25'!
waitForCommand: aCommandString
	"Run a command in a shell process. Similar to the system(3) call in the standard C library.
	The active Smalltalk process waits for completion of the external command process. This just
	uses a simple polling loop, which is not very elegant but works well enough for most purposes."

	"PipeableOSProcess waitForCommand: 'echo sleeping...; sleep 3; echo I just slept for three seconds'"

	| proc d |
	d _ Delay forMilliseconds: 50.
	proc _ self command: aCommandString.
	proc ifNil: [self class noAccessorAvailable].
	[proc runState == #complete] whileFalse: [d wait].
	^ proc
! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 2/25/2001 10:48'!
wish
	"Start a Tk/Tcl command interpreter"

	^ self command: self tkShellPath! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 3/4/2002 07:25'!
xon: remoteSystem command: aCommandString
	"Convenience method for running an X program on a remote system and displaying its window
	on the local display."

	"PipeableOSProcess xon: 'micron' command: 'xeyes'"

	^ self command: 'xon ', remoteSystem, ' ', aCommandString
! !

!PipeableOSProcess class methodsFor: 'utility' stamp: 'dtl 3/4/2002 07:25'!
xterm: aCommandString
	"Convenience method for running a command in an external xterm window"

	"PipeableOSProcess xterm: 'top -d 2'"

	^ self command: 'xterm -T ''', aCommandString, ''' -e ', aCommandString! !

!PipeableOSProcess class methodsFor: 'examples' stamp: 'dtl 3/4/2002 07:25'!
remoteShellExample: remoteUnixHostName
	"Start a shell on another computer using rsh, and answer the the output
	of some commands on the remote host. You must have security access to
	the remote system in order for this to work."

	"PipeableOSProcess remoteShellExample: 'micron'"
	"PipeableOSProcess remoteShellExample: 'minnow.cc.gatech.edu'"
	"PipeableOSProcess remoteShellExample: 'localhost'"

	| rsh |
	rsh _  self remoteShell: remoteUnixHostName.
	rsh exec: 'echo remote host name is '.
	rsh exec: 'hostname'.
	rsh exec: 'exit'.
	rsh close.
	^ rsh output

! !

!PipeableOSProcess class methodsFor: 'examples' stamp: 'dtl 3/4/2002 07:25'!
tkExample
	"Start an interactive Tk shell and send it some commands to display a user interface."

	"PipeableOSProcess tkExample"

	| wish |
	wish _  self wish.
	[wish
		exec: 'button .b1 -text "This is button b1"';
		exec: 'button .b2 -text "This is button b2"';
		exec: 'button .exit -text Exit -command exit';
		exec: 'pack .b1 .b2 .exit'] fork.
	^ wish
! !

!PipeableOSProcess class methodsFor: 'examples' stamp: 'dtl 3/4/2002 07:21'!
unixCommandPipeLine
	"Run a pipeline of commands in a manner similar to Unix command shell
	usage, and answer the result as a string."

	"PipeableOSProcess unixCommandPipeLine"

	^ ((PipeableOSProcess command: 'ps') | 'grep squeak' | 'cut -c16-100') output! !


!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/31/2001 20:08'!
helpSelector

	^ helpSelector! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/31/2001 20:08'!
helpSelector: aSymbol

	helpSelector _ aSymbol! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/26/2001 19:54'!
name

	^ name! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/26/2001 19:54'!
name: aString

	name _ aString! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/27/2001 01:24'!
needsPrompt
	"True if the command should be followed by a prompt"

	^ needsPrompt ifNil: [needsPrompt _ true]! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/27/2001 01:22'!
needsPrompt: trueOrFalse
	"True if the command should be followed by a prompt"

	needsPrompt _ trueOrFalse! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/31/2001 20:09'!
procedureSelector

	^ procedureSelector! !

!ShellBuiltin methodsFor: 'accessing' stamp: 'dtl 12/31/2001 20:09'!
procedureSelector: aSymbol

	procedureSelector _ aSymbol! !


!ShellBuiltin class methodsFor: 'instance creation' stamp: 'dtl 1/4/2002 21:28'!
name: aString help: helpSelector procedure: procedureSelector needsPrompt: trueOrFalse
	"Command definition methods use this method to create instances representing
	shell builtin commands. The commands are installed in a CommandShell, and
	later evaluated in the context of a PipeableEvaluator."

	^ self new
		name: aString;
		helpSelector: helpSelector;
		procedureSelector: procedureSelector;
		needsPrompt: trueOrFalse
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:34'!
cd: commandShell
	"Define command to set the current working directory. Answer an empty string
	or #invalidCommand."

	^ self name: 'cd'
		help: #cdHelp
		procedure: #cdCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:34'!
clear: commandShell
	"Define command to clear the terminal display screen. Answer a string or an invalid
	command message."

	^ self name: 'clear'
		help: #clearHelp
		procedure: #clearCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:34'!
copyToError: commandShell
	"Define command to copy the contents of (argArray at: 1) or stdin onto
	stderr. This command exists only for purposes of testing stdin and pipelines
	for PipeableEvaluator proxies."

	^ self name: 'copyToError'
		help: nil
		procedure: #copyToErrorCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:34'!
copyToOutput: commandShell
	"Define command to  copy the contents of (argArray at: 1) or stdin onto
	stdout. This command exists only for purposes of testing stdin and pipelines
	for PipeableEvaluator proxies."

	^ self name: 'copyToOutput'
		help: nil
		procedure: #copyToOutputCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:34'!
edit: commandShell
	"Define command to open an editor on each of the named files."

	^ self name: 'edit'
		help: #editHelp
		procedure: #editCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 19:35'!
exit: commandShell
	"Define command to exit the shell window. Answer a string or an invalid
	command message."

	^ self name: 'exit'
		help: #exitHelp
		procedure: #exitCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:20'!
fc: commandShell
	"Define 'fix command' command. If argArray is emply, answer the last
	command in the history list. If there is one argument, interpret it as an
	integer index into the history list. Otherwise answer an invalid command
	message."

	^ self name: 'fc'
		help: #fcHelp
		procedure: #fcCommand:input:output:error:arguments:
		needsPrompt: false
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:21'!
help: commandShell
	"Define command to display help messages."

	^ self name: 'help'
		help: #helpHelp
		procedure: #helpCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:21'!
history: commandShell
	"Define command to display the command history list."

	^ self name: 'history'
		help: #historyHelp
		procedure: #historyCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:22'!
inspect: commandShell
	"Define command to open a Smalltalk inspector on the contents of stdin, or the
	file(s) named on the command line."

	^ self name: 'inspect'
		help: #inspectHelp
		procedure: #inspectCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:22'!
pwd: commandShell
	"Define command to answer the current working directory (a string) or an
	invalid command message."

	^ self name: 'pwd'
		help: #pwdHelp
		procedure: #pwdCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:22'!
sls: commandShell
	"Define command to for a simple directory contents lister"

	^ self name: 'sls'
		help: #slsHelp
		procedure: #slsCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:22'!
sqsh: commandShell
	"Define command to open a new shell window."

	^ self name: 'sqsh'
		help: #sqshHelp
		procedure: #sqshCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'command definition' stamp: 'dtl 1/3/2002 21:22'!
type: commandShell
	"Define command to answer how each name would be interpreted if used as a
	command name."

	^ self name: 'type'
		help: #typeHelp
		procedure: #typeCommand:input:output:error:arguments:
		needsPrompt: true
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/4/2002 21:24'!
cdCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Set the current working directory. Answer an empty string or #invalidCommand."

	| newPath path arg pathCwd p |
	argArray size == 0
		ifTrue:
			[newPath _ commandShell home]
		ifFalse:
			[argArray size == 1
				ifTrue:
					[path _ argArray at: 1.
					(path = commandShell shellSyntax pathStringAboveRoot)
						ifTrue:
							[newPath _ commandShell shellSyntax pathAboveRoot]
						ifFalse:
							[pathCwd _ commandShell shellSyntax getCwdForPath: path.
							arg _ (path = FileDirectory slash)
								ifTrue: [path]
								ifFalse: [commandShell shellSyntax
												expandArgument: path
												inDirectoryPath: pathCwd].
							newPath _ arg isEmpty
								ifTrue: [arg]
								ifFalse:
									[p _ commandShell newDirPath: arg from: pathCwd.
									p ifNotNil: [FileDirectory default fullNameFor: p]]]]
				ifFalse:
					[^ commandShell invalidCommandMessage]].
	newPath isNil
		ifTrue:
			["No directory found with this name"
			stderr nextPutAll: argArray first, ': no such file or directory'; nextPut: Character lf]
		ifFalse:
			[(commandShell workingDirectory ~= newPath)
				ifTrue:
					[(newPath isEmpty or: [commandShell isADirectory: newPath])
						ifTrue:
							[commandShell workingDirectory: newPath.
							commandShell changed: #relabel.
							commandShell environment ifNotNil:
								[commandShell environment at: #PWD put: commandShell workingDirectory]]
						ifFalse:
							["File of this name exists, but is not a directory"
							stderr nextPutAll: newPath, ': not a directory'; nextPut: Character lf]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:28'!
clearCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Clear the terminal display screen. Answer a string or an invalid command message."

	argArray size == 0 ifFalse: [^ commandShell invalidCommandMessage].
	commandShell terminateStProcesses. "Terminate any running Smalltalk processes"
	commandShell terminateCommandLineProcesses. "Terminate any running Smalltalk processes"
	commandShell changed: #clearText
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/5/2002 12:06'!
copyToErrorCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Copy the contents of (argArray at: 1) or stdin onto stderr. This
	command exists only for purposes of testing stdin and pipelines
	for PipeableEvaluator proxies."

	| anyOutput fs |
	(argArray isNil or: [argArray size == 0])
		ifTrue:
			[stdin ifNotNil: [self copyAllFrom: stdin to: stderr]]
		ifFalse:
			[anyOutput _ false.
			(self expandArguments: argArray commandShell: commandShell) do:
				[:file |
					(FileDirectory default fileExists: file)
						ifTrue:
							[fs _ FileStream readOnlyFileNamed: file.
							fs ifNotNil:
								[anyOutput _ true.
								self copyAllFrom: fs to: stderr.
								fs close]].
			anyOutput ifTrue: [stderr nextPut: Character lf]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/5/2002 12:06'!
copyToOutputCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Copy the contents of (argArray at: 1) or stdin onto stdout. This
	command exists only for purposes of testing stdin and pipelines
	for PipeableEvaluator proxies."

	| anyOutput fs |
	(argArray isNil or: [argArray size == 0])
		ifTrue:
			[stdin ifNotNil: [self copyAllFrom: stdin to: stdout]]
		ifFalse:
			[anyOutput _ false.
			(self expandArguments: argArray commandShell: commandShell) do:
				[:file |
					(FileDirectory default fileExists: file)
						ifTrue:
							[fs _ FileStream readOnlyFileNamed: file.
							fs ifNotNil:
								[anyOutput _ true.
								self copyAllFrom: fs to: stdout.
								fs close]].
			anyOutput ifTrue: [stdout nextPut: Character lf]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/5/2002 12:07'!
editCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Open an editor on each of the named files."

	| controllers inputString |
	(argArray isNil or: [argArray size == 0])
		ifTrue:
			["When taking input from a command pipeline, the input must be
			read into inputString now. This is because, in MVC, the CrLfFileEditor
			is scheduled to be created later, and the input pipe will be closed by
			the caller of this method before the CrLfFileEditor ever has a chance
			to read it."
			inputString _ stdin isNil
				ifTrue:
					['']
				ifFalse:
					[(self copyAllFrom: stdin to: (WriteStream on: String new)) contents
						replaceAll: Character lf with: Character cr].
			commandShell scheduleToEvaluate:
				[(CrLfFileEditor
					openOn: inputString
					withLabel: (commandShell commandHistory isEmpty
									ifTrue: ['']
									ifFalse: [commandShell commandHistory last])
					inDirectory: (FileDirectory on: commandShell workingDirectory)
					defaultFileName: 'buffer.txt') openInWorld] fixTemps]
		ifFalse:
			[controllers _ (self expandArguments: argArray commandShell: commandShell)
								collect:
									[:file | CrLfFileEditor fileNamed: file].
			Smalltalk isMorphic
				ifFalse:
					[controllers
						inject: nil
						into:
							[:prev :c |
							prev ifNotNil:
								[c addDeferredUIMessage: [prev open] fixTemps].
							c].
					commandShell scheduleToEvaluate: [controllers last open]]
				ifTrue:
					[controllers do:
						[:e | commandShell scheduleToEvaluate: [e openInWorld] fixTemps]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:21'!
exitCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Exit the shell window. Answer a string or an invalid command message."

	argArray size == 0 ifFalse: [^ commandShell invalidCommandMessage].
	commandShell changed: #exit
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:19'!
fcCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Fix command. If argArray is emply, answer the last command in the
	history list. If there is one argument, interpret it as an integer index
	into the history list. Otherwise answer an invalid command message."

	| index cmd |
	commandShell commandHistory ifNotNil:
		[commandShell scheduleToEvaluate:
			[argArray size == 0
				ifTrue:
					[cmd _ commandShell editCommand: (commandShell historyAt: 0)]
				ifFalse:
					[[index _ (argArray at: 1) asNumber]
								on: Error
								do: [:ex | index _ nil].
					cmd _ commandShell editCommand:
							(index isNil
								ifTrue: ['']
								ifFalse: [commandShell historyAt: index])].
					commandShell prompt.
					cmd isEmpty ifFalse:
						[commandShell show: cmd; doCommandsInString: cmd]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/1/2002 11:26'!
helpCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray

	| topic command |
	argArray size == 0
		ifTrue:
			[(commandShell builtinCommands collect: [:c | c helpSelector] thenSelect: [:s | s notNil])
				asSortedArray do:
					[:sel | stdout nextPutAll: (self perform: sel); nextPut: Character lf].
			stdout
				nextPutAll: 'simple Smalltalk expression!! evaluates a simple expression as a doIt';
				nextPut: Character lf;
				nextPutAll: '<ctl-C> to interrupt a running program';
				nextPut: Character lf;
				nextPutAll: '<ctl-D> to end input to a running program';
				nextPut: Character lf]
		ifFalse:
			[topic _ argArray at: 1.
			command _ commandShell builtinCommands at: topic ifAbsent: [^ self].
			command helpSelector ifNotNil:
				[stdout nextPutAll: (self perform: command helpSelector); nextPut: Character lf]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:14'!
historyCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Display the command history list."

	| ws rs |
	ws _ WriteStream on: Character cr asString.
	rs _ ReadStream on: commandShell commandHistory.
	[rs atEnd]
		whileFalse: [ws nextPutAll: rs next.
			ws nextPutAll: ' '.
			ws nextPutAll: rs next.
			rs atEnd
				ifFalse: [ws cr]].
	stdout nextPutAll: (ws contents, Character cr asString)
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 1/5/2002 12:07'!
inspectCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Open a Smalltalk inspector on the contents of stdin, or the file(s) named on the
	command line."

	| files fs inputString |
	(argArray isNil or: [argArray size == 0])
		ifTrue:
			[stdin ifNotNil:
				["When taking input from a command pipeline, the input must be
				read into inputString now. This is because, in MVC, the inspector
				is scheduled to be created later, and the input pipe will be closed by
				the caller of this method before the deferred block ever has a
				chance to read it."
				inputString _ stdin ifNotNil:
					[(self copyAllFrom: stdin to: (WriteStream on: String new)) contents
						replaceAll: Character lf with: Character cr].
				commandShell scheduleToEvaluate: [inputString inspect]]]
		ifFalse:
			[files _ self expandArguments: argArray commandShell: commandShell.
			(files size == 0)
				ifTrue:
					[commandShell scheduleToEvaluate: [nil inspect]]
				ifFalse:
					[files do:
						[:e |
						fs _ (FileDirectory default fileExists: e)
							ifTrue: [FileStream readOnlyFileNamed: e]
							ifFalse: [nil].
						fs isNil
							ifTrue:
								[commandShell scheduleToEvaluate: [nil inspect]]
							ifFalse:
								[commandShell scheduleToEvaluate:
									[(fs contentsOfEntireFile
									replaceAll: Character lf
									with: Character cr) inspect.
									fs close] fixTemps]]]]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:09'!
pwdCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Answer the current working directory (a string) or an invalid command message."

	| directoryString |
	directoryString _ commandShell workingDirectory.
	directoryString isEmpty ifTrue: [directoryString _ commandShell nullDirectoryString].
	argArray size == 0 ifFalse: [^ commandShell invalidCommandMessage].
	stdout nextPutAll: directoryString; cr
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:07'!
slsCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Simple directory contents lister"

	| filePatterns d entries names dirs files entry |
	(argArray isNil or: [argArray size == 0])
		ifTrue:
			["Contents of current directory."
			filePatterns _ Array with: '*']
		ifFalse:
			["List named files"
			filePatterns _ argArray].
	d _ FileDirectory on: commandShell workingDirectory.
	entries _ d entries.
	names _ Set new.
	filePatterns do: [:pat | names addAll: (commandShell shellSyntax glob: pat inDirectory: d)].
	dirs _ OrderedCollection new.
	files _ OrderedCollection new.
	names asSortedArray do:
		[:n |
		entry _ entries detect: [:e | e name = n].
		entry isDirectory
			ifTrue: [dirs add: entry]
			ifFalse: [files add: entry]].
	dirs do: [:e | stdout nextPutAll: (commandShell dirEntryString: e); nextPut: Character cr].
	files do: [:e | stdout nextPutAll: (commandShell dirEntryString: e); nextPut: Character cr]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:05'!
sqshCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Open a new shell window."

	| ws |
	argArray size == 0
		ifTrue:
			[commandShell scheduleToEvaluate: [commandShell class open]]
		ifFalse:
			[ws _ WriteStream on: String new.
			argArray inject: true into:
				[:first :each |
				first ifFalse: [ws nextPut: Character space].
				ws nextPutAll: each.
				false].
			commandShell scheduleToEvaluate: [commandShell class openLabel: ws contents] fixTemps]
! !

!ShellBuiltin class methodsFor: 'implementations' stamp: 'dtl 12/27/2001 11:03'!
typeCommand: commandShell input: stdin output: stdout error: stderr arguments: argArray
	"Answer how each name would be interpreted if used as a command name."

	| results exe |
	argArray size == 0
		ifTrue:
			[^ '']
		ifFalse:
			[results _ WriteStream on: Array new.
			argArray do:
			[:arg |
			(commandShell isBuiltInCommand: arg)
				ifTrue:
					[results nextPut: arg, ' is a shell builtin']
				ifFalse:
					[((Smalltalk hasClassNamed: #OSProcess)
							and: [OSProcess accessor canAccessSystem])
					 	ifFalse:
							[self inform: 
								((Smalltalk hasClassNamed: #OSProcess)
									ifTrue: [OSProcess accessor class name]
									ifFalse: [commandShell class name]), ' cannot access system'.
							stdout nextPutAll: 'cannot access system'; cr.
							^ self].
					exe _ commandShell shellSyntax findExecutablePathFor: arg inDirectoryPath: commandShell workingDirectory.
					(commandShell shellSyntax isExecutable: exe) ifFalse: [exe _ nil].
					exe isNil
						ifTrue: [results nextPut: arg, ': not found']
								ifFalse: [results nextPut: arg, ' is ', exe]]].
				results contents do: [:e | stdout nextPutAll: e; cr]]
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 19:58'!
cdHelp

	^ 'cd [path] - change default directory'! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 19:59'!
clearHelp

	^ 'clear - clear screen'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:00'!
editHelp

	^ 'edit [files...] - edit the contents of stdin or the named files'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:00'!
exitHelp

	^ 'exit - exit shell and close window'! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:01'!
fcHelp

	^ 'fc [i] - "fix command", command number i from history list, or -i, or the last command'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:01'!
helpHelp

	^ 'help - help on sqsh commands'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:02'!
historyHelp

	^ 'history - display command history list'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:02'!
inspectHelp

	^ 'inspect [files...] - open an inspector on the contents of stdin or the named files'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:02'!
pwdHelp

	^ 'pwd - print current working directory'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:06'!
slsHelp

	^ 'sls [filepatterns] - list current directory contents'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:03'!
sqshHelp

	^ 'sqsh [title] - open new shell window'
! !

!ShellBuiltin class methodsFor: 'help messages' stamp: 'dtl 12/31/2001 20:03'!
typeHelp

	^ 'type [names...] - indicate how each name would be interpreted if used as a command'
! !

!ShellBuiltin class methodsFor: 'private' stamp: 'dtl 1/1/2002 11:36'!
copyAllFrom: aPipe to: aStream
	"Copy the contents of aPipe to aStream, where aPipe is the output of a
	process proxy. Do the copy in chunks, and between chunks force an
	update to the run status of external child processes. Answer aStream
	when done.

	This method is intended to be used by internal commands which need to
	read input from an external OSPipe, and which could deadlock if the
	pipe is set to blocking mode.

	This method synchronizes the evaluation of process proxies by forcing
	a wait for the first available character on aPipe. All pipes will supply
	at least one character, or a nil when empty. It is safe to block waiting
	for the first character as long as the pipe is being written by a proxy
	which will close the pipe when it exits."

	| d chunkSize s |
	d _ Delay forMilliseconds: 200.
	chunkSize _ 100000.
	aPipe peek. "Force a wait for the first character prior to setting nonblocking mode"
	[aPipe setNonBlocking] on: Error do: []. "Set nonblocking mode if input is a pipe"
	[aPipe atEnd] whileFalse:
		[s _ aPipe next: chunkSize.
		s isNil
			ifTrue:
				[(Smalltalk hasClassNamed: #OSProcess)
					ifTrue: [OSProcess thisOSProcess updateActiveChildren]]
			ifFalse:
				[aStream nextPutAll: s].
		d wait].
	^ aStream
! !

!ShellBuiltin class methodsFor: 'private' stamp: 'dtl 1/5/2002 12:01'!
expandArguments: argArray commandShell: aCommandShell
	"The builtin command is simulating an external command, and needs to expand
	the argument list in the context of a file system. Answer the expanded list of
	arguments."

	^ aCommandShell shellSyntax
		expandedFileNames: argArray
		inDirectoryPath: aCommandShell workingDirectory! !


!ShellSyntax methodsFor: 'accessing' stamp: 'dtl 12/16/2001 20:04'!
cwdDictionary
	"Current working directory paths indexed by device or file system name"

	^ cwdDictionary ifNil: [cwdDictionary _ Dictionary new]
! !

!ShellSyntax methodsFor: 'accessing' stamp: 'dtl 12/17/2001 10:49'!
cwdIndex
	"Key to current cwd path name in cwdDictionary"

	^ cwdIndex ifNil: [cwdIndex _ self cwdIndexFor: FileDirectory default pathName]
! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 3/6/2001 22:27'!
argsFromCommand: aString

	^ aString findTokens: ' 	'
! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 12/17/2001 11:39'!
isComment: aString
	"Answer true if aString is empty or if its first non-space character is commentChar"

	"ShellSyntax new isComment: '   #comment'"
	"ShellSyntax new isComment: '#comment'"
	"ShellSyntax new isComment: '   notComment'"
	"ShellSyntax new isComment: 'notComment'"
	"ShellSyntax new isComment: ''"

	^ (aString size == 0)
		or:
			[aString do: [:e | (e isSeparator not)
							ifTrue: [^ e == self commentChar]].
			false]! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 12/17/2001 11:39'!
isFlagParameter: aString
	"Answer true if aString begins with $- (the convention for command flags for Unix)"

	"ShellSyntax new isFlagParameter: '-help'"
	"ShellSyntax new isFlagParameter: 'filename'"
	"ShellSyntax new isFlagParameter: ''"

	^ (aString size > 0) and: [(aString at: 1) == $-]! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 12/17/2001 11:39'!
redirectIOFor: commandString inDirectoryPath: dirPathString
	"Handle IO redirection. Answer a four element array with the command string
	(with IO tokens removed); and stdin, stdout and stderr if specified for
	redirection."

	"ShellSyntax new
		redirectIOFor: 'ls /tmp /NOSUCHFILE > /tmp/sqTempOut.tmp 2> /tmp/sqTempErr.tmp'
		inDirectoryPath: nil"
	"ShellSyntax new
		redirectIOFor: 'cat < /etc/hosts > /tmp/sqHosts.tmp'
		inDirectoryPath: nil"

	| cmd tokenStream tok target input output error |
	cmd _ nil.
	input _ output _ error _ nil.
	"Default to nil unless overridden by commandString."
	tokenStream _ ReadStream on: (self tokenizeForRedirect: commandString).
	[tokenStream atEnd]
		whileFalse:
			[tok _ tokenStream next.
			tok == #inputRedirect
				ifTrue: ["Do input redirection"
					target _ self expandArgument: tokenStream next
								inDirectoryPath: dirPathString.
					input _ FileStream readOnlyFileNamed: target.
					input
						ifNil: [self inform: 'Cannot open ' , target , ', using default stdin']]
				ifFalse: [tok == #outputRedirect
						ifTrue: ["Do output redirection"
							target _ self expandArgument: tokenStream next
										inDirectoryPath: dirPathString.
							output _ self truncatedOutputFile: target.
							output ifNil:
									[self inform: 'Cannot open ' , target , ', using default stdout']]
						ifFalse: [tok == #outputAppendRedirect
								ifTrue: ["Do output redirection, appended to existing output file if any."
									target _ self expandArgument: tokenStream next
												inDirectoryPath: dirPathString.
									output _ FileStream fileNamed: target.
									output isNil
										ifTrue: [self inform: 'Cannot open ' , target , ', using default stdout']
										ifFalse: [output setToEnd]]
								ifFalse: [tok == #errorRedirect
										ifTrue: ["Do error redirection"
											target _ self expandArgument: tokenStream next
														inDirectoryPath: dirPathString.
											error _ self truncatedOutputFile: target.
											error ifNil:
													[self inform: 'Cannot open ' , target , ', using default stdout']]
										ifFalse: [tok == #errorAppendRedirect
												ifTrue: ["Do error redirection, appended to existing error file if any. "
													target _ self expandArgument: tokenStream next
																inDirectoryPath: dirPathString.
													error _ FileStream fileNamed: target.
													error isNil
														ifTrue: [self inform: 'Cannot open ' , target , ', using default stdout']
														ifFalse: [error setToEnd]]
												ifFalse: [cmd isNil
														ifTrue: [cmd _ tok]
														ifFalse: [self inform: 'Ack!! Pfft!! IO redirection parsing error.']]]]]]].
	^ Array
		with: cmd
		with: input
		with: output
		with: error! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 12/17/2001 11:39'!
tokenizeForRedirect: aString
	"Answer a collection of tokens for IO redirection. Answers a collection of
	tokens, where each token is either a String, or a Symbol in:
	#(#inputRedirect #outputRedirect #outputAppendRedirect #errorRedirect #errorAppendRedirect)"

	"ShellSyntax new tokenizeForRedirect: 'one > two < three 2> four five six 2>> seven eight > nine ten >> eleven twelve 2 > thirteen'"

	| oc rs ws c redirectToken tok |
	oc _ OrderedCollection new.
	rs _ ReadStream on: aString.
	ws _ WriteStream on: ''.
	[rs atEnd]
		whileFalse:
			[c _ rs next.
			((c == $2) and: [rs peek == $>])
				ifTrue:
					[rs next.
					(rs peek == $>)
						ifTrue:
							[rs next.
							redirectToken _ #errorAppendRedirect]
						ifFalse:
							[redirectToken _ #errorRedirect].
					c _ ws contents.
					(c size > 0)
						ifTrue:
							[oc add: c.
							ws resetContents].
					oc add: redirectToken]
				ifFalse:
					[(c == $>)
						ifTrue:
							[(rs peek == $>)
								ifTrue:
									[rs next.
									redirectToken _ #outputAppendRedirect]
								ifFalse:
									[redirectToken _ #outputRedirect].
							c _ ws contents.
							(c size > 0)
								ifTrue:
									[oc add: c.
									ws resetContents].
							oc add: redirectToken]
						ifFalse:
							[(c == $<)
								ifTrue:
									[c _ ws contents.
									(c size > 0)
										ifTrue:
											[oc add: c.
											ws resetContents].
									oc add: #inputRedirect]
								ifFalse: [ws nextPut: c]]]].
	tok _ ws contents.
	(tok size > 0) ifTrue: [oc add: tok].
	^ oc
! !

!ShellSyntax methodsFor: 'command string parsing' stamp: 'dtl 12/17/2001 11:39'!
truncatedOutputFile: fileName
	"Attempt to do reasonable things to open a file of size zero. Better would be
	to implement a file truncation primitive."

	"ShellSyntax new truncatedOutputFile: '/tmp/delete.me'"
	"ShellSyntax new truncatedOutputFile: '/dev/null'"

	| strm |
	[strm _ FileStream concreteStream forceNewFileNamed: fileName]
		on: Error
		do: [:ex | ^ FileStream fileNamed: fileName].
	^ strm
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/2/2002 19:47'!
appendPath: aPathString toPath: startingPathString

	"ShellSyntax new appendPath: 'hosts' toPath: '/etc'"
	"ShellSyntax new appendPath: 'etc' toPath: '/'"
	"ShellSyntax new appendPath: 'hosts' toPath: '/etc'"
	"ShellSyntax new appendPath: 'WINDOWS' toPath: 'C:\'"
	"ShellSyntax new appendPath: 'someFileName' toPath: 'C:\WINDOWS'"

	^ (self isAtFileSystemRoot: startingPathString)
		ifTrue: [startingPathString, aPathString]
		ifFalse: [startingPathString, FileDirectory slash, aPathString]! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/2/2002 22:16'!
expandArgument: aString inDirectoryPath: aPath
	"Expand a single argument and answer a fully qualified path to the first matching
	name. If no match, answer the literal path and file name (which does not exist).
	This method may be used to expand a single argument, such as the target for a
	command output redirection, where the target is expected to resolve to a single
	file name."

	"ShellSyntax new expandArgument: 'b?*h' inDirectoryPath: '/usr/bin'"
	"ShellSyntax new expandArgument: 'b?*h' inDirectoryPath: '/no/such/directory'"
	"ShellSyntax new expandArgument: 'no*such*file???' inDirectoryPath: '/usr/bin'"
	"ShellSyntax new expandArgument: '/usr/bin/vi' inDirectoryPath: '/usr/bin'"
	"ShellSyntax new expandArgument: '../bin/vi' inDirectoryPath: '/usr/bin'"
	"ShellSyntax new expandArgument: nil inDirectoryPath: '/usr/bin'"

	| expanded path trimmedString |
	aString ifNil: [^ ''].
	trimmedString _ aString withBlanksTrimmed.
	expanded _ self expandArgumentsFrom: (Array with: trimmedString) inDirectoryPath: aPath.
	path _ expanded isEmpty
			ifTrue: [trimmedString]
			ifFalse: [expanded first].
	^ self newPathFor: path fromDefault: aPath
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/17/2001 11:40'!
expandArgumentsFrom: argArray
	"Perform globbing expansion of command arguments."

	"ShellSyntax new expandArgumentsFrom: #('this' 'is' 'a' 'test' 'Sq*log')"

	^ self expandArgumentsFrom: argArray inDirectoryPath: FileDirectory default pathName
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/17/2001 11:40'!
expandArgumentsFrom: argArray inDirectoryPath: aDefaultFileDirectoryPath
	"Perform globbing expansion of command arguments. For each argument which is not a
	pathname, use aDefaultFileDirectory as the context for globbing."

	"ShellSyntax new
		expandArgumentsFrom: #('-help' '/b?n/s?' 'ho?ts' 'fs*' 'NOSUCHFILE')
		inDirectoryPath: '/etc'"
	"ShellSyntax new
		expandArgumentsFrom: #('this' 'is' 'a' 'test' 'Sq*log' '/us*/b?n/v?')
		inDirectoryPath: FileDirectory default pathName"
	"ShellSyntax new
		expandArgumentsFrom: #('this' 'is' 'a' 'test' 'Sq*log' '/us*/b?n/v?')
		inDirectoryPath: nil"

	| newArgs pathStrings dirPath |
	dirPath _ aDefaultFileDirectoryPath ifNil: [FileDirectory default pathName].
	newArgs _ OrderedCollection new.
	argArray do:
		[:arg |
		(self isFlagParameter: arg)
			ifTrue:
				[newArgs add: arg]
			ifFalse:
				[(pathStrings _ self glob: arg inDirectory: (FileDirectory on: dirPath))
					isEmpty ifTrue: [pathStrings _ self expandedPathsFrom: arg beginningAt: dirPath].
				pathStrings isEmpty
					ifTrue: [newArgs add: arg]
					ifFalse: [newArgs addAll: pathStrings]]].
	^ newArgs
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/17/2001 14:41'!
expandPathParts: pathParts beginningAt: root
	"Walk directory tree and answer a collection of matching path strings."

	| firstPart remainder dirPaths names dirNames basePath |
	(pathParts size == 0)
		ifTrue:
			["Should never get here, but just in case"
			^ Array with: root].
	firstPart _ pathParts first.
	remainder _ pathParts allButFirst.
	(firstPart = '.')
		ifTrue: "Stay at the current directory level"
			[dirPaths _ Array with: root]
		ifFalse:
			[(firstPart = '..') "Move up a directory level if possible"
				ifTrue:
					[dirPaths _ Array with: (self upOneDirectoryLevel: root)]
				ifFalse: "Normal case, a directory name"
					[remainder isEmpty
						ifTrue:
							["This condition terminates recursion"
							names _ self glob: firstPart inDirectory: (FileDirectory on: root).
							^ (root = FileDirectory slash)
								ifTrue: [^ names collect: [:n | root, n]]
								ifFalse: [^ names collect: [:n | root, FileDirectory slash, n]]]
						ifFalse:
							["Continue recursion until no more elements"
							dirNames _ self glob: firstPart
											names: (FileDirectory on: root) directoryNames.
							(('*', FileDirectory slash) match: root)
								ifTrue: [basePath _ root]
								ifFalse: [basePath _ root, FileDirectory slash].
							dirPaths _ dirNames collect: [:d | basePath, d]]]].
		^ dirPaths
			inject: OrderedCollection new
			into: [:result :dir |
				result addAll: (self expandPathParts: remainder beginningAt: dir).
				result]
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/2/2002 22:20'!
expandedFileNames: argArray inDirectoryPath: dirPathString
	"Expand argArray into a collection of file names"

	"ShellSyntax new
		expandedFileNames: (Array with: '/etc/h?st*' with: '/bin/*sh')
		inDirectoryPath: nil"

	| oc |
	argArray size == 0
		ifTrue:
			[^ argArray]
		ifFalse:
			[oc _ OrderedCollection new.
			argArray do:
				[:arg |
				oc addAll: (self expandArgumentsFrom: (Array with: arg)
								inDirectoryPath: dirPathString)]].
	^ oc collect: [:e | self newPathFor: e fromDefault: dirPathString]
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/17/2001 11:40'!
expandedPathsFrom: aPathString beginningAt: firstPartOfPath
	"Answer a collection of all paths which match aPathString. If aPathString is a relative path,
	expand the path relative to firstPartOfPath."

	 "ShellSyntax new expandedPathsFrom: '/e*c/h*s' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: 'e*c/h*s' beginningAt: '/'"
	 "ShellSyntax new expandedPathsFrom: '/usr/bin/vi' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: 'bin/vi' beginningAt: '/usr'"
	 "ShellSyntax new expandedPathsFrom: '/usr/*/vi' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: '/usr/bin/../bin/./../bin/../../usr/bin/vi' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: '/bin/../bin/./../bin/../../usr/bin/vi' beginningAt: '/usr'"
	 "ShellSyntax new expandedPathsFrom: '/usr/bin/../bin/./../bin/../../../../../usr/bin/vi' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: '../../../../../../usr/bin/vi' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: '/' beginningAt: '/'"
	 "ShellSyntax new expandedPathsFrom: '*.image' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: 'C:\WINDOWS\*.*' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: '*.*' beginningAt: 'C:\WINDOWS'"
	 "ShellSyntax new expandedPathsFrom: 'C:\*.*' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: 'C:\CONFIG.*' beginningAt: nil"
	 "ShellSyntax new expandedPathsFrom: 'C:\CONFIG.*' beginningAt: '\'"

	| result oldPrefix a prefix dirPathString pathParts root |
	result _ OrderedCollection new.
	oldPrefix _ firstPartOfPath isNil
				ifTrue: ['']
				ifFalse: [(self splitLocationPrefixFromPath: firstPartOfPath) first].
	a _ self splitLocationPrefixFromPath: aPathString.
	prefix _ (a at: 1) isEmpty
				ifTrue: [oldPrefix]
				ifFalse: [a at: 1].
	dirPathString _ a at: 2.
	pathParts _ dirPathString findTokens: FileDirectory slash.
	root _ (self isAbsolutePath: dirPathString)
			ifTrue: "Fully qualified path name, ignore firstPartOfPathName"
				[prefix, FileDirectory slash]
			ifFalse: "Relative path name, need to use firstPartOfPathName"
				[firstPartOfPath isNil
					ifTrue: [FileDirectory default pathName]
					ifFalse: [firstPartOfPath]].
	result addAll: (self expandPathParts: pathParts beginningAt: root).
	^ result

! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/17/2001 14:37'!
findExecutablePathFor: aString inDirectoryPath: pathString
	"Look for the executable, following Unix conventions for searching the PATH.
	If no likely candidate is found, answer nil."

	"ShellSyntax new findExecutablePathFor: 'bash' inDirectoryPath: nil"
	"ShellSyntax new findExecutablePathFor: 'ReadMe.txt' inDirectoryPath: nil"
	"ShellSyntax new findExecutablePathFor: 'SqueakDebug.log' inDirectoryPath: nil"
	"ShellSyntax new findExecutablePathFor: 'noSuchFileName' inDirectoryPath: nil"
	"ShellSyntax new findExecutablePathFor: 'a' inDirectoryPath: nil"
	"ShellSyntax new findExecutablePathFor: 'sqcat' inDirectoryPath: '/home/lewis/bin'"

	| delimiter path localNames fd fullName pathEntries dir |
	delimiter _ FileDirectory pathNameDelimiter.
	path _ pathString ifNil: [FileDirectory default pathName].
	"Unix compatibility note: If aString contains wildcard characters,
	it is expanded in the context of the current working directory. Expansion
	does not take place in the context of the PATH directories."
	localNames _ self glob: aString.
	fd _ FileDirectory default.

	(aString includes: delimiter)
		ifTrue:
			["A fully or partially qualified path, do not search PATH"
			(self isAbsolutePath: aString)
				ifTrue:
					["Fully qualified path from the file system root"
					^ localNames
						detect:
							[:fileName |
							((fd fileExists: fileName) and: [self isExecutable: fileName])
								ifTrue: [^ fileName]]
						ifNone: [nil]]
				ifFalse:
					["A path relative to the current directory, pathString"
					^ localNames
						detect:
							[:fileName |
							fullName _ path, FileDirectory slash, aString.
							((fd fileExists: fullName) and: [self isExecutable: fullName])
								ifTrue: [^ fullName]]
						ifNone: [nil]]]
		ifFalse:
			["Look for the file in the PATH locations"
			(localNames size == 0)
				ifTrue:
					["Name was not expanded, so use the unmodified value of aString"
					localNames _ Array with: aString].
			pathEntries _ (OSProcess thisOSProcess path findTokens: ':') collect:
							[:e | (e first == delimiter)
							ifTrue: [e]
							ifFalse: [path, delimiter asString, e]].
			dir _ pathEntries
				detect: [:pathName |
					(localNames
						detect: [:fileName |
							fullName _ pathName, FileDirectory slash, fileName.
							((fd fileExists: fullName) and: [self isExecutable: fullName])
								ifTrue: [^ fullName].
						false]
						ifNone: [nil]) notNil]
				ifNone: [nil].
			dir isNil
				ifTrue: [^ nil]
				ifFalse: [self error: 'should be nil']]
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/2/2002 20:03'!
findPathTo: aString inDirectoryPath: pathString
	"Look for a path to aString, following Unix conventions for searching the PATH.
	If no likely candidate is found, answer nil."

	"ShellSyntax new findPathTo: 'bash' inDirectoryPath: nil"
	"ShellSyntax new findPathTo: 'ReadMe.txt' inDirectoryPath: nil"
	"ShellSyntax new findPathTo: 'SqueakDebug.log' inDirectoryPath: nil"
	"ShellSyntax new findPathTo: 'noSuchFileName' inDirectoryPath: nil"
	"ShellSyntax new findPathTo: 'a' inDirectoryPath: nil"

	| delimiter localNames pathEntries dir fd exeName path relativePath |
	delimiter _ FileDirectory pathNameDelimiter.
	path _ pathString ifNil: [FileDirectory default pathName].
	(aString includes: delimiter)
		ifTrue:
			["A fully or partially qualified path, do not search PATH"
			(self isAbsolutePath: aString)
				ifTrue:
					["Fully qualified path from the file system root"
					(FileDirectory default fileExists: aString)
						ifTrue: [^ aString]
						ifFalse: [^ nil]]
				ifFalse:
					["A path relative to the current directory, pathString"
					relativePath _ path, FileDirectory slash, aString.
					(FileDirectory default fileExists: relativePath)
						ifTrue: [^ relativePath]
						ifFalse: [^ nil]]]
		ifFalse:
			["Look for the file in the PATH locations"
			localNames _ self glob: aString. "Unix shells do this for some reason"
			(localNames size == 0)
				ifTrue:
					["Name was not expanded, so use the unmodified value of aString"
					localNames _ Array with: aString].
			pathEntries _ (OSProcess thisOSProcess path findTokens: ':') collect:
							[:e | (e first == delimiter)
							ifTrue: [e]
							ifFalse: [path, FileDirectory slash, e]].
			dir _ pathEntries
				detect: [:pathName |
					fd _ FileDirectory on: pathName.
					(localNames
						detect: [:fileName |
							(fd fileExists: fileName)
								ifTrue: [exeName _ fileName. true]
								ifFalse: [false]]
						ifNone: [nil]) notNil]
				ifNone: [exeName].
			dir isNil
				ifTrue: [^ nil]
				ifFalse: [^ (self expandedPathsFrom: (dir, FileDirectory slash, exeName)
								beginningAt: FileDirectory slash) at: 1 ifAbsent: [nil]]]! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/2/2002 22:09'!
newPathFor: aPathString fromDefault: startingPathString
	"Answer a new path starting from startingPathString if aPathString is a,
	relative path, otherwise just answer aPathString unmodified."

	"ShellSyntax new newPathFor: 'hosts' fromDefault: '/etc'"
	"ShellSyntax new newPathFor: 'three' fromDefault: 'one/two'"
	"ShellSyntax new newPathFor: 'one/two/three' fromDefault: ''"
	"ShellSyntax new newPathFor: '/hosts' fromDefault: '/etc'"
	"ShellSyntax new newPathFor: 'WINDOWS' fromDefault: 'C:\'"
	"ShellSyntax new newPathFor: 'D:\WINDOWS' fromDefault: 'C:\'"
	"ShellSyntax new newPathFor: 'D:WINDOWS' fromDefault: 'C:\'"

	^ (self isAbsolutePath: aPathString)
		ifTrue:
			[aPathString]
		ifFalse:
			[self appendPath: (self splitLocationPrefixFromPath: aPathString) last
					toPath: startingPathString]
! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 1/4/2002 21:19'!
pathStringAboveRoot
	"Magic string indicating location above the file system root. For Unix, this just
	points to the file system root. For Windows, it points to one level above the C: drive."

	^ '[]'! !

!ShellSyntax methodsFor: 'path name expansion' stamp: 'dtl 12/26/2001 18:04'!
programNameAndArgumentsFrom: aString inDirectoryPath: pathString

	"ShellSyntax new programNameAndArgumentsFrom: 'sleep 6' inDirectoryPath: '/etc'"
	"ShellSyntax new programNameAndArgumentsFrom: 'ls -l h?s*' inDirectoryPath: '/etc'"

	| tokens tok args exe |
	tokens _ self argsFromCommand: aString.
	tokens size == 0
		ifTrue: [tok _ '']
		ifFalse: [tok _ tokens at: 1].
	args _ self expandArgumentsFrom: (tokens copyFrom: 2 to: tokens size) inDirectoryPath: pathString.
	exe _ self findExecutablePathFor: tok inDirectoryPath: pathString.
	exe ifNil: [exe _ tok].
	^ Array with: exe with: args
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/16/2001 20:06'!
cwdIndex: aSymbol
	"Key to current cwd path name in cwdDictionary"

	cwdIndex _ aSymbol
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/17/2001 09:56'!
cwdIndexFor: aPathStringWithPrefix
	"Answer key to use for aPathStringWithPrefix"

	| prefix |
	prefix _ (self splitLocationPrefixFromPath: aPathStringWithPrefix) first.
	^ prefix isEmpty
		ifTrue: [#default]
		ifFalse: [prefix]! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 1/3/2002 19:15'!
defaultPathFor: aPathStringWithPrefix
	"Answer a reasonable path string to use as a default"

	^ self pathRoot: aPathStringWithPrefix
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/17/2001 09:52'!
getCwdForPath: aPathString

	| prefix |
	prefix _ (self splitLocationPrefixFromPath: aPathString) first.
	^ prefix isEmpty
		ifTrue: [self workingDirectory]
		ifFalse: [self cwdDictionary at: prefix ifAbsentPut: [self defaultPathFor: aPathString]]
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/16/2001 21:26'!
setCwdIndexFrom: aPathString
	"Set the current working directory index to a string (Win32 device name) or to #default."

	| prefix |
	prefix _ (self splitLocationPrefixFromPath: aPathString) first.
	prefix isEmpty
		ifTrue: [self cwdIndex: #default]
		ifFalse: [self cwdIndex: prefix]
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/16/2001 20:23'!
workingDirectory

	^ self cwdDictionary at: self cwdIndex ifAbsentPut:
		[(Smalltalk hasClassNamed: #OSProcess)
			ifTrue: [OSProcess thisOSProcess getCwd]
			ifFalse: [nil]]
! !

!ShellSyntax methodsFor: 'working directory' stamp: 'dtl 12/16/2001 21:32'!
workingDirectory: aPathString

	self setCwdIndexFrom: aPathString.
	self cwdDictionary at: self cwdIndex put: aPathString! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 3/10/2001 18:07'!
character: aCharacter matches: aToken
	"Test if aCharacter is included in the characters of aToken, or if aToken is a #matchAny"

	(aToken == #matchAny) ifTrue: [^ true].
	^ aToken includes: aCharacter! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 12/17/2001 11:41'!
glob: aString
	"Apply Unix shell globbing rules to aString, and answer an array of matching
	file names."

	"ShellSyntax new glob: 'ReadMe.txt'"
	"ShellSyntax new glob: 'rEADmE.TXT'"
	"ShellSyntax new glob: 'R*dM?.txt'"

	^ self glob: aString inDirectory: FileDirectory default
! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 12/17/2001 11:41'!
glob: aString inDirectory: aFileDirectory
	"Apply Unix shell globbing rules to aString, and answer an array of matching
	file names."

	"ShellSyntax new glob: 'ReadMe.txt' inDirectory: FileDirectory default"
	"ShellSyntax new glob: 'SqueakDebug.log' inDirectory: FileDirectory default"
	"ShellSyntax new glob: '?queak*.[0-9].log' inDirectory: FileDirectory default"
	"ShellSyntax new glob: '*image*' inDirectory: FileDirectory default"
	"ShellSyntax new glob: 'noSuchFileName' inDirectory: FileDirectory default"
	"ShellSyntax new glob: 'b?n' inDirectory: (FileDirectory on: '/usr')"

	[^ self glob: aString names: aFileDirectory fileAndDirectoryNames]
		on: Error
		do: [^ #()]

! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 3/11/2001 17:37'!
glob: aString names: fileNameArray
	"Apply Unix shell globbing rules to aString with respect to the elements of fileNameArray,
	and answer an array of matching file names. The fileNameArray is expected to have been
	provided by a FileDirectory query."

	| tokens |
	tokens _ self globTokensFrom: aString.
	^ fileNameArray
		select: [:n |
			self tokenStream: (ReadStream on: tokens)
				matches: (ReadStream on: n)]

! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 3/10/2001 17:49'!
globRangeFrom: aString tokenStream: aTokenStream
	"Answer a string containing the characters specified by a range expression
	such as [a-z]. Sorry, this is just a simple implementation which assumes ASCII."

	| r w c t |
	(aString includes: $-) ifFalse: [^ aString]. "Simple case"
	r _ ReadStream on: aString.
	w _ WriteStream on: ''.
	(r peek == $!!) ifTrue:
		[r next.
		aTokenStream nextPut: #not].
	[r atEnd] whileFalse: [
		c _ r next.
		(r peek == $-)
			ifTrue: [r next.
					t _ r next.
					(c asciiValue to: t asciiValue) do:
						[:e | w nextPut: (Character value: e)]]
			ifFalse: [w nextPut: c]].
	^ w contents! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 12/17/2001 11:41'!
globTokensFrom: aString
	"Answer a collection of tokens to be used for glob matching."

	"ShellSyntax new globTokensFrom: 'abc?def\ghi\?jkl*mno\*pqr[hello]there[Xa-eY]Z[!!A-Z]end'"

	| lastToken r w t |
	lastToken _ nil.
	r _ ReadStream on: aString.
	w _ WriteStream on: #().
	[r atEnd] whileFalse:
		[t _ self nextGlobToken: r lastToken: lastToken tokenStream: w.
		(t ~~ #escape) ifTrue: [w nextPut: t].
		lastToken _ t].
	^ w contents
! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 12/15/2001 09:55'!
nextGlobToken: aStream lastToken: aToken tokenStream: aTokenStream
	"Escape character processing probably belongs elsewhere. Since it can conflict
	with Win32 file name conventions, I have commented it out here. The code
	is otherwise left alone here in case I change my mind later. -dtl"

	| c |
	(aToken == #escape)
		ifTrue:
			[^ aStream next]
		ifFalse:
			[c _ aStream next.
			(c == $[)
				ifTrue:
					["character range"
					^ self globRangeFrom: (aStream upTo: $]) tokenStream: aTokenStream]
				ifFalse:
					[(c == $*) ifTrue: [^ #matchRun].
					(c == $?) ifTrue: [^ #matchAny].
					"(c == $\) ifTrue: [^ #escape].	Escape processing disabled here"
					^ c asString]]! !

!ShellSyntax methodsFor: 'globbing' stamp: 'dtl 1/5/2002 09:52'!
tokenStream: aTokenStream matches: aCharacterStream 
	"Iterate over both streams. If each character in aCharacterStream 
	matches its corresponding token in tokenStream, answer true."

	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'a?c')) matches: (ReadStream on: 'abc')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'ab*cde')) matches: (ReadStream on: 'abcde')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'ab*cde')) matches: (ReadStream on: 'abXXXcde')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'ab*cdX')) matches: (ReadStream on: 'abXXXcde')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'abc*')) matches: (ReadStream on: 'abcde')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'abc*')) matches: (ReadStream on: 'abc')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'a?cde*jkl')) matches: (ReadStream on: 'abcdefghijkl')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'abc[A-C]xyz')) matches: (ReadStream on: 'abcBxyz')"
	"ShellSyntax new tokenStream: (ReadStream on: (ShellSyntax new globTokensFrom: 'abc[!!A-C]xyz')) matches: (ReadStream on: 'abcZxyz')"

	| c tok |
	[aCharacterStream atEnd]
		whileFalse: [aTokenStream atEnd
				ifTrue: [^ false].
			c _ aCharacterStream peek.
			tok _ aTokenStream next.
			tok == #not
				ifTrue: ["A negated character range follows"
					tok _ aTokenStream next.
					(self character: c matches: tok)
						ifTrue: [^ false].
					aCharacterStream next]
				ifFalse: ["The normal case"
					tok == #matchRun
						ifTrue:
							["Skip characters until we resync the streams, or answer false"
							[self tokenStream: aTokenStream copy matches: aCharacterStream copy]
								whileFalse:
									[aCharacterStream atEnd ifTrue: [^ false].
									aCharacterStream next]]
						ifFalse: [(self character: c matches: tok)
								ifFalse: [^ false].
							aCharacterStream next]]].
	^ aTokenStream atEnd
		or: [aTokenStream next == #matchRun
				and: [aTokenStream atEnd]]
! !

!ShellSyntax methodsFor: 'defaults' stamp: 'dtl 9/8/2001 10:15'!
commentChar

	^ $#! !

!ShellSyntax methodsFor: 'defaults' stamp: 'dtl 9/8/2001 10:16'!
pipeCharToken
	"The command pipeline character"

	^ '|'! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 1/2/2002 19:54'!
isAbsolutePath: aPathString
	"Answer true if aPathString is specified relative to the root of the file system."

	"ShellSyntax new isAbsolutePath: 'not/absolute/path'"
	"ShellSyntax new isAbsolutePath: '/absolute/path'"
	"ShellSyntax new isAbsolutePath: '/'"
	"ShellSyntax new isAbsolutePath: 'C:\'"
	"ShellSyntax new isAbsolutePath: '\'"
	"ShellSyntax new isAbsolutePath: 'C:'"
	"ShellSyntax new isAbsolutePath: 'C:WINDOWS'"
	"ShellSyntax new isAbsolutePath: 'C:\WINDOWS'"

	| prefixAndPath path |
	^ ((((FileDirectory slash, '*') match: aPathString)
		or:	[prefixAndPath _ self splitLocationPrefixFromPath: aPathString.
			(FileDirectory slash, '*') match: (path _ prefixAndPath last)])
				or: [prefixAndPath first isEmpty not and: [path isEmpty]]) "One above the root of a Win32 file system tree"
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 12/17/2001 11:40'!
isAtFileSystemRoot: aPathString
	"Answer true if aPathString is not a subdirectory."

	"ShellSyntax new isAtFileSystemRoot: 'D:\'"
	"ShellSyntax new isAtFileSystemRoot: 'D:'"
	"ShellSyntax new isAtFileSystemRoot: 'D:\Windows'"
	"ShellSyntax new isAtFileSystemRoot: '\'"

	^ (FileDirectory slash = (self splitLocationPrefixFromPath: aPathString) last) or: [aPathString isEmpty]
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 9/8/2001 10:24'!
isExecutable: aPath
	"Answer true if aPath points to an executable file. This could be
	enhanced to support setting UID and GID for a CommandShell session.
	For now, just take the default for the current Squeak process."

	^ aPath notNil and: [OSProcess accessor isExecutable: aPath]
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 1/4/2002 21:21'!
pathAboveRoot
	"Answer a path pointing to a location above the file system root. The
	pathStringAboveRoot string refers to this location."

	 "ShellSyntax new pathAboveRoot"

	^ (Smalltalk platformName = 'Win32')
		ifTrue: ['']
		ifFalse: [FileDirectory slash].
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 1/3/2002 19:17'!
pathRoot: aPathString
	"For aPathString pointing to a file in a file system, answer the root of the
	file system. This method works fine for Unix and Windows, but may require
	conditional code for other platforms."

	| prefix |
	prefix _ (self splitLocationPrefixFromPath: aPathString) first.
	^ prefix, FileDirectory slash
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 12/17/2001 11:42'!
splitLocationPrefixFromPath: aPathString
	"Split any leading prefix from a path string, such as the C: device name
	for Win32. Answer an Array with prefix and path."

	 "ShellSyntax new splitLocationPrefixFromPath: 'C:\u'"
	 "ShellSyntax new splitLocationPrefixFromPath: 'C:\'"
	 "ShellSyntax new splitLocationPrefixFromPath: 'C:'"
	 "ShellSyntax new splitLocationPrefixFromPath: 'C:u'"
	 "ShellSyntax new splitLocationPrefixFromPath: 'c:u'"
	 "ShellSyntax new splitLocationPrefixFromPath: '\u'"

	| prefix path |
	(Smalltalk platformName = 'Win32')
		ifTrue:
			[((aPathString at: 2 ifAbsent: []) == $:)
				ifTrue:
					[prefix _ (String new: 2).
					prefix at: 1 put: (aPathString at: 1) asUppercase.
					prefix at: 2 put: $:.
					path _ aPathString copyAfter: $:]
				ifFalse:
					[prefix _ ''.
					path _ aPathString]]
		ifFalse:
			[prefix _ ''.
			path _ aPathString].
	^ Array with: prefix with: path
! !

!ShellSyntax methodsFor: 'platform dependent' stamp: 'dtl 1/3/2002 19:30'!
upOneDirectoryLevel: aPathName
	"Answer a path name for a directory one level up the directory tree"

	 "ShellSyntax new upOneDirectoryLevel: 'C:\Windows\temp'"
	 "ShellSyntax new upOneDirectoryLevel: 'C:\Windows'"
	 "ShellSyntax new upOneDirectoryLevel: 'C:\'"
	 "ShellSyntax new upOneDirectoryLevel: ''"
	 "ShellSyntax new upOneDirectoryLevel: '/usr/bin'"
	 "ShellSyntax new upOneDirectoryLevel: '/usr'"
	 "ShellSyntax new upOneDirectoryLevel: '/'"

	| prefixAndPath prefix path newPath |
	prefixAndPath _ self splitLocationPrefixFromPath: aPathName.
	prefix _ prefixAndPath at: 1.
	path _ prefixAndPath at: 2.
	(self isAtFileSystemRoot: aPathName)
		ifTrue:
			[prefix isEmpty
				ifTrue: "Normal case, unix. Do not go up a level."
					[^ aPathName]
				ifFalse: "A Win32 device name, go up a level above the file systems"
					[^ '']]
		ifFalse:
			[newPath _ path copyUpToLast: FileDirectory pathNameDelimiter.
			^ newPath isEmpty
				ifTrue:
					[prefix, FileDirectory slash]
				ifFalse:
					[prefix, newPath]]
! !


!ShellWindowMorph methodsFor: 'command input' stamp: 'dtl 3/18/2001 18:17'!
commandLineInput

	^ (self text copyFrom: self positionAfterPromptString to: self text size) asString.

! !

!ShellWindowMorph methodsFor: 'command input' stamp: 'dtl 4/7/2001 12:21'!
positionAfterPromptString
	"Answer the index of the first character after the last prompt string in my text. If
	not found, then assume that the contents of the text are all intended to be command
	input."

	| t loc |
	t _ self text.
	(1 to: (t size - model promptString size))
		reverseDo: [:i |
			((loc _ t findString: model promptString startingAt: i) ~= 0)
				ifTrue: [^ loc + model promptString size]].
	^ 1
! !

!ShellWindowMorph methodsFor: 'menu commands' stamp: 'dtl 8/4/2001 15:50'!
accept

	self model doCommandsInString: self commandLineInput asString
! !

!ShellWindowMorph methodsFor: 'model access' stamp: 'dtl 4/22/2001 18:25'!
setText: aText
	scrollBar setValue: 0.0.
	textMorph
		ifNil: [textMorph _ TtyTextMorphForEditView new
						contents: aText wrappedTo: self innerBounds width-6.
				textMorph setEditView: self.
				scroller addMorph: textMorph]
		ifNotNil: [textMorph newContents: aText].
	self hasUnacceptedEdits: false.
	self setScrollDeltas.! !

!ShellWindowMorph methodsFor: 'updating' stamp: 'dtl 4/21/2001 18:19'!
appendEntry

	| str |
	"Append the text in the model's writeStream to the editable text. "
	textMorph asText size > model characterLimit ifTrue:
		["Knock off first half of text"
		self selectInvisiblyFrom: 1 to: textMorph asText size // 2.
		self replaceSelectionWith: Text new].
	self selectInvisiblyFrom: textMorph asText size + 1 to: textMorph asText size.
	str _ model contents.
	(str size > 0) ifTrue:
		[self replaceSelectionWith: str asText.
		self selectInvisiblyFrom: textMorph asText size + 1 to: textMorph asText size.
		model reset]

! !

!ShellWindowMorph methodsFor: 'updating' stamp: 'dtl 6/3/2001 19:02'!
update: something

	(something == #doCommand)
		ifTrue:
			[^ self accept].
	(something == #exit)
		ifTrue:
			[^ self owner release; delete].
	^ super update: something
! !


!ShellWindowMorph class methodsFor: 'instance creation' stamp: 'dtl 4/29/2001 11:42'!
open
	"Open a new CommandShell, and answer the instance of ShellWindowMorph which it uses."

	"ShellWindowMorph open"

	^ CommandShell open model dependents at: 2! !


!ShellWindowView methodsFor: 'initialization' stamp: 'dtl 5/30/2001 21:53'!
defaultControllerClass 

	^ TtyPluggableTextController
! !

!ShellWindowView methodsFor: 'initialization' stamp: 'dtl 5/30/2001 22:07'!
initialize

	super initialize.
	self controller acceptOnCr: true! !

!ShellWindowView methodsFor: 'initialization' stamp: 'dtl 6/2/2001 19:05'!
on: anObject text: getTextSel accept: setTextSel readSelection: getSelectionSel menu: getMenuSel

	super on: anObject text: getTextSel accept: setTextSel readSelection: getSelectionSel menu: getMenuSel.
	self model prompt! !

!ShellWindowView methodsFor: 'updating' stamp: 'dtl 6/24/2001 22:55'!
update: something

	(something == #doCommand)
		ifTrue:
			[^ controller accept].
	(something == #clear)
		ifTrue:
			[^ self changeText: Text new].
	(something == #exit)
		ifTrue:
			[self topView controller
				addDeferredUIMessage:
					[controller controlTerminate.
					self topView controller closeAndUnschedule.
					ScheduledControllers restore] fixTemps].
	^ super update: something
! !

!ShellWindowView methodsFor: 'testing' stamp: 'dtl 6/2/2001 19:15'!
isCollapsed
	"Gross hack for starting up a new window. I don't understand why I did this. Aack!! Pfft!!"

	^ true! !


!TtyPluggableTextController methodsFor: 'accessing' stamp: 'dtl 5/30/2001 22:02'!
acceptOnCr
	"If true, notify my view to accept whenever a <cr> is input"

	acceptOnCr ifNil: [acceptOnCr _ false].
	^ acceptOnCr! !

!TtyPluggableTextController methodsFor: 'accessing' stamp: 'dtl 5/30/2001 22:00'!
acceptOnCr: trueOrFalse
	"If true, notify my view to accept whenever a <cr> is input"

	acceptOnCr _ trueOrFalse! !

!TtyPluggableTextController methodsFor: 'accessing' stamp: 'dtl 6/13/2001 22:07'!
callbackQueue
	"A queue of blocks to be evaluated. Asynchronously executing processes
	can place a block in this queue, and the block will later be evaluated
	in my control loop."

	^ callbackQueue ifNil: [callbackQueue _ SharedQueue new]! !

!TtyPluggableTextController methodsFor: 'accessing' stamp: 'dtl 6/24/2001 20:42'!
closed
	"True after user enters an 'exit' command"

	closed ifNil: [closed _ false].
	^ closed
! !

!TtyPluggableTextController methodsFor: 'accessing' stamp: 'dtl 6/24/2001 20:42'!
closed: trueOrFalse
	"True after user enters an 'exit' command"

	closed _ trueOrFalse
! !

!TtyPluggableTextController methodsFor: 'command input' stamp: 'dtl 6/9/2001 19:05'!
commandLineInput

	^ (self text copyFrom: self positionAfterPromptString to: self text size) asString.
! !

!TtyPluggableTextController methodsFor: 'command input' stamp: 'dtl 6/9/2001 19:06'!
positionAfterPromptString
	"Answer the index of the first character after the last prompt string in my text. If
	not found, then assume that the contents of the text are all intended to be command
	input."

	(1 to: (self text size - model promptString size))
		reverseDo: [:i |
			((self text findString: model promptString startingAt: i) ~= 0)
				ifTrue: [^ i + model promptString size]].
	^ 0
! !

!TtyPluggableTextController methodsFor: 'menu messages' stamp: 'dtl 8/4/2001 15:50'!
accept
	"Evaluate command in a separate process. The separate process will
	send #addDeferredUIMessage: to generate a new prompt when complete."

	self model readSyncSemaphore; activeController: self.
	self model doCommandsInString: self commandLineInput asString! !

!TtyPluggableTextController methodsFor: 'typing support' stamp: 'dtl 6/23/2001 18:53'!
dispatchOnCharacter: char with: typeAheadStream
	"Carry out the action associated with this character, if any.
	Type-ahead is passed so some routines can flush or use it."

	char ifNil: [^ char].
	(((char == Character cr) and: [self acceptOnCr]) and: [model keyboardConnector isNil])
		ifTrue:
			[sensor keyboard.  "consume enter key".
			self accept.
			ScheduledControllers searchForActiveController].
	(model filterAndForward: char) isNil
		ifTrue:
			[sensor keyboard.  "consume enter key".
			^ true]
		ifFalse:
			[^ super dispatchOnCharacter: char with: typeAheadStream]
! !

!TtyPluggableTextController methodsFor: 'callbacks' stamp: 'dtl 7/1/2001 18:48'!
addDeferredUIMessage: aBlock
	"Enqueue aBlock for later execution in my control loop."

	self callbackQueue nextPut: aBlock! !

!TtyPluggableTextController methodsFor: 'control defaults' stamp: 'dtl 6/18/2001 20:54'!
controlActivity

	[self callbackQueue isEmpty]
		whileFalse:
			[callbackQueue next value].
	^ super controlActivity! !

!TtyPluggableTextController methodsFor: 'control defaults' stamp: 'dtl 6/24/2001 20:45'!
startUp

	self closed ifFalse: [^ super startUp]! !


!TtyTextMorphForEditView methodsFor: 'editing' stamp: 'dtl 6/9/2001 16:04'!
keyStroke: evt

	(self editView model filterAndForward: evt keyValue asCharacter)
		ifNotNil: [^ super keyStroke: evt]
! !

CommandShell initialize!
"Postscript:

Open documention windows and a CommandShell, and display help for the user in the shell window."

CommandShell new command: 'CommandShell overview!! | edit'.
CommandShell new command: 'CommandShell raceConditions!! | edit'.
CommandShell new command: 'CommandShell commandProcessing!! | edit'.
CommandShell command: 'help'
!

